<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Der is in flater bard!';
$messages['loginfailed']  = 'Ynloggen mislearre.';
$messages['cookiesdisabled'] = 'Jo browser akseptearret gjin koekjes.';
$messages['sessionerror'] = 'Jo sesje is ûnjildich of ferrûn.';
$messages['storageerror'] = 'Ferbining mei opslach tsjinner mislearre.';
$messages['servererror'] = 'Tsjinner Flater!';
$messages['servererrormsg'] = 'Tsjinner Flater: $msg';
$messages['accountlocked'] = 'Ynloggen te faak mislearre. Besykje it letter nochris.';
$messages['connerror'] = 'Ferbinings Flater (Kin de tsjinner net berikke)!';
$messages['dberror'] = 'Databank Flater!';
$messages['windowopenerror'] = 'De popup finster waard blokkearre!';
$messages['requesttimedout'] = 'Fersyk ferrûn';
$messages['errorreadonly'] = 'Koe operaasje net útfiere. Map kin allinnich lêzen wurde.';
$messages['errornoperm'] = 'Koe operaasje net útfiere. Tastimming wegere.';
$messages['erroroverquota'] = 'Koe operaasje net útfiere. Gjin frije skiifromte.';
$messages['erroroverquotadelete'] = 'Gjin frije skiifromte. Brûk Shift + DEL om in berjocht te wiskjen.';
$messages['invalidrequest'] = 'Ûnjildich fersyk! Gjin data waard bewarre.';
$messages['invalidhost'] = 'Unjildige tsjinner namme.';
$messages['nomessagesfound'] = 'Gjin berjochten fûn yn dit postfek.';
$messages['mailboxempty'] = 'Postfek is leech';
$messages['nomessages'] = 'Gjin berjochten';
$messages['refreshing'] = 'Ferfarskje...';
$messages['loading'] = 'Lade...';
$messages['uploading'] = 'Bestân oplade...';
$messages['attaching'] = 'Bestân tafoegje...';
$messages['uploadingmany'] = 'Bestânnen oplade...';
$messages['loadingdata'] = 'Data lade...';
$messages['checkingmail'] = 'Kontrolearje op nije berjochten...';
$messages['sendingmessage'] = 'Berjocht ferstjoere...';
$messages['messagesent'] = 'Berjocht mei sukses ferstjoerd.';
$messages['savingmessage'] = 'Berjocht bewarje...';
$messages['messagesaved'] = 'Berjocht bewarre yn ûntwerpen.';
$messages['successfullysaved'] = 'Mei sukses bewarre.';
$messages['savingresponse'] = 'Antwurd tekst bewarje...';
$messages['deleteresponseconfirm'] = 'Wolle jo dizze antwurd tekst echt wiskje?';
$messages['addedsuccessfully'] = 'Kontakt mei sukses taheakke oan adresboek.';
$messages['contactexists'] = 'In kontakt mei deselde e-post adres bestiet al.';
$messages['contactnameexists'] = 'In kontakt mei deselde namme bestiet al.';
$messages['blockedimages'] = 'Om jo privacy te beskermjen binne eksterne ôfbyldingen blokkeare yn dit berjocht.';
$messages['encryptedmessage'] = 'Dit is in fersifere berjocht en kin net werjûn wurde. Sorry!';
$messages['externalmessagedecryption'] = 'Dit is in fersifere berjocht en kin ûntsifere wurde mei jo browser ekstinsje.';
$messages['nopubkeyfor'] = 'Gjin jildich iepenbiere kaai fûn foar $email';
$messages['nopubkeyforsender'] = 'Gjin jildich iepenbiere kaai fûn foar jo stjoerder identiteit. Wolle jo it berjocht allinnich foar de ûntfangers fersiferje?';
$messages['encryptnoattachments'] = 'Al oanbeane taheaksels kinne net fersifere wurde. Asjebleaft op \'e nij taheakje yn de fersifering bewurker.';
$messages['searchpubkeyservers'] = 'Wolle jo op publike kaai tsjinners sykje nei de missende kaaien?';
$messages['encryptpubkeysfound'] = 'De folgjende publike kaaien binne fûn:';
$messages['nocontactsfound'] = 'Gjin kontakten fûn.';
$messages['contactnotfound'] = 'De opfrege kontakt waard net fûn.';
$messages['sendingfailed'] = 'Berjocht koe net ferstjoerd wurde.';
$messages['senttooquickly'] = 'Wachtsje $sec sekonde(n) foar it ferstjoeren fan dit berjocht.';
$messages['errorsavingsent'] = 'Der barde in flater ûnder it bewarjen fan ferstjoerd berjocht.';
$messages['errorsaving'] = 'Der barde in flater ûnder it bewarjen.';
$messages['errormoving'] = 'Koe berjocht(en) net ferpleatse.';
$messages['errorcopying'] = 'Koe berjocht(en) net kopieare.';
$messages['errordeleting'] = 'Koe berjocht(en) net wiskje.';
$messages['errormarking'] = 'Koe berjocht(en) net markearje.';
$messages['deletecontactconfirm']  = 'Wolle jo selektearre kontakt(en) echt wiskje?';
$messages['deletegroupconfirm']  = 'Wolle jo selektearre groep echt wiskje?';
$messages['deletemessagesconfirm'] = 'Wolle jo selektearre berjocht(en) echt wiskje?';
$messages['deletefolderconfirm']  = 'Wolle jo dizze map echt wiskje?';
$messages['purgefolderconfirm']  = 'Wolle jo echt alle berjochten yn dizze map wiskje?';
$messages['contactdeleting'] = 'Kontakt(en) wiskje...';
$messages['groupdeleting'] = 'Groep wiskje...';
$messages['folderdeleting'] = 'Map wiskje...';
$messages['foldermoving'] = 'Map ferpleatse...';
$messages['foldersubscribing'] = 'Ynskriuwe map...';
$messages['folderunsubscribing'] = 'Utskriuwe map...';
$messages['formincomplete'] = 'It formulier wie net hielendal ynfolle.';
$messages['noemailwarning'] = 'Fier in jildich e-post adres yn.';
$messages['nonamewarning']  = 'Fier in namme yn.';
$messages['nopagesizewarning'] = 'Fier in side grutte yn.';
$messages['nosenderwarning'] = 'Fier stjoerder e-post adres yn.';
$messages['norecipientwarning'] = 'Fier op syn minst ien ûntfanger yn.';
$messages['disclosedrecipwarning'] = 'Alle ûntfangers sjoche de oare e-post adressen. Om dat te foarkommen en harren privacy te beskermjen kinne jo gebrûk meitsje fan it Bcc fjild.';
$messages['disclosedreciptitle'] = 'Tefolle iepenbiere ûntfangers';
$messages['nosubjectwarning']  = 'It "Underwerp" fjild is leech. Wolle jo no ien ynfiere?';
$messages['nosubjecttitle']  = 'Gjin ûnderwerp';
$messages['nobodywarning'] = 'Dit berjocht sûnder tekst ferstjoere?';
$messages['notsentwarning'] = 'It berjocht is net ferstjoerd en hat net-bewarre feroarings. Wolle jo de feroarings fuort smite?';
$messages['restoresavedcomposedata'] = 'In earder komponearre mar net-ferstjoerd berjocht waard fûn.\n\nSubject: $subject\nSaved: $date\n\nWolle jo dit berjocht weromsette?';
$messages['nosearchname'] = 'Fier in kontakt namme of e-post adres yn.';
$messages['notuploadedwarning'] = 'Noch net alle taheaksels binne opladen. Jo kinne wachtsje of it opladen ôfbrekke.';
$messages['searchsuccessful'] = '$nr berjochten fûn.';
$messages['contactsearchsuccessful'] = '$nr kontakten fûn.';
$messages['searchnomatch'] = 'Sykjen hat gjin risseltaten opsmiten.';
$messages['searching'] = 'Sykje...';
$messages['checking'] = 'Kontrolearje...';
$messages['stillsearching'] = 'Noch oan it sykjen...';
$messages['nospellerrors'] = 'Gjin stavering flaters fûn.';
$messages['folderdeleted'] = 'Map mei sukses wiske.';
$messages['foldersubscribed'] = 'Map mei sukses ynskreaun.';
$messages['folderunsubscribed'] = 'Map mei sukses útskreaun.';
$messages['deletedsuccessfully'] = 'Mei sukses wiske.';
$messages['converting'] = 'Opmaak wiskje...';
$messages['messageopenerror'] = 'Koe berjocht net fan tsjinner lade.';
$messages['filelinkerror'] = 'Taheakjen fan bestân mislearre.';
$messages['fileuploaderror'] = 'Bestân oplade mislearre.';
$messages['filesizeerror'] = 'It opladen bestân is grutter as de maksimale grutte fan $size.';
$messages['filecounterror'] = 'Jo kinne maksimaal $count bestânnen yn ien kear oplade.';
$messages['msgsizeerror'] = 'Bestân taheakje mislearre. Maksimum grutte fan in berjocht ($size) oer gien.';
$messages['copysuccess'] = 'Mei sukses $nr kontakten kopiearre.';
$messages['movesuccess'] = 'Mei sukses $nr kontakten ferpleatst.';
$messages['copyerror'] = 'Koe gjin kontakten kopiearje.';
$messages['moveerror'] = 'Koe gjin kontakten ferpleatse.';
$messages['sourceisreadonly'] = 'Dizze adres boarne kin allinnich lêzen wurde.';
$messages['errorsavingcontact'] = 'Koe kontakt adres net bewarje.';
$messages['movingmessage'] = 'Berjocht(en) ferpleatse...';
$messages['copyingmessage'] = 'Berjocht(en) kopiearje...';
$messages['copyingcontact'] = 'Kontakt(en) kopiearje...';
$messages['movingcontact'] = 'Kontakt(en) ferpleatse...';
$messages['deletingmessage'] = 'Berjocht(en) wiskje...';
$messages['markingmessage'] = 'Berjocht(en) markearje...';
$messages['addingmember'] = 'Kontakt(en) oan de groep tafoegje...';
$messages['removingmember'] = 'Kontakt(en) út de groep ferwiderje...';
$messages['receiptsent'] = 'Mei súkses in lêzen ûntfangstbewiis ferstjoerd.';
$messages['errorsendingreceipt'] = 'Koe it ûntfangstbewiis net stjoere.';
$messages['deleteidentityconfirm'] = 'Wolle jo echt dizze identiteit wiskje?';
$messages['nodeletelastidentity'] = 'Jo kinne dizze identiteit net wiskje, it is jo lêste.';
$messages['forbiddencharacter'] = 'Mapnamme befettet in ferbean karakter.';
$messages['selectimportfile'] = 'Selektearje in bestân om op te laden.';
$messages['addresswriterror'] = 'It selektearre adres boek is net skriuwber.';
$messages['contactaddedtogroup'] = 'De kontakten mei sukses oan dizze groep taheakke.';
$messages['contactremovedfromgroup'] = 'De kontakten mei sukses út dizze groep ferwidere.';
$messages['nogroupassignmentschanged'] = 'Gjin groep opdrachten feroare.';
$messages['importwait'] = 'Ymportearjen, in amerijke...';
$messages['importformaterror'] = 'Ymport mislearre! It opladen bestân is net in jildich ymport data bestân.';
$messages['importconfirm'] = '<b>Mei sukses ymportearre $inserted kontakten</b>';
$messages['importconfirmskipped'] = '<b>Oerslein $skipped besteande weardes</b>';
$messages['importmessagesuccess'] = 'Mei sukses $nr berjochten ymportearre';
$messages['importmessageerror'] = 'Ymport mislearre! It opladen bestân is net in jildich berjocht of postfek bestân';
$messages['opnotpermitted'] = 'Operaasje net tastien!';
$messages['nofromaddress'] = 'E-post adres mist yn selektearre identiteit.';
$messages['editorwarning'] = 'Troch te wiskeljen fan berwurker kin tekst opmaak ferlern gean. Wolle jo trochgean?';
$messages['httpreceivedencrypterror'] = 'In fatale konfiguraasje flater. Nim fuortendaliks kontakt op mei jo systeembehearder. <B>Jo berjocht kin net stjoerd wurde.</ B>';
$messages['smtpconnerror'] = 'SMTP Flater ($code): Ferbining mei tsjinner mislearre.';
$messages['smtpautherror'] = 'SMTP Flater ($code): Ferifikaasje mislearre.';
$messages['smtpfromerror'] = 'SMTP Flater ($code): Stjoerder fêststelle mislearre "$from" ($msg).';
$messages['smtptoerror'] = 'SMTP Flater ($code): Untfanger tafoegje mislearre "$to" ($msg).';
$messages['smtprecipientserror'] = 'SMTP Flater: Koe ûntfangers lyst net ferwurkje.';
$messages['smtperror'] = 'SMTP Flater: $msg';
$messages['emailformaterror'] = 'Unjildich e-post adres: $email';
$messages['toomanyrecipients'] = 'Tefolle ûntfangers. Ferminderje it tal fan ûntfangers nei $max.';
$messages['maxgroupmembersreached'] = 'It tal fan groep leden is grutter as it maksimum fan $max.';
$messages['internalerror'] = 'In ynterne flater. Besykje it nochris.';
$messages['contactdelerror'] = 'Koe kontakt(en) net wiskje.';
$messages['contactdeleted'] = 'Kontakt(en) mei sukses wiske.';
$messages['contactrestoreerror'] = 'Koe wiske kontakt(en) net werom sette.';
$messages['contactrestored'] = 'Kontakt(en) mei sukses werom setten.';
$messages['groupdeleted'] = 'Groep mei sukses wiske.';
$messages['grouprenamed'] = 'Groep namme mei sukses feroare.';
$messages['groupcreated'] = 'Groep mei sukses oanmakke.';
$messages['savedsearchdeleted'] = 'Bewarre syk opdracht mei sukses wiske.';
$messages['savedsearchdeleteerror'] = 'Koe bewarre syk opdracht net wiskje.';
$messages['savedsearchcreated'] = 'Syk opdracht mei sukses bewarre.';
$messages['savedsearchcreateerror'] = 'Koe syk opdracht net bewarje.';
$messages['messagedeleted'] = 'Berjocht(en) mei sukses wiske.';
$messages['messagemoved'] = 'Berjocht(en) mei sukses ferpleatst.';
$messages['messagemovedtotrash'] = 'Berjocht(en) mei sukses nei Jiskefet ferpleatse.';
$messages['messagecopied'] = 'Berjocht(en) mei sukses kopieare.';
$messages['messagemarked'] = 'Berjocht(en) mei sukses markeare.';
$messages['autocompletechars'] = 'Fier op syn minst $min tekens yn foar autokompleet.';
$messages['autocompletemore'] = 'Mear oerienkommende risseltaten fûn. Typ mear tekens.';
$messages['namecannotbeempty'] = 'Namme kin net leech wêze.';
$messages['nametoolong'] = 'Namme is te lang.';
$messages['namedotforbidden'] = 'Mapnamme kin net mei in punt begjinne.';
$messages['folderupdated'] = 'Map mei sukses bywurke.';
$messages['foldercreated'] = 'Map mei sukses oanmakke.';
$messages['invalidimageformat'] = 'Gjin jildich ôfbyldings formaat.';
$messages['mispellingsfound'] = 'Stavering flaters ûntdutsen yn it berjocht.';
$messages['parentnotwritable'] = 'Koe map net oanmeitsje/ferhúzje yn selektearre boppelizzende map. Gjin tagong rjochten.';
$messages['messagetoobig'] = 'It berjocht diel is te grut om te ferwurkjen.';
$messages['noscriptwarning'] = 'Warskôging: Dizze webmail tsjinst fereasket Javascript! Om it te brûken moatte jo Javascript ynskeakelje yn jo browser ynstellings.';
$messages['messageissent'] = 'Dit berjocht wie al ferstjoerd, mar noch net bewarre. Wolle jo it no bewarje?';
$messages['errnotfound'] = 'Bestân Net Fûn';
$messages['errnotfoundexplain'] = 'De frege boarne waard net fûn!';
$messages['errfailedrequest'] = 'Mislearre Fersyk';
$messages['errauthorizationfailed'] = 'Autorisaasje Mislearre';
$messages['errunauthorizedexplain'] = 'Koe net nei gean oft jo machtige binne om tagong te krijen ta dizze tsjinst!';
$messages['errrequestcheckfailed'] = 'Fersyk Kontrole Mislearre';
$messages['errcsrfprotectionexplain'] = "Foar jo beskerming, tagong ta dizze boarne is befeilige tsjin CSRF.\nAs jo dit sjogge, hawwe jo net útlogge foar it ferlitten fan de web applikaasje.\n\nMinskelike ynteraksje is no ferplichte om fierder te gean.";
$messages['errcontactserveradmin'] = 'Nim kontakt op mei jo tsjinner-behearder.';
$messages['clicktoresumesession'] = 'Klik hjir om jo foarige sesje te ferfetsjen';
$messages['errcomposesession'] = 'Skriuw berjocht sesje flater';
$messages['errcomposesessionexplain'] = 'Fersyk skriuw berjocht sesje net fûn.';
$messages['clicktocompose'] = 'Klik hjir om in nij berjocht te skriuwen';
