<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'خطایی رخ داد!';
$messages['loginfailed']  = 'ورود ناموفق بود.';
$messages['cookiesdisabled'] = 'مرورگر شما کوکی‌ها را قبول نمی‌کند.';
$messages['sessionerror'] = 'نشست شما معتبر نیست، یا منقضی شده است.';
$messages['storageerror'] = 'اتصال به سرور مخزن ناموفق بود.';
$messages['servererror'] = 'خطای سرور!';
$messages['servererrormsg'] = 'خطای سرور: $msg';
$messages['connerror'] = 'خطای ارتباط (عدم دسترسی به سرور)!';
$messages['dberror'] = 'خطای پایگاه داده!';
$messages['windowopenerror'] = 'پنجره پاپ‌آپ مسدود شده است!';
$messages['requesttimedout'] = 'زمان درخواست تمام شد';
$messages['errorreadonly'] = ' عمل مورد نظر انجام نشد. پوشه فقط خواندنی است.';
$messages['errornoperm'] = ' عمل مورد نظر انجام نشد. دسترسی وجود ندارد.';
$messages['erroroverquota'] = 'عملیات انجام نشد. دیسک فضای خالی ندارد.';
$messages['erroroverquotadelete'] = 'دیسک فضای خالی ندارد. برای حذف پیام از SHIFT+DEL استفاده کنید.';
$messages['invalidrequest'] = 'درخواست نامعتبر! هیچ داده‌ای ذخیره نشد.';
$messages['invalidhost'] = 'نام سرور غیرمعتبر.';
$messages['nomessagesfound'] = 'هیچ پیغامی در این صندوق‌پستی پیدا نشد.';
$messages['mailboxempty'] = 'صندوق پستی خالی است';
$messages['nomessages'] = 'بدون پیام';
$messages['refreshing'] = 'نوسازی...';
$messages['loading'] = 'بارگذاری...';
$messages['uploading'] = 'بارگذاری پرونده...';
$messages['attaching'] = 'پیوست کردن پرونده...';
$messages['uploadingmany'] = 'بارگذاری پرونده‌ها...';
$messages['loadingdata'] = 'بارگذاری داده‌ها...';
$messages['checkingmail'] = 'بررسی برای پیام‌های جدید...';
$messages['sendingmessage'] = 'ارسال پیغام...';
$messages['messagesent'] = 'پیغام با موفقیت فرستاده شد.';
$messages['savingmessage'] = 'ذخیره‌ی پیام...';
$messages['messagesaved'] = 'پیغام در پیش‌نویس‌ها ذخیره شد.';
$messages['successfullysaved'] = 'با موفقیت ذخیره شد.';
$messages['savingresponse'] = 'ذخیره متن پاسخ...';
$messages['deleteresponseconfirm'] = 'آیا واقعا می‌خواهید این متن پاسخ را حذف نمایید؟';
$messages['addedsuccessfully'] = 'مخاطب با موفقیت به دفتر نشانی‌ها اضافه شد.';
$messages['contactexists'] = 'مخاطبی با آدرس ایمیل مشابه وجود دارد.';
$messages['contactnameexists'] = 'در حال حاضر مخاطبی با نام یکسان وجود دارد.';
$messages['blockedimages'] = 'برای حفاظت از حریم شخصی شما، عکس‌های خارجی در این پیام مسدود شده‌اند.';
$messages['encryptedmessage'] = 'این یک پیام رمزنگاری شده است و قابل نمایش نیست. با عرض پوزش!';
$messages['nocontactsfound'] = 'مخاطبی پیدا نشد.';
$messages['contactnotfound'] = 'مخاطب درخواست شده پیدا نشد.';
$messages['sendingfailed'] = 'ارسال پیغام ناموفق بود.';
$messages['senttooquickly'] = 'لطفا قبل از ارسال این پیام $sec ثانیه صبر کنید.';
$messages['errorsavingsent'] = 'خطایی رخ داده است پیام ارسالی ذخیره می گردد.';
$messages['errorsaving'] = 'خطایی در ذخیره کردن رخ داده است.';
$messages['errormoving'] = 'پیام(ها) منتقل نشدند.';
$messages['errorcopying'] = 'پیام(ها) کپی نشدند.';
$messages['errordeleting'] = 'پیام(ها) حذف نشدند.';
$messages['errormarking'] = 'پیام(ها) نشانه‌گذاری نشدند.';
$messages['deletecontactconfirm']  = 'آیا واقعاً می‌خواهید مخاطب(های) انتخاب شده را حذف کنید؟';
$messages['deletegroupconfirm']  = 'آیا واقعا می‌خواهید گروه انتخاب شده را حذف کنید؟';
$messages['deletemessagesconfirm'] = 'آیا واقعاً می‌خواهید پیام(های) انتخاب شده را حذف کنید؟';
$messages['deletefolderconfirm']  = 'آیا واقعاً می‌خواهید این پوشه را حذف کنید؟';
$messages['purgefolderconfirm']  = 'آیا واقعاً می‌خواهید همه‌ی پیام‌های داخل این پوشه را حذف کنید؟';
$messages['contactdeleting'] = 'حذف مخاطب(ها)...';
$messages['groupdeleting'] = 'حذف گروه...';
$messages['folderdeleting'] = 'حذف پوشه...';
$messages['foldermoving'] = 'جابجایی پوشه...';
$messages['foldersubscribing'] = 'اشتراک پوشه...';
$messages['folderunsubscribing'] = 'لغو اشتراک پوشه...';
$messages['formincomplete'] = 'فرم کامل پر نشده بود.';
$messages['noemailwarning'] = 'لطفا یک نشانی رایانامه معتبر وارد کنید.';
$messages['nonamewarning']  = 'لطفا یک نام وارد کنید.';
$messages['nopagesizewarning'] = 'لطفا اندازه‌ی صفحه را وارد کنید.';
$messages['nosenderwarning'] = 'لطفا آدرس ایمیل فرستنده را وارد کنید.';
$messages['norecipientwarning'] = 'لطفاً حداقل یک گیرنده وارد کنید.';
$messages['nosubjectwarning']  = 'قسمت "موضوع" خالی است. می‌خواهید اکنون وارد کنید؟';
$messages['nosubjecttitle']  = 'بدون موضوع';
$messages['nobodywarning'] = 'این پیام بدون متن ارسال شود؟';
$messages['restoresavedcomposedata'] = 'نامه قبلا نوشته و نفرستاده یافت شد.\n\nموضوع: $subject\n
ذخیره شده: $date\n\nآیا می‌خواهید این پیام را بازیابی نمایید؟';
$messages['nosearchname'] = 'لطفا یک نام مخاطب یا نشانی رایانامه وارد نمایید.';
$messages['notuploadedwarning'] = 'همه پیوست ها هنوز بارگذاری نشده‌اند. لطفا صبر کرده یا بارگذاری را لغو کنید.';
$messages['searchsuccessful'] = '$nr پیام پیدا شد.';
$messages['contactsearchsuccessful'] = '$nr مخاطب ییدا شد.';
$messages['searchnomatch'] = 'جست‌و‌جو هیچ نتیجه‌ای نداشت.';
$messages['searching'] = 'در حال جست‌و‌جو...';
$messages['checking'] = 'در حال بررسی...';
$messages['stillsearching'] = 'هنور در حال جستجو...';
$messages['nospellerrors'] = 'هیچ اشکال املایی پیدا نشد.';
$messages['folderdeleted'] = 'پوشه با کام‌یابی حذف شد.';
$messages['foldersubscribed'] = 'اشتراک پوشه با کام‌یابی انجام شد.';
$messages['folderunsubscribed'] = 'اشتراک پوشه با کام‌یابی لغو شد.';
$messages['deletedsuccessfully'] = 'با کام‌یابی حذف شد.';
$messages['converting'] = 'در حال حذف قالب‌بندی...';
$messages['messageopenerror'] = 'بارگذاری پیام از روی سرور انجام نشد.';
$messages['fileuploaderror'] = 'بارگذاری پرونده ناموفق بود.';
$messages['filesizeerror'] = 'اندازه‌ی پرونده‌ی بارگذاری شده از بیشینه اندازه‌ی $size بیشتر است.';
$messages['copysuccess'] = '$nr مخاطب با کام‌یابی کپی شد.';
$messages['movesuccess'] = '$nr مخاطب با کام‌یابی جابجا شد.';
$messages['copyerror'] = 'مخاطب‌ها کپی نشدند.';
$messages['moveerror'] = 'مخاطب‌ها جابجا نشدند.';
$messages['sourceisreadonly'] = 'این منبع نشانی فقط خواندنی است.';
$messages['errorsavingcontact'] = 'ذخیره‌ی نشانی مخاطب ناموفق بود.';
$messages['movingmessage'] = 'در حال انتقال پیام(ها)...';
$messages['copyingmessage'] = 'در حال کپی‌برداری از پیام(ها)...';
$messages['copyingcontact'] = 'در حال کپی‌برداری مخاطب(ها)...';
$messages['movingcontact'] = 'در حال جابجایی مخاطب(ها)...';
$messages['deletingmessage'] = 'در حال حذف پیام(ها)...';
$messages['markingmessage'] = 'در حال نشانه‌گذاری پیام(ها)...';
$messages['addingmember'] = 'در حال افزودن مخاطب(ها) به گروه...';
$messages['removingmember'] = 'در حال حذف مخاطب(ها) از گروه...';
$messages['receiptsent'] = 'رسید خواندن با کام‌یابی ارسال شد.';
$messages['errorsendingreceipt'] = 'ارسال رسید انجام نشد.';
$messages['deleteidentityconfirm'] = 'آیا از حذف این شناسه مطمئن هستید؟';
$messages['nodeletelastidentity'] = 'این شناسه را نمی‌توانید حذف کنید، زیرا آخرین شناسه شما است.';
$messages['forbiddencharacter'] = 'نام پوشه شامل یک کاراکتر غیر مجاز است.';
$messages['selectimportfile'] = 'لطفاً پرونده‌ای را برای بارگذاری انتخاب کنید.';
$messages['addresswriterror'] = 'دفترچه نشانی انتخابی قابل نوشتن نیست.';
$messages['contactaddedtogroup'] = 'مخاطب‌ها با کام‌یابی به این گروه اضافه شدند.';
$messages['contactremovedfromgroup'] = 'مخاطب‌ها با کام‌یابی از این گروه حذف شدند.';
$messages['nogroupassignmentschanged'] = 'هیچ تکلیف گروهی تغییر نکرده است.';
$messages['importwait'] = 'در حال وارد کردن، لطفا صبر کنید...';
$messages['importformaterror'] = 'وارد کردن ناموفق! فایل بارگذاری شده یک فایل اطلاعات معتبر نیست.';
$messages['importconfirm'] = '<b>$inserted مخاطب با کام‌یابی وارد شدند</b>';
$messages['importconfirmskipped'] = '<b>$skipped ورودی موجود نادیده گرفته شدند</b>';
$messages['importmessagesuccess'] = 'با کام‌یابی $nr پیام وارد شد.';
$messages['importmessageerror'] = 'وارد کردن ناموفق! فایل بارگذاری شده یک پیام یا صندوق‌پستی معتبر نیست.';
$messages['opnotpermitted'] = 'عملیات مجاز نیست!';
$messages['editorwarning'] = 'تعویض به ویرایشگر متن ساده باعث از دست رفتن قالب‌بندی همه متن‌ها می‌شود، آیا می‌خواهید عملیات را ادامه بدهید؟';
$messages['httpreceivedencrypterror'] = 'یک خطای پیکربندی خطرناک رخ داده است. سریعا با سرپرست یا مسئول خود تماس بگیرید. <b>امکان ارسال  پیام شما وجود ندارد.</b>';
$messages['smtpconnerror'] = 'خطای SMTP ($code): اتصال به سرور ناموفق بود.';
$messages['smtpautherror'] = 'خطای SMTP ($code): تصدیق هویت ناموفق بود.';
$messages['smtpfromerror'] = 'خطای SMTP ($code): ناموفق در تنظیم فرستنده "$from" ($msg).';
$messages['smtptoerror'] = 'خطای SMTP ($code): نام موفق در افزودن گیرنده "$to" ($msg).';
$messages['smtprecipientserror'] = 'خطای SMTP: ناتوان در تجزیه فهرست گیرنده‌ها.';
$messages['smtperror'] = 'خطای SMTP: $msg';
$messages['toomanyrecipients'] = 'گیرنده‌های بیش از اندازه: تعداد گیرنده ها را به $max کاهش دهید.';
$messages['maxgroupmembersreached'] = 'تعداد اعضای گروه بیشتر از $max است.';
$messages['internalerror'] = 'یک خطای داخلی رخ داده است. لطفا دوباره سعی کنید.';
$messages['contactdelerror'] = 'حذف مخاطب(ها) انجام شد.';
$messages['contactdeleted'] = 'مخاطب(ها) با کام‌یابی حذف شدند.';
$messages['contactrestoreerror'] = 'مخاطب(های) حذف شده بازگردانی نخواهند شد.';
$messages['contactrestored'] = 'مخاطب(ها) با کام‌یابی بازگردانده شدند.';
$messages['groupdeleted'] = 'گروه با کام‌یابی حذف شد.';
$messages['grouprenamed'] = 'نام گروه با کام‌یابی تغییر داده شد.';
$messages['groupcreated'] = 'گروه با کام‌یابی ایجاد شد.';
$messages['savedsearchdeleted'] = 'جستجوی ذخیره شده با کام‌یابی حذف شد.';
$messages['savedsearchdeleteerror'] = 'حذف جستجوی ذخیره شده انجام نشد.';
$messages['savedsearchcreated'] = 'جستجوی حذف شده با کام‌یابی ایجاد شد.';
$messages['savedsearchcreateerror'] = 'ساخت جستجوی ذخیره شده انجام نشد.';
$messages['messagedeleted'] = 'پیام(ها) با کام‌یابی حذف شدند.';
$messages['messagemoved'] = 'پیام(ها) با کام‌یابی منتقل شدند.';
$messages['messagecopied'] = 'پیام(ها) با کام‌یابی کپی شدند.';
$messages['messagemarked'] = 'پیام(ها) با کام‌یابی نشانه‌گذاری شدند.';
$messages['autocompletechars'] = 'حداقل $min حرف برای تکمیل خودکار وارد نمایید.';
$messages['autocompletemore'] = 'نتایج زیادی یافت شد. لطفا حروف بیشتری وارد نمایید.';
$messages['namecannotbeempty'] = 'نام نمی‌تواند خالی باشد.';
$messages['nametoolong'] = 'نام خیلی طولانی است.';
$messages['folderupdated'] = 'پوشه با کام‌یابی به‌روز شد.';
$messages['foldercreated'] = 'پوشه با کام‌یابی افزوده شد.';
$messages['invalidimageformat'] = 'فرمت تصویر نامعتبر است.';
$messages['mispellingsfound'] = 'خطای املایی در پیام شناسایی شد.';
$messages['parentnotwritable'] = 'به دلیل نداشتن حق دسترسی، ایجاد/انتقال پوشه به پوشه والد انتخاب شده، انجام نشد.';
$messages['messagetoobig'] = 'بخش پیام برای پردازش آن خیلی بزرگ است.';
$messages['noscriptwarning'] = 'هشدار: این برنامه به جاوااسکریپت نیاز دارد! برای استفاده از این برنامه لطفا جاوااسکریپت را در تنظیمات مرورگر خود فعال نمایید.';
$messages['errnotfound'] = 'پرونده پیدا نشد';
