<?php

/*
+-----------------------------------------------------------------------+
| localization/de_CH/csv2vcard.inc                                      |
|                                                                       |
| Localization file of the Roundcube Webmail client                     |
| Copyright (C) 2005-2014, The Roundcube Dev Team                       |
|                                                                       |
| Licensed under the GNU General Public License version 3 or            |
| any later version with exceptions for skins & plugins.                |
| See the README file for a full license statement.                     |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Aleksander Machniak <alec@alec.pl>                            |
+-----------------------------------------------------------------------+
*/
$map = array();
$map['anniversary'] = "Jahrestag";
$map['assistants_name'] = "Name Assistent";
$map['assistants_phone'] = "Telefon Assistent";
$map['birthday'] = "Geburtstag";
$map['business_city'] = "Ort geschäftlich";
$map['business_countryregion'] = "Region geschäftlich";
$map['business_fax'] = "Fax geschäftlich";
$map['business_phone'] = "Telefon geschäftlich";
$map['business_phone_2'] = "Telefon geschäftlich 2";
$map['business_postal_code'] = "Postleitzahl geschäftlich";
$map['business_state'] = "Land geschäftlich";
$map['business_street'] = "Straße geschäftlich";
$map['car_phone'] = "Autotelefon";
$map['categories'] = "Kategorien";
$map['company'] = "Firma";
$map['department'] = "Abteilung";
$map['email_address'] = "E-Mail-Adresse";
$map['first_name'] = "Vorname";
$map['gender'] = "Geschlecht";
$map['home_city'] = "Ort privat";
$map['home_countryregion'] = "Region privat";
$map['home_fax'] = "Fax privat";
$map['home_phone'] = "Telefon privat";
$map['home_phone_2'] = "Telefon privat 2";
$map['home_postal_code'] = "Postleitzahl privat";
$map['home_state'] = "Land privat";
$map['home_street'] = "Straße privat";
$map['job_title'] = "Position";
$map['last_name'] = "Nachname";
$map['managers_name'] = "Manager's Name";
$map['middle_name'] = "Weitere Vornamen";
$map['mobile_phone'] = "Mobiltelefon";
$map['notes'] = "Notizen";
$map['other_city'] = "Weiterer Ort";
$map['other_countryregion'] = "Weitere Region";
$map['other_fax'] = "Weiteres Fax";
$map['other_phone'] = "Weiteres Telefon";
$map['other_postal_code'] = "Weitere Postleitzahl";
$map['other_state'] = "Weiteres Land";
$map['other_street'] = "Weitere Straße";
$map['pager'] = "Pager";
$map['primary_phone'] = "Haupttelefon";
$map['spouse'] = "Spouse";
$map['suffix'] = "Suffix";
$map['title'] = "Title";
$map['web_page'] = "Webseite";
$map['birth_day'] = "Geburtstag";
$map['birth_month'] = "Geburtsmonat";
$map['birth_year'] = "Geburtsjahr";
$map['display_name'] = "Anzeigename";
$map['fax_number'] = "Fax-Nummer";
$map['home_address'] = "Privat: Adresse";
$map['home_country'] = "Privat: Land";
$map['home_zipcode'] = "Privat: PLZ";
$map['mobile_number'] = "Mobil-Tel.-Nr.";
$map['nickname'] = "Spitzname";
$map['organization'] = "Organisation";
$map['pager_number'] = "Pager-Nummer";
$map['primary_email'] = "Primäre E-Mail-Adresse";
$map['secondary_email'] = "Sekundäre E-Mail-Adresse";
$map['web_page_1'] = "Webseite 1";
$map['web_page_2'] = "Webseite 2";
$map['work_phone'] = "Tel. dienstlich";
$map['work_address'] = "Dienstlich: Adresse";
$map['work_country'] = "Dienstlich: Land";
$map['work_zipcode'] = "Dienstlich: PLZ";
$map['date_of_birth'] = "Date of Birth";
$map['email'] = "Email";
$map['home_mobile'] = "Home Mobile";
$map['home_zip'] = "Home Zip";
$map['info'] = "Info";
$map['user_photo'] = "User Photo";
$map['url'] = "URL";
$map['work_city'] = "Work City";
$map['work_company'] = "Work Company";
$map['work_dept'] = "Work Dept";
$map['work_fax'] = "Work Fax";
$map['work_mobile'] = "Work Mobile";
$map['work_state'] = "Work State";
$map['work_title'] = "Work Title";
$map['work_zip'] = "Work Zip";
