<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Velkomin í $product';
$labels['username'] = 'Netfang';
$labels['password'] = 'Lykilorð';
$labels['server'] = 'Póstþjónn';
$labels['login'] = 'Innskrá';
$labels['oauthlogin'] = 'Skrá inn með $provider';
$labels['menu'] = 'Valmynd';
$labels['logout'] = 'Útskrá';
$labels['mail'] = 'Tölvupóstur';
$labels['settings'] = 'Stillingar';
$labels['addressbook'] = 'Nafnaskrá';
$labels['darkmode'] = 'Dökkur hamur';
$labels['lightmode'] = 'Ljós hamur';
$labels['inbox'] = 'Innhólf';
$labels['drafts'] = 'Drög';
$labels['sent'] = 'Sent';
$labels['trash'] = 'Rusl';
$labels['junk'] = 'Ruslpóstur';
$labels['show_real_foldernames'] = 'Birta raunveruleg heiti á sérmöppum';
$labels['subject'] = 'Titill';
$labels['from'] = 'Frá';
$labels['sender'] = 'Sendandi';
$labels['to'] = 'Til';
$labels['cc'] = 'Afrit';
$labels['bcc'] = 'Falið afrit';
$labels['replyto'] = 'Svar til';
$labels['followupto'] = 'Svar við';
$labels['date'] = 'Dagsetning';
$labels['size'] = 'Stærð';
$labels['priority'] = 'Forgangur';
$labels['organization'] = 'Stofnun';
$labels['readstatus'] = 'Lesmerking';
$labels['listoptions'] = 'Telja upp valkosti...';
$labels['listoptionstitle'] = 'Valkostir lista';
$labels['mailboxlist'] = 'Möppur';
$labels['messagesfromto'] = 'Skilaboð $from til $to af $count';
$labels['threadsfromto'] = 'Skilaboðaþræðir $from til $to af $count';
$labels['messagenrof'] = 'Skilaboð $nr af $count';
$labels['fromtoshort'] = '$from - $to af $count';
$labels['copy'] = 'Afrit';
$labels['move'] = 'Færa';
$labels['moveto'] = 'Færa í...';
$labels['copyto'] = 'Afrita í...';
$labels['download'] = 'Sækja';
$labels['open'] = 'Opna';
$labels['showattachment'] = 'Birta';
$labels['showanyway'] = 'Birta það samt';
$labels['filename'] = 'Skráarheiti';
$labels['filesize'] = 'Skráarstærð';
$labels['addtoaddressbook'] = 'Bæta í nafnaskrá';
$labels['sun'] = 'sun.';
$labels['mon'] = 'mán.';
$labels['tue'] = 'þri.';
$labels['wed'] = 'mið.';
$labels['thu'] = 'fim.';
$labels['fri'] = 'fös.';
$labels['sat'] = 'lau.';
$labels['sunday'] = 'sunnudagur';
$labels['monday'] = 'mánudagur';
$labels['tuesday'] = 'þriðjudagur';
$labels['wednesday'] = 'miðvikudagur';
$labels['thursday'] = 'fimmtudagur';
$labels['friday'] = 'föstudagur';
$labels['saturday'] = 'laugardagur';
$labels['jan'] = 'jan';
$labels['feb'] = 'feb';
$labels['mar'] = 'mar';
$labels['apr'] = 'apr';
$labels['may'] = 'maí';
$labels['jun'] = 'jún';
$labels['jul'] = 'júl';
$labels['aug'] = 'ágú';
$labels['sep'] = 'sep';
$labels['oct'] = 'okt';
$labels['nov'] = 'nóv';
$labels['dec'] = 'des';
$labels['longjan'] = 'janúar';
$labels['longfeb'] = 'febrúar';
$labels['longmar'] = 'mars';
$labels['longapr'] = 'apríl';
$labels['longmay'] = 'maí';
$labels['longjun'] = 'júní';
$labels['longjul'] = 'júlí';
$labels['longaug'] = 'ágúst';
$labels['longsep'] = 'september';
$labels['longoct'] = 'október';
$labels['longnov'] = 'nóvember';
$labels['longdec'] = 'desember';
$labels['today'] = 'Í dag';
$labels['refresh'] = 'Endurhlaða';
$labels['checkmail'] = 'Athuga með ný skilaboð';
$labels['compose'] = 'Semja skilaboð';
$labels['writenewmessage'] = 'Búa til ný skilaboð';
$labels['reply'] = 'Svara';
$labels['replytomessage'] = 'Svara skilaboðum';
$labels['replytoallmessage'] = 'Svar til lista eða sendanda og allra viðtakenda';
$labels['replyall'] = 'Svara öllum';
$labels['replylist'] = 'Svar til lista';
$labels['forward'] = 'Áframsenda';
$labels['forwardinline'] = 'Áframsenda innan skilaboða';
$labels['forwardattachment'] = 'Áframsenda sem viðhengi';
$labels['forwardmessage'] = 'Áframsenda skilaboðin';
$labels['bouncemsg'] = 'Endursenda (bounce)';
$labels['bounce'] = 'Endursenda';
$labels['deletemessage'] = 'Eyða skilaboðum';
$labels['movemessagetotrash'] = 'Færa skilaboð í ruslið';
$labels['printmessage'] = 'Prenta þessi skilaboð';
$labels['previousmessage'] = 'Birta fyrri skilaboð';
$labels['firstmessage'] = 'Birta fyrstu skilaboð';
$labels['nextmessage'] = 'Birta næstu skilaboð';
$labels['lastmessage'] = 'Birta síðustu skilaboðin';
$labels['backtolist'] = 'Til baka í skilaboðalista';
$labels['viewsource'] = 'Skoða kóða';
$labels['mark'] = 'Merki';
$labels['markmessages'] = 'Merkja skilaboð';
$labels['markread'] = 'Sem lesið';
$labels['markunread'] = 'Sem ólesið';
$labels['markflagged'] = 'Sem flaggað';
$labels['markunflagged'] = 'Sem óflaggað';
$labels['markundeleted'] = 'Sem ekki eytt';
$labels['moreactions'] = 'Fleiri aðgerðir...';
$labels['markallread'] = 'Merkja allt sem lesið';
$labels['folders-cur'] = 'Aðeins valin mappa';
$labels['folders-sub'] = 'Valin mappa og undirmöppur hennar';
$labels['folders-all'] = 'Allar möppur';
$labels['more'] = 'Meira';
$labels['back'] = 'Til baka';
$labels['options'] = 'Valkostir';
$labels['composeoptions'] = 'Valkostir við samningu skilaboða';
$labels['optionsandattachments'] = 'Valkostir og viðhengi';
$labels['actions'] = 'Aðgerðir';
$labels['first'] = 'Fyrsta';
$labels['last'] = 'Síðasta';
$labels['previous'] = 'Fyrra';
$labels['next'] = 'Næsta';
$labels['select'] = 'Velja';
$labels['selection'] = 'Val';
$labels['all'] = 'Allt';
$labels['none'] = 'Ekkert';
$labels['currpage'] = 'Núverandi síða';
$labels['isread'] = 'Lesið';
$labels['unread'] = 'Ólesið';
$labels['flagged'] = 'Flaggað';
$labels['unflagged'] = 'Óflaggað';
$labels['unanswered'] = 'Ósvarað';
$labels['withattachment'] = 'Með viðhengi';
$labels['deleted'] = 'Eytt';
$labels['undeleted'] = 'Ekki eytt';
$labels['replied'] = 'Svarað';
$labels['forwarded'] = 'Áframsent';
$labels['invert'] = 'Umhverfa';
$labels['filter'] = 'Sía';
$labels['list'] = 'Listi';
$labels['threads'] = 'Þræðir';
$labels['expand-all'] = 'Þenja allt út';
$labels['expand-unread'] = 'Þenja ólesið';
$labels['collapse-all'] = 'Fella allt saman';
$labels['threaded'] = 'Þrætt';
$labels['showunread'] = 'Birta ólesin skilaboð';
$labels['autoexpand_threads'] = 'Þenja skilaboðaþræði út';
$labels['do_expand'] = 'allir þræðir';
$labels['expand_only_unread'] = 'aðeins ólesin skilaboð';
$labels['fromto'] = 'Frá/Til';
$labels['flag'] = 'Flagg';
$labels['attachment'] = 'Viðhengi';
$labels['nonesort'] = 'Ekkert';
$labels['sentdate'] = 'Sendingardagur';
$labels['arrival'] = 'Komudagur';
$labels['asc'] = 'hækkandi';
$labels['desc'] = 'lækkandi';
$labels['listcolumns'] = 'Listadálkar';
$labels['listsorting'] = 'Röðunardálkur';
$labels['listorder'] = 'Röðun';
$labels['listmode'] = 'Listayfirlit';
$labels['lmode'] = 'Listahamur';
$labels['layout'] = 'Framsetning';
$labels['layoutwidescreen'] = 'Breiðskjár';
$labels['layoutdesktop'] = 'Skjáborð';
$labels['layoutlist'] = 'Listi';
$labels['layoutwidescreendesc'] = 'Breiðskjár (3-dálka sýn)';
$labels['layoutdesktopdesc'] = 'Skjáborð (breiður listi með forskoðun fyrir neðan)';
$labels['layoutlistdesc'] = 'Listi (engin forskoðun á pósti)';
$labels['folderactions'] = 'Möppuaðgerðir...';
$labels['compact'] = 'Pakka';
$labels['empty'] = 'Tæma';
$labels['importmessages'] = 'Flytja inn skilaboð';
$labels['mailimportdesc'] = 'Þú getur sent inn póst með því að nota skrár með <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> eða <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> sniði.';
$labels['mailimportzip'] = 'Hægt er að þjappa mörgum skrám í ZIP-safnskrár.';
$labels['quota'] = 'Gagnamagn';
$labels['unknown'] = 'óþekkt';
$labels['unlimited'] = 'ótakmarkað';
$labels['quotatype'] = 'Tegund kvóta';
$labels['quotatotal'] = 'Takmarkað';
$labels['quotaused'] = 'Notað';
$labels['quotastorage'] = 'Diskpláss';
$labels['quotamessage'] = 'Fjöldi skilaboða';
$labels['shortheaderdate'] = 'Þann $date';
$labels['shortheaderto'] = 'Til $from þann $date';
$labels['shortheaderfrom'] = 'Frá $from þann $date';
$labels['quicksearch'] = 'Flýtileit';
$labels['searchplaceholder'] = 'Leita...';
$labels['resetsearch'] = 'Tæma leit';
$labels['searchmod'] = 'Leitarskilyrði';
$labels['msgtext'] = 'Öll skilaboðin';
$labels['body'] = 'Meginmál';
$labels['type'] = 'Tegund';
$labels['namex'] = 'Heiti';
$labels['searchscope'] = 'Umfang';
$labels['currentfolder'] = 'Núverandi mappa';
$labels['subfolders'] = 'Þessi og undirmöppur';
$labels['allfolders'] = 'Allar möppur';
$labels['searchinterval-1W'] = 'eldri en vikugömul';
$labels['searchinterval-1M'] = 'eldri en mánaðargömul';
$labels['searchinterval-1Y'] = 'eldri en ársgömul';
$labels['searchinterval1W'] = 'yngri en vikugömul';
$labels['searchinterval1M'] = 'yngri en mánaðargömul';
$labels['searchinterval1Y'] = 'yngri en ársgömul';
$labels['openinextwin'] = 'Opna í nýjum glugga';
$labels['emlsave'] = 'Sækja (.eml)';
$labels['changeformattext'] = 'Birta sem hreinan texta';
$labels['changeformathtml'] = 'Birta á HTML-sniði';
$labels['editasnew'] = 'Breyta sem nýju';
$labels['send'] = 'Senda';
$labels['sendmessage'] = 'Senda skilaboðin núna';
$labels['savemessage'] = 'Vista drög';
$labels['addattachment'] = 'Hengja við';
$labels['charset'] = 'Stafatafla';
$labels['editortype'] = 'Gerð ritils';
$labels['returnreceipt'] = 'Kvittun við lestur';
$labels['dsn'] = 'Afhendingarstaða';
$labels['keepformatting'] = 'Halda sniðum';
$labels['mailreplyintro'] = 'Þann $date, skrifaði $sender:';
$labels['originalmessage'] = 'Upprunaleg skilaboð';
$labels['selectimage'] = 'Veldu mynd';
$labels['addimage'] = 'Bæta við mynd';
$labels['selectmedia'] = 'Veldu myndskeið';
$labels['addmedia'] = 'Bæta við myndskeiði';
$labels['encrypt'] = 'Dulrita';
$labels['encryptmessage'] = 'Dulrita skilaboð';
$labels['encryptmessagemailvelope'] = 'Dulrita skilaboð með Mailvelope';
$labels['importpubkeys'] = 'Flytja inn dreifilykla';
$labels['encryptedsendialog'] = 'Sendi dulrituð skilaboð';
$labels['encryptandsign'] = 'Dulrita og undirrita';
$labels['keyid'] = 'Auðkenni lykils';
$labels['keylength'] = 'Bitar';
$labels['keyexpired'] = 'Útrunninn';
$labels['keyrevoked'] = 'Afturkallaður';
$labels['bccinstead'] = 'Nota BCC';
$labels['addheader'] = 'Bæta við viðtakanda (haus)';
$labels['insert'] = 'Setja inn';
$labels['insertcontact'] = 'Setja inn tengiliði';
$labels['recipient'] = 'Viðtakandi';
$labels['recipientedit'] = 'Breyting á viðtakanda';
$labels['editidents'] = 'Breyta persónuauðkennum';
$labels['spellcheck'] = 'Stafsetning';
$labels['checkspelling'] = 'Athuga stafsetningu';
$labels['resumeediting'] = 'Aftur í ritham';
$labels['revertto'] = 'Hverfa aftur til';
$labels['restore'] = 'Endurheimta';
$labels['restoremessage'] = 'Endurheimta skilaboð?';
$labels['ignore'] = 'Hunsa';
$labels['responses'] = 'Svör';
$labels['insertresponse'] = 'Setja inn svar';
$labels['manageresponses'] = 'Sýsla með svör';
$labels['newresponse'] = 'Búa til nýtt svar';
$labels['addresponse'] = 'Bæta við svari';
$labels['editresponse'] = 'Breyta svari';
$labels['editresponses'] = 'Breyta svörum';
$labels['responsename'] = 'Nafn';
$labels['responsetext'] = 'Texti svars';
$labels['attach'] = 'Viðhengi';
$labels['attachments'] = 'Viðhengi';
$labels['upload'] = 'Hlaða upp';
$labels['uploadprogress'] = '$percent ($current af $total)';
$labels['close'] = 'Loka';
$labels['messageoptions'] = 'Valkostir skilaboða...';
$labels['togglecomposeoptions'] = 'Víxla valkostum samningar af/á';
$labels['attachmentrename'] = 'Endurnefna viðhengi';
$labels['low'] = 'Lágt';
$labels['lowest'] = 'Lægst';
$labels['normal'] = 'Venjulegt';
$labels['high'] = 'Hátt';
$labels['highest'] = 'Hæst';
$labels['nosubject'] = '(án titils)';
$labels['showimages'] = 'Birta myndir';
$labels['allow'] = 'Leyfa';
$labels['alwaysshow'] = 'Alltaf birta myndir frá $sender';
$labels['alwaysallow'] = 'Alltaf leyfa frá $sender';
$labels['isdraft'] = 'Þetta eru drög að skilaboðum.';
$labels['andnmore'] = '$nr í viðbót...';
$labels['details'] = 'Nánar';
$labels['summary'] = 'Samantekt';
$labels['headers'] = 'Hausar';
$labels['allheaders'] = 'Allir hausar...';
$labels['togglemoreheaders'] = 'Birta fleiri skilaboðahausa';
$labels['togglefullheaders'] = 'Víxla hráum skilaboðahausum af/á';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Hreinn texti';
$labels['savesentmessagein'] = 'Vista send skilaboð í';
$labels['dontsave'] = 'ekki vista';
$labels['maxuploadsize'] = 'Leyfileg hámarksstærð skjals er $size';
$labels['addcc'] = 'Bæta við Cc';
$labels['addbcc'] = 'Bæta við Bcc';
$labels['addreplyto'] = 'Bæta við Reply-To';
$labels['addfollowupto'] = 'Nýtt svar við';
$labels['sendreceipt'] = 'Senda leskvittun?';
$labels['mdnrequest'] = 'Sendandi þessara skilaboða hefur óskað þess að þú látir vita að þú hafir lesið skilaboðin. Viltu láta hann vita?';
$labels['receiptread'] = 'Kvittun (lesa)';
$labels['yourmessage'] = 'Þetta er kvittun fyrir skilaboðin þín';
$labels['receiptnote'] = 'ATH: Þessi kvittun segir aðeins til um að skilaboðin komu upp á skjánum hjá viðtakanda. Það er engin sönnun um að hann hafi lesið þau eða skilið efni þeirra.';
$labels['sendalwaysto'] = 'Alltaf senda til $email';
$labels['zoomin'] = 'Renna að';
$labels['zoomout'] = 'Renna frá';
$labels['rotate'] = 'Snúa';
$labels['increaseimage'] = 'Auka stærð myndar';
$labels['decreaseimage'] = 'Minnka stærð myndar';
$labels['rotateimage'] = 'Snúa mynd';
$labels['showtools'] = 'Birta myndaverkfæri';
$labels['hidetools'] = 'Fela myndaverkfæri';
$labels['name'] = 'Skjánafn';
$labels['firstname'] = 'Eiginnafn';
$labels['surname'] = 'Eftirnafn';
$labels['middlename'] = 'Millinafn';
$labels['nameprefix'] = 'Forskeyti';
$labels['namesuffix'] = 'Viðskeyti';
$labels['nickname'] = 'Stuttnefni';
$labels['jobtitle'] = 'Starfstitill';
$labels['department'] = 'Deild';
$labels['gender'] = 'Kyn';
$labels['maidenname'] = 'Ættarnafn móður';
$labels['email'] = 'Netfang';
$labels['phone'] = 'Sími';
$labels['address'] = 'Heimilisfang';
$labels['street'] = 'Götuheiti';
$labels['locality'] = 'Staður';
$labels['zipcode'] = 'Póstnúmer';
$labels['region'] = 'Ríki/Fylki';
$labels['country'] = 'Land';
$labels['birthday'] = 'Afmælisdagur';
$labels['anniversary'] = 'Afmæli';
$labels['website'] = 'Vefur';
$labels['instantmessenger'] = 'IM-spjall';
$labels['notes'] = 'Glósur';
$labels['male'] = 'karlkyns';
$labels['female'] = 'kvenkyns';
$labels['manager'] = 'Stjórnandi';
$labels['assistant'] = 'Aðstoðarmaður';
$labels['spouse'] = 'Maki';
$labels['allfields'] = 'Öll svæði';
$labels['search'] = 'Leit';
$labels['searchresult'] = 'Leitarniðurstöður';
$labels['advsearch'] = 'Ítarleg leit';
$labels['advanced'] = 'Nánar';
$labels['other'] = 'Annað';
$labels['printcontact'] = 'Prenta tengilið';
$labels['qrcode'] = 'QR-kóði';
$labels['typehome'] = 'Heimasími';
$labels['typework'] = 'Vinnusími';
$labels['typeother'] = 'Annað';
$labels['typemobile'] = 'Farsími';
$labels['typemain'] = 'Aðalstillingar';
$labels['typehomefax'] = 'Heimafax';
$labels['typeworkfax'] = 'Vinnufax';
$labels['typecar'] = 'Bílsími';
$labels['typepager'] = 'Friðþjófur';
$labels['typevideo'] = 'Myndband';
$labels['typeassistant'] = 'Aðstoðarmaður';
$labels['typehomepage'] = 'Heimasíða';
$labels['typeblog'] = 'Blogg';
$labels['typeprofile'] = 'Mannlýsing';
$labels['addfield'] = 'Bæta við svæði...';
$labels['addcontact'] = 'Bæta við tengilið';
$labels['editcontact'] = 'Breyta tengilið';
$labels['contacts'] = 'Tengiliðir';
$labels['contactproperties'] = 'Eiginleikar tengiliðar';
$labels['contactnameandorg'] = 'Nafn og fyrirtæki/stofnun';
$labels['personalinfo'] = 'Persónulegar upplýsingar';
$labels['personal'] = 'Einka';
$labels['contactphoto'] = 'Mynd af tengilið';
$labels['edit'] = 'Breyta';
$labels['cancel'] = 'Hætta við';
$labels['save'] = 'Vista';
$labels['delete'] = 'Eyða';
$labels['discard'] = 'Henda';
$labels['continue'] = 'Halda áfram';
$labels['ok'] = 'Í lagi';
$labels['rename'] = 'Endurnefna';
$labels['addphoto'] = 'Bæta við';
$labels['replacephoto'] = 'Skipta út';
$labels['uploadphoto'] = 'Senda inn mynd';
$labels['choosefile'] = 'Veldu skrá...';
$labels['choosefiles'] = 'Veldu skrár...';
$labels['browse'] = 'Flakka';
$labels['newcontact'] = 'Búa til nýjan tengilið';
$labels['deletecontact'] = 'Eyða völdum tengiliðum';
$labels['composeto'] = 'Skrifa tölvupóst til';
$labels['contactsfromto'] = 'Tengiliðir $from til $to af $count';
$labels['print'] = 'Prenta';
$labels['export'] = 'Flytja út';
$labels['exportall'] = 'Flytja allt út';
$labels['exportsel'] = 'Flytja út valið';
$labels['exportvcards'] = 'Flytja út nafnspjöld á vCard formi';
$labels['newgroup'] = 'Búa til nýjan hóp';
$labels['addgroup'] = 'Bæta við hópi';
$labels['grouprename'] = 'Breyta nafni hóps';
$labels['groupdelete'] = 'Fjarlægja hóp';
$labels['groupassign'] = 'Úthluta í hóp...';
$labels['groupremove'] = 'Fjarlægja úr hópi';
$labels['groupremoveselected'] = 'Fjarlægja valda tengiliði úr hópi';
$labels['uponelevel'] = 'Upp um eitt stig';
$labels['previouspage'] = 'Birta fyrri síðu';
$labels['firstpage'] = 'Birta fyrstu síðu';
$labels['nextpage'] = 'Birta næstu síðu';
$labels['lastpage'] = 'Birta síðustu síðu';
$labels['group'] = 'Hópur';
$labels['groups'] = 'Hópar';
$labels['listgroup'] = 'Telja upp meðlimi hóps';
$labels['personaladrbook'] = 'Persónuleg heimilisföng';
$labels['searchsave'] = 'Vista leit';
$labels['searchdelete'] = 'Eyða leit';
$labels['import'] = 'Flytja inn';
$labels['importcontacts'] = 'Flytja inn nafnspjöld';
$labels['importfromfile'] = 'Flytja inn úr skrá';
$labels['importtarget'] = 'Bæta tengiliðum í';
$labels['importreplace'] = 'Skipta út allri netfangaskránni';
$labels['importgroups'] = 'Flytja inn verkefni hóps';
$labels['importgroupsall'] = 'Allt (búa til hópa ef þess þarf)';
$labels['importgroupsexisting'] = 'Aðeins fyrirliggjandi hópar';
$labels['importdesc'] = 'Þú getur sent inn tengiliði úr fyrirliggjandi nafnaskrá.<br/>Núna er stuðningur við innflutning vistfanga úr <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> eða CSV (kommu-aðgreind) gagnasniðum.';
$labels['importmapdesc'] = 'Staðfestu að upplýsingarnar hér fyrir neðan um vensl gagnasviða séu réttar áður en haldið er áfram með innflutning á CSV-sniði (kommu-aðgreint).';
$labels['fieldnotmapped'] = 'Gagnasvið ekki venslað (ekki flytja inn)';
$labels['skipheader'] = 'Ekki flytja inn fyrstu línuna (fyrirsagnir)';
$labels['done'] = 'Búið';
$labels['settingsfor'] = 'Stillingar fyrir';
$labels['about'] = 'Um forritið';
$labels['preferences'] = 'Stillingar';
$labels['userpreferences'] = 'Notendastillingar';
$labels['editpreferences'] = 'Breyta notendastillingum';
$labels['identities'] = 'Auðkenni';
$labels['manageidentities'] = 'Sýsla með auðkenni';
$labels['newidentity'] = 'Búa til nýtt auðkenni';
$labels['addidentity'] = 'Bæta við auðkenni';
$labels['editidentity'] = 'Breyta auðkenni';
$labels['identityencryption'] = 'Dulritun';
$labels['preferhtml'] = 'Birta HTML';
$labels['defaultcharset'] = 'Sjálfgefin stafatafla';
$labels['htmlmessage'] = 'HTML-skilaboð';
$labels['messagepart'] = 'Partur';
$labels['digitalsig'] = 'Stafræn undirritun';
$labels['dateformat'] = 'Snið dagsetningar';
$labels['timeformat'] = 'Tímasnið';
$labels['prettydate'] = 'Fallegar dagsetningar';
$labels['setdefault'] = 'Gera sjálfgilt';
$labels['autodetect'] = 'Sjálfvirkt';
$labels['language'] = 'Tungumál';
$labels['timezone'] = 'Tímabelti';
$labels['pagesize'] = 'Línur á síðu';
$labels['signature'] = 'Undirskrift';
$labels['dstactive'] = 'Sumar-/vetratími';
$labels['showinextwin'] = 'Opna skilaboð í nýjum glugga';
$labels['composeextwin'] = 'Semja í nýjum glugga';
$labels['htmleditor'] = 'Skrifa HTML-skilaboð';
$labels['htmlonreply'] = 'sem svar við HTML-skilaboðum';
$labels['htmlonreplyandforward'] = 'við áframsendingu eða svar við HTML-skilaboðum';
$labels['htmlsignature'] = 'HTML-undirskrift';
$labels['showemail'] = 'Birta tölvupóstföng með skjánafni';
$labels['previewpane'] = 'Birta forskoðunarglugga';
$labels['skin'] = 'Skinn á viðmóti';
$labels['logoutclear'] = 'Tæma rusl við útskráningu';
$labels['logoutcompact'] = 'Þjappa innhólf við útskráningu';
$labels['uisettings'] = 'Notandaviðmót';
$labels['serversettings'] = 'Stillingar þjóns';
$labels['mailboxview'] = 'Útlit pósthólfs';
$labels['mdnrequests'] = 'Við beiðni um kvittun skilaboða';
$labels['askuser'] = 'spyrja notanda';
$labels['autosend'] = 'senda kvittun';
$labels['autosendknown'] = 'senda kvittun til tengiliða minna, annars spyrja mig';
$labels['autosendknownignore'] = 'senda kvittun til tengiliða minna, annars hunsa';
$labels['autosendtrusted'] = 'senda kvittun til treystra tengiliða, annars spyrja mig';
$labels['autosendtrustedignore'] = 'senda kvittun til treystra tengiliða, annars hunsa';
$labels['ignorerequest'] = 'hunsa beiðni';
$labels['readwhendeleted'] = 'Merkja skilaboðin sem lesin þegar þeim er hent';
$labels['flagfordeletion'] = 'Merkja skilaboð til eyðingar í stað þess að eyða þeim';
$labels['skipdeleted'] = 'Ekki birta eydd skilaboð';
$labels['deletealways'] = 'Ef ekki er hægt að setja skilaboð í ruslafötuna, henda þeim';
$labels['deletejunk'] = 'Eyða skilaboðum beint úr ruslpóstmöppu';
$labels['showremoteimages'] = 'Birta fjartengdar innbyggðar myndir';
$labels['allowremoteresources'] = 'Leyfa fjartengd tilföng (myndir, stílar)';
$labels['fromknownsenders'] = 'frá þekktum sendendum';
$labels['fromtrustedsenders'] = 'frá treystum sendendum';
$labels['frommycontacts'] = 'frá tengiliðunum mínum';
$labels['always'] = 'alltaf';
$labels['alwaysbutplain'] = 'alltaf, nema þegar svarað er skilaboðum með hreinum texta';
$labels['showinlineimages'] = 'Birta viðhangandi myndir fyrir neðan skilaboðin';
$labels['autosavedraft'] = 'Vista sjálfkrafa sem drög';
$labels['everynminutes'] = 'á $n mínútna fresti';
$labels['refreshinterval'] = 'Endurhlaða (athuga með ný skilaboð, o.s.frv.)';
$labels['never'] = 'aldrei';
$labels['immediately'] = 'samstundis';
$labels['messagesdisplaying'] = 'Birting skilaboða';
$labels['messagescomposition'] = 'Semja skilaboð';
$labels['mimeparamfolding'] = 'Nöfn á viðhengjum';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (annað)';
$labels['force7bit'] = 'Nota MIME kóðun fyrir 8-bita stafi';
$labels['savelocalstorage'] = "Vista (tímabundið) í staðværri geymslu vafrans";
$labels['advancedoptions'] = 'Ítarlegir valkostir';
$labels['toggleadvancedoptions'] = 'Víxla ítarlegum valkostum af/á';
$labels['focusonnewmessage'] = 'Láta vafraglugga vera virkan á nýjum skilaboðum';
$labels['checkallfolders'] = 'Athuga með ný skilaboð í öllum möppum';
$labels['displaynext'] = 'Birta næstu færslu í lista eftir að skilaboðum er eytt/færð';
$labels['defaultfont'] = 'Sjálfgefið letur HTML-skilaboða';
$labels['mainoptions'] = 'Aðalstillingar';
$labels['browseroptions'] = 'Valkostir vafra';
$labels['section'] = 'Hluti';
$labels['maintenance'] = 'Viðhald';
$labels['newmessage'] = 'Ný skilaboð';
$labels['signatureoptions'] = 'Valkostir undirskriftar';
$labels['whenreplying'] = 'Þegar svarað';
$labels['replyempty'] = 'ekki taka tilvitnun úr upprunalegum skilaboðum';
$labels['replytopposting'] = 'hefja ný skilaboð fyrir ofan tilvitnun';
$labels['replytoppostingnoindent'] = 'hefja ný skilaboð fyrir ofan tilvitnun (enginn inndráttur)';
$labels['replybottomposting'] = 'hefja ný skilaboð fyrir neðan tilvitnun';
$labels['replyremovesignature'] = 'Þegar er svarað skal fjarlægja upphaflega undirskrift úr skilaboðum';
$labels['autoaddsignature'] = 'Bæta undirskrift við sjálfkrafa';
$labels['newmessageonly'] = 'eingöngu ný skilaboð';
$labels['replyandforwardonly'] = 'svör og áframsendingar eingöngu';
$labels['insertsignature'] = 'Bæta undirskrift við';
$labels['sigbelow'] = 'Setja undirskrift fyrir neðan tilvitnuð skilaboð';
$labels['sigseparator'] = 'Þvinga staðlaðan aðgreini í undirskriftum';
$labels['automarkread'] = 'Merkja skilaboð sem lesin';
$labels['afternseconds'] = 'eftir $n sekúndur';
$labels['reqmdn'] = 'Biðja ávallt um kvittun';
$labels['reqdsn'] = 'Biðja ávallt um sendingarstöðu';
$labels['replysamefolder'] = 'Setja svarskilaboð í möppuna þar sem upphafleg skilaboð eru';
$labels['defaultabook'] = 'Sjálfgefin nafnaskrá';
$labels['autocompletesingle'] = 'Sleppa aukanetföngum í sjálfklárun';
$labels['listnamedisplay'] = 'Lista tengiliði sem';
$labels['contactformmode'] = 'Hamur tengiliðaforms';
$labels['privatemode'] = 'Einka (Heima)';
$labels['businessmode'] = 'Vinna';
$labels['collectedaddresses'] = 'Söfnuð póstföng';
$labels['collectedrecipients'] = 'Safnaðir viðtakendur';
$labels['collectedrecipientsopt'] = 'Geyma viðtakendur útsends pósts í';
$labels['collectedsendersopt'] = 'Geyma treysta sendendur í';
$labels['trustedsenders'] = 'Treystir sendendur';
$labels['spellcheckbeforesend'] = 'Athuga stafsetningu áður en skilaboð eru send';
$labels['spellcheckoptions'] = 'Stafsetningarvalkostir';
$labels['spellcheckignoresyms'] = 'Hunsa orð með táknum';
$labels['spellcheckignorenums'] = 'Hunsa orð með tölum';
$labels['spellcheckignorecaps'] = 'Hunsa orð sem eru í hástöfum';
$labels['addtodict'] = 'Bæta við orðalista';
$labels['mailtoprotohandler'] = 'Skrá fyrir meðhöndlun mailto: links samskiptamáta';
$labels['standardwindows'] = 'Meðhöndla sprettglugga sem venjulega glugga';
$labels['forwardmode'] = 'Áframsending skilaboða';
$labels['inline'] = 'innfellt';
$labels['asattachment'] = 'sem viðhengi';
$labels['replyallmode'] = 'Sjálfgefin aðgerð [Svara öllum] hnappsins';
$labels['replyalldefault'] = 'svara öllum';
$labels['replyalllist'] = 'einungis svara póstlista (ef hann finnst)';
$labels['allmessages'] = 'öll skilaboð';
$labels['olderxdays'] = 'eldri en $x daga';
$labels['folder'] = 'Mappa';
$labels['folders'] = 'Möppur';
$labels['foldername'] = 'Nafn möppu';
$labels['subscribed'] = 'Valin';
$labels['messagecount'] = 'Skilaboð';
$labels['create'] = 'Búa til';
$labels['createfolder'] = 'Búa til nýja möppu';
$labels['managefolders'] = 'Sýsla með möppur';
$labels['specialfolders'] = 'Sérstakar möppur';
$labels['properties'] = 'Eiginleikar';
$labels['folderproperties'] = 'Eiginleikar möppu';
$labels['parentfolder'] = 'Yfirmappa';
$labels['location'] = 'Staðsetning';
$labels['info'] = 'Upplýsingar';
$labels['getfoldersize'] = 'Smelltu til að sjá stærð möppu';
$labels['changesubscription'] = 'Smelltu til að breyta áskrift';
$labels['foldertype'] = 'Möpputegund';
$labels['personalfolder'] = 'Einkamappa';
$labels['otherfolder'] = 'Möppur annara notenda';
$labels['sharedfolder'] = 'Opinber mappa';
$labels['findfolders'] = 'Finna möppur';
$labels['findcontacts'] = 'Finna tengiliði';
$labels['findmail'] = 'Finna póstskilaboð';
$labels['namespace.personal'] = 'Einka';
$labels['namespace.other'] = 'Annara notenda';
$labels['namespace.shared'] = 'Sameiginlegar';
$labels['dualuselabel'] = 'Getur aðeins innihaldið';
$labels['dualusemail'] = 'skilaboð';
$labels['dualusefolder'] = 'möppur';
$labels['generate'] = 'Útbúa';
$labels['encryptioncreatekey'] = 'Búa til nýtt lyklapar';
$labels['openmailvelopesettings'] = 'Opna stillingar Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Þú ert með $nr samsvarandi einkalykla sem geymdir eru í Mailvelope lyklageymslunni þinni:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Auðkenni þessa sendanda er ekki ennþá með PGP-einkalykil geymdan í Mailvelope-viðbótinni. Mydirðu vilja útbúa einn slíkann til að virkja dulritun skilaboða?';
$labels['encryption'] = 'Dulritun';
$labels['mailvelopeoptions'] = 'Mailvelope-valkostir';
$labels['mailvelopemainkeyring'] = 'Nota aðallyklakippu Mailvelope';
$labels['mailvelopenotfound'] = 'Mailvelope-viðbótin er ekki virk/uppsett í vafranum þínum.';
$labels['sortby'] = 'Raða eftir';
$labels['sortasc'] = 'Raða vaxandi';
$labels['sortdesc'] = 'Raða minnkandi';
$labels['undo'] = 'Taka til baka';
$labels['installedplugins'] = 'Uppsettar viðbætur';
$labels['plugin'] = 'Viðbætur';
$labels['version'] = 'Útgáfa';
$labels['source'] = 'Uppruni';
$labels['destination'] = 'Áfangastaður';
$labels['license'] = 'Notkunarleyfi';
$labels['support'] = 'Fá aðstoð';
$labels['savedsearches'] = 'Vistaðar leitir';
$labels['dateformatY'] = 'ÁÁÁÁ';
$labels['dateformaty'] = 'ÁÁ';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Enska';
$labels['westerneuropean'] = 'Vesturevrópskt';
$labels['easterneuropean'] = 'Austurevrópskt';
$labels['southeasterneuropean'] = 'Suðausturevrópskt';
$labels['baltic'] = 'Eystrasalts';
$labels['cyrillic'] = 'Kýrílískt';
$labels['arabic'] = 'Arabískt';
$labels['greek'] = 'Grískt';
$labels['hebrew'] = 'Hebreskt';
$labels['turkish'] = 'Tyrkneskt';
$labels['nordic'] = 'Norrænt';
$labels['thai'] = 'Tælenskt';
$labels['celtic'] = 'Keltneskt';
$labels['vietnamese'] = 'Víetnamskt';
$labels['japanese'] = 'Japanskt';
$labels['korean'] = 'Kóreskt';
$labels['chinese'] = 'Kínverskt';
$labels['arialabeltopnav'] = 'Gluggastýring';
$labels['arialabeltasknav'] = 'Verkefni forrits';
$labels['arialabeltoolbar'] = 'Verkfærastika forrits';
$labels['arialabellistnav'] = 'Rötun um lista';
$labels['arialabelactivetask'] = 'Virkt verkefni';
$labels['arialabelmessagessearchfilter'] = 'Sía fyrir upptalningu tölvupósta';
$labels['arialabelmailsearchform'] = 'Leitargluggi fyrir tölvupósta';
$labels['arialabelcontactsearchform'] = 'Leitargluggi fyrir tengiliði';
$labels['arialabelmailquicksearchbox'] = 'Leitarinntak fyrir tölvupósta';
$labels['arialabelquicksearchbox'] = 'Leitarinntak';
$labels['arialabelfoldersearchfilter'] = 'Sía fyrir upptalningu á möppum';
$labels['arialabelfoldersearchform'] = 'Leitargluggi fyrir möppur';
$labels['arialabelfolderlist'] = 'Val á póstmöppum';
$labels['arialabelmessagelist'] = 'Upptalning á tölvupóstum';
$labels['arialabelmailpreviewframe'] = 'Forskoðun skilaboða';
$labels['arialabelmailboxmenu'] = 'Valmynd möppuaðgerða';
$labels['arialabellistselectmenu'] = 'Valmynd vallista';
$labels['arialabelthreadselectmenu'] = 'Valmynd fyrir upptalningu skilaboðaþráða';
$labels['arialabelmessagelistoptions'] = 'Birting póstskilaboða og valkostir við röðun';
$labels['arialabelmailimportdialog'] = 'Innflutningsgluggi skilaboða';
$labels['arialabelmessagenav'] = 'Rötun um skilaboð';
$labels['arialabelmessagebody'] = 'Meginmál skilaboða';
$labels['arialabelmessageactions'] = 'Aðgerðir skilaboða';
$labels['arialabelcontactquicksearch'] = 'Leitargluggi fyrir tengiliði';
$labels['arialabelcontactsearchbox'] = 'Leitarinntak fyrir tengiliði';
$labels['arialabelmessageheaders'] = 'Skilaboðahausar';
$labels['arialabelforwardingoptions'] = 'Valkostir áframsendinga';
$labels['arialabelreplyalloptions'] = 'Valkostir við að svara-öllum';
$labels['arialabelmoremessageactions'] = 'Fleiri aðgerðir skilaboða';
$labels['arialabelmorecontactactions'] = 'Fleiri aðgerðir tengiliða';
$labels['arialabelmarkmessagesas'] = 'Merka valin skilaboð sem...';
$labels['arialabelcomposeoptions'] = 'Valkostir við samningu skilaboða';
$labels['arialabelresponsesmenu'] = 'Valmynd fyrir stöðluð svör';
$labels['arialabelattachmentuploadform'] = 'Gluggi fyrir innsendingu viðhengja';
$labels['arialabelattachmentmenu'] = 'Valkostir viðhengja';
$labels['arialabelmailtomenu'] = 'Valkostir tölvupóstfanga';
$labels['arialabelattachmentpreview'] = 'Forskoðun viðhengis';
$labels['ariasummarycomposecontacts'] = 'Listi yfir tengiliði og hópa sem velja má sem viðtakendur';
$labels['arialabelcontactexportoptions'] = 'Valkostir við útflutning tengiliða';
$labels['arialabelabookgroupoptions'] = 'Valkostir nafnaskrár/hópa';
$labels['arialabelpreferencesform'] = 'Kjörstillingagluggi';
$labels['arialabelidentityeditfrom'] = 'Gluggi til stillinga auðkenna';
$labels['arialabelresponseeditfrom'] = 'Gluggi fyrir breytingar á svari';
$labels['arialabelsearchterms'] = 'Leitarstrengir';
$labels['arialabeldropactionmenu'] = 'Aðgerðavalmynd fyrir draga-sleppa';
$labels['arialabelheadersmenu'] = 'Valmynd til að bæta við viðtakanda (haus)';
$labels['arialabelimagetools'] = 'Myndaverkfæri';
$labels['helplistnavigation'] = 'Listi yfir rötun um skilaboð með lyklaborði';
$labels['helplistkeyboardnavigation'] = "Örvar upp/niður: Flytja virkni/val um röð.
Bil: Velja virka röð.
Shift + upp/niður: Velja röð til viðbótar fyrir ofan/neðan.
Ctrl + Bil: Bæta virkri röð við val/fjarlægja úr vali.";
$labels['helplistkeyboardnavmessages'] = "Örvar hægri/vinstri: Þenja/fella saman skilaboðaþræði (einungis í samskiptaþráðaham).
Enter: Opna valin/virk skilaboð.
Del/Eyða: Færa valin skilaboð í ruslið.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Opna valinn/virkan tengilið.";
