<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'عوامل التصفية';
$labels['filtername'] = 'إسم عامل التصفية';
$labels['newfilter'] = 'عامل تصفية جديد';
$labels['filteradd'] = 'إضافة عامل تصفية';
$labels['filterdel'] = 'حذف عامل تصفية';
$labels['rules'] = 'القواعد';
$labels['actions'] = 'الإجراءات';
$labels['scope'] = 'المجال';
$labels['moveup'] = 'النقل إلى أعلى';
$labels['movedown'] = 'النقل إلى أسفل';
$labels['filterany'] = 'كافة الرسائل';
$labels['filtercontains'] = 'يحتوي على';
$labels['filternotcontains'] = 'لا يحتوي على';
$labels['addrule'] = 'إضافة قاعدة';
$labels['delrule'] = 'حذف قاعدة';
$labels['messagemoveto'] = 'نقل الرسالة إلى';
$labels['messageredirect'] = 'تحويل الرسالة إلى';
$labels['messagecopyto'] = 'نسخ الرسالة إلى';
$labels['messagedelete'] = 'حذف الرسالة';
$labels['add'] = 'إضافة';
$labels['del'] = 'حذف';
$labels['sender'] = 'المُرسِل';
$labels['recipient'] = 'المتلقَّي';
$labels['vacationaddr'] = 'عناوين البريد الإلكترونية الخاصة بي :';
$labels['vacationsubject'] = 'موضوع الرسالة :';
$labels['days'] = 'أيام';
$labels['seconds'] = 'ثواني';
$labels['enable'] = 'تعطيل/تشغيل';
$labels['flagdeleted'] = 'محذوف';
$labels['flagflagged'] = 'موسوم';
$labels['varlength'] = 'الطول';
$labels['notifyimportance'] = 'الأهمية :';
$labels['notifymethodmailto'] = 'البريد الإلكتروني';
$labels['notifymethodtel'] = 'الهاتف';
$labels['notifymethodsms'] = 'رسالة نصية قصيرة';
$labels['nextstep'] = 'الخطوة التالية';
$labels['string'] = 'السلسلة';
$labels['currdate'] = 'التاريخ الحالي';
$labels['datetest'] = 'التاريخ';
$labels['year'] = 'سنة';
$labels['month'] = 'شهر';
$labels['day'] = 'يوم';
$labels['hour'] = 'ساعة';
$labels['minute'] = 'دقيقة';
$labels['second'] = 'ثانية';
$labels['time'] = 'الوقت (hh:mm:ss)';
$labels['iso8601'] = 'التاريخ (ISO8601)';
$labels['std11'] = 'التاريخ (RFC2822)';
$labels['advancedopts'] = 'خيارات متقدّمة';
$labels['body'] = 'هيكل الرسالة';
$labels['address'] = 'العنوان';
$labels['domain'] = 'النطاق';
$labels['detail'] = 'التفاصيل';
$labels['default'] = 'إفتراضي';
$labels['vacation.advanced'] = 'الإعدادات المتقدمة';
$labels['vacation.subject'] = 'الموضوع';
$labels['vacation.body'] = 'هيكل الرسالة';
$labels['vacation.saving'] = 'جارٍ حفظ البيانات...';
$labels['forward.status'] = 'الحالة:';
$labels['forward.saving'] = 'جارٍ حفظ البيانات...';
