<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Archivar';
$labels['buttontitle'] = 'Archivar iste message';
$labels['archived'] = 'Archivate con successo';
$labels['archivedreload'] = 'Archivate con successo. Recarga le pagina pro vider le nove dossieres de archivo.';
$labels['archiveerror'] = 'Alcun messages non poteva esser archivate';
$labels['archivefolder'] = 'Archivo';
$labels['settingstitle'] = 'Archivo';
$labels['archivetype'] = 'Divider le archivo per';
$labels['archivetypeyear'] = 'Anno (p.ex. Archivo/2012)';
$labels['archivetypemonth'] = 'Mense (p.ex. Archivo/2012/06)';
$labels['archivetypetbmonth'] = 'Mense - compatibile con Thunderbird (p.ex. Archivo/2012/2012-06)';
$labels['archivetypefolder'] = 'Dossier original';
$labels['archivetypesender'] = 'E-mail del expeditor';
$labels['unkownsender'] = 'incognite';
$labels['readonarchive'] = 'Marcar le message como legite in le archivo';
