<?php

/**
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/roundcube/roundcube-webmail/plugin-enigma/
*/

$labels['encryption'] = 'التشفير';
$labels['enigmakeys'] = 'مفاتيح PGP';
$labels['keyname'] = 'الإسم';
$labels['keytype'] = 'نوع المفتاح';
$labels['fingerprint'] = 'البصمة';
$labels['typeencrypt'] = 'تعمية';
$labels['typeauth'] = 'المصادقة';
$labels['expiresnever'] = 'أبداً';
$labels['unknown'] = 'مجهول';
$labels['createkeys'] = 'إنشاء زوج مِن المفاتيح';
$labels['keychpass'] = 'تغيير كلمة المرور';
$labels['newkeyident'] = 'الهوية';
$labels['newkeypass'] = 'كلمة المرور';
$labels['newkeypassconfirm'] = 'تأكيد الكلمة السرية';
$labels['newkeytype'] = 'نوع المفتاح';
$labels['keygenerating'] = 'جارٍ توليد المفاتيح...';
$labels['managekeys'] = 'إدارة مفاتيح PGP';
$labels['newkeysize'] = 'حجم المفتاح';
$labels['key2048'] = '2048 bits - افتراضي';
$labels['key4096'] = '4096 bits - أكثر أمانا';
