<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Алдаа гарлаа!';
$messages['loginfailed']  = 'Нэвтрэлт амжилтгүй.';
$messages['cookiesdisabled'] = 'Таны вэб хөтөч күүкүү зөвшөөрөхгүй байна.';
$messages['sessionerror'] = 'Та нэвтрээгүй буюу эсвэл автоматаар гарсан байна.';
$messages['storageerror'] = 'Хадгалах серверт холбогдоход алдаа гарлаа.';
$messages['servererror'] = 'Серверийн алдаа!';
$messages['servererrormsg'] = 'Серверийн Алдаа: $msg';
$messages['connerror'] = 'Холболтын Алдаа (Серверт холбогдож чадсангүй)!';
$messages['dberror'] = 'Мэдээллийн баазын Алдаа!';
$messages['windowopenerror'] = 'Попап цонх зөвшөөрөгдөөгүй!';
$messages['requesttimedout'] = 'Хүсэлтийн хугацаа дууссан';
$messages['errorreadonly'] = 'Үйлдлийг хийж чадахгүй байна. Зөвхөн унших хавтас.';
$messages['errornoperm'] = 'Үйлдлийг хийж чадахгүй байна. Хандалт зөвшөөрөгдөөгүй.';
$messages['erroroverquota'] = 'Үйлдлийг хийж чадахгүй байна. Диск дүүрсэн.';
$messages['erroroverquotadelete'] = 'Диск дүүрсэн. Захиа устгахдаа SHIFT+DEL ашиглана.';
$messages['invalidrequest'] = 'Алдаатай хүсэлт! Мэдээлэл хадгалагдаагүй.';
$messages['invalidhost'] = 'Серверийн нэр буруу.';
$messages['nomessagesfound'] = 'Захианы хавтсанд захиа байхгүй байна.';
$messages['mailboxempty'] = 'Захианы хавтас хоосон байна';
$messages['nomessages'] = 'Захиа байхгүй байна';
$messages['refreshing'] = 'Шинэчилж байна...';
$messages['loading'] = 'Боловсруулж байна...';
$messages['uploading'] = 'Файлыг хуулж байна...';
$messages['uploadingmany'] = 'Файлууд хуулж байна...';
$messages['loadingdata'] = 'Мэдээллийг боловсруулж байна...';
$messages['checkingmail'] = 'Шинэ захиа шалгаж байна...';
$messages['sendingmessage'] = 'Илгээж байна...';
$messages['messagesent'] = 'Захиа амжилттай илгээгдлээ.';
$messages['savingmessage'] = 'Захиа хадгалж байна...';
$messages['messagesaved'] = 'Захиа Ноороглож хадгалагдсан';
