<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Zipdownload plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-zipdownload/
*/

$labels['downloadall'] = 'Atsisiųsti visus priedus';
$labels['download'] = 'Parsisiųsti...';
$labels['downloadmbox'] = 'Mbox formatas (.zip)';
$labels['downloadmaildir'] = 'Maildir formatas (.zip)';
$labels['downloademl'] = 'Kodas (.eml)';
$labels['sizelimiterror'] = 'Bendras pasirinktų laiškų dydis viršija ribą ($size)';
