<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Vítejte v $product';
$labels['username'] = 'Uživatel';
$labels['password'] = 'Heslo';
$labels['server'] = 'Server';
$labels['login'] = 'Přihlásit';
$labels['oauthlogin'] = 'Přihlášení přes $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Odhlásit';
$labels['mail'] = 'E-mail';
$labels['settings'] = 'Nastavení';
$labels['addressbook'] = 'Adresář';
$labels['darkmode'] = 'Tmavý režim';
$labels['lightmode'] = 'Světlý režim';
$labels['inbox'] = 'Příchozí pošta';
$labels['drafts'] = 'Rozepsané';
$labels['sent'] = 'Odeslané';
$labels['trash'] = 'Koš';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Zobrazit skutečná jména speciálních složek';
$labels['subject'] = 'Předmět';
$labels['from'] = 'Odesílatel';
$labels['sender'] = 'Odesílatel';
$labels['to'] = 'Adresát';
$labels['cc'] = 'Kopie';
$labels['bcc'] = 'Skrytá kopie';
$labels['replyto'] = 'Odpověď na';
$labels['followupto'] = 'Followup-To';
$labels['date'] = 'Datum';
$labels['size'] = 'Velikost';
$labels['priority'] = 'Priorita';
$labels['organization'] = 'Organizace';
$labels['readstatus'] = 'Přečteno';
$labels['listoptions'] = 'Seznam  možností...';
$labels['listoptionstitle'] = 'Možnosti seznamu';
$labels['mailboxlist'] = 'Složky';
$labels['messagesfromto'] = 'Zprávy $from až $to z celkem $count';
$labels['threadsfromto'] = 'Konverzace $from až $to z celkem $count';
$labels['messagenrof'] = 'Zpráva $nr z $count';
$labels['fromtoshort'] = '$from - $to z $count';
$labels['copy'] = 'Kopírovat';
$labels['move'] = 'Přesunout';
$labels['moveto'] = 'Přesunout do...';
$labels['copyto'] = 'Kopírovat do...';
$labels['download'] = 'Stáhnout';
$labels['open'] = 'Otevřít';
$labels['showattachment'] = 'Zobrazit';
$labels['showanyway'] = 'Přesto zobrazit';
$labels['filename'] = 'Jméno přílohy';
$labels['filesize'] = 'Velikost přílohy';
$labels['addtoaddressbook'] = 'Přidat do adresáře';
$labels['sun'] = 'Ne';
$labels['mon'] = 'Po';
$labels['tue'] = 'Út';
$labels['wed'] = 'St';
$labels['thu'] = 'Čt';
$labels['fri'] = 'Pá';
$labels['sat'] = 'So';
$labels['sunday'] = 'Neděle';
$labels['monday'] = 'Pondělí';
$labels['tuesday'] = 'Úterý';
$labels['wednesday'] = 'Středa';
$labels['thursday'] = 'Čtvrtek';
$labels['friday'] = 'Pátek';
$labels['saturday'] = 'Sobota';
$labels['jan'] = 'led';
$labels['feb'] = 'úno';
$labels['mar'] = 'bře';
$labels['apr'] = 'dub';
$labels['may'] = 'kvě';
$labels['jun'] = 'čvn';
$labels['jul'] = 'čvc';
$labels['aug'] = 'srp';
$labels['sep'] = 'zář';
$labels['oct'] = 'říj';
$labels['nov'] = 'lis';
$labels['dec'] = 'pro';
$labels['longjan'] = 'Leden';
$labels['longfeb'] = 'Únor';
$labels['longmar'] = 'Březen';
$labels['longapr'] = 'Duben';
$labels['longmay'] = 'Květen';
$labels['longjun'] = 'Červen';
$labels['longjul'] = 'Červenec';
$labels['longaug'] = 'Srpen';
$labels['longsep'] = 'Září';
$labels['longoct'] = 'Říjen';
$labels['longnov'] = 'Listopad';
$labels['longdec'] = 'Prosinec';
$labels['today'] = 'Dnes';
$labels['refresh'] = 'Obnovit';
$labels['checkmail'] = 'Zkontrolovat nové zprávy';
$labels['compose'] = 'Napsat';
$labels['writenewmessage'] = 'Vytvořit novou zprávu';
$labels['reply'] = 'Odpovědět';
$labels['replytomessage'] = 'Odpovědět odesílateli';
$labels['replytoallmessage'] = 'Odpovědět všem';
$labels['replyall'] = 'Odpovědět všem';
$labels['replylist'] = 'Odpovědět do e-mailové konference';
$labels['forward'] = 'Přeposlat';
$labels['forwardinline'] = 'Přeposlat v textu';
$labels['forwardattachment'] = 'Přeposlat jako přílohu';
$labels['forwardmessage'] = 'Předat zprávu';
$labels['bouncemsg'] = 'Přeposlat (bounce)';
$labels['bounce'] = 'Přeposlat';
$labels['deletemessage'] = 'Odstranit zprávu';
$labels['movemessagetotrash'] = 'Přesunout zprávu do koše';
$labels['printmessage'] = 'Vytisknout zprávu';
$labels['previousmessage'] = 'Zobrazit předchozí zprávu';
$labels['firstmessage'] = 'Zobrazit první zprávu';
$labels['nextmessage'] = 'Zobrazit další zprávu';
$labels['lastmessage'] = 'Zobrazit poslední zprávu';
$labels['backtolist'] = 'Zpět do seznamu zpráv';
$labels['viewsource'] = 'Zobrazit zdroj';
$labels['mark'] = 'Označit';
$labels['markmessages'] = 'Označ zprávy';
$labels['markread'] = 'Jako přečtené';
$labels['markunread'] = 'Jako nepřečtené';
$labels['markflagged'] = 'Jako označené';
$labels['markunflagged'] = 'Jako neoznačené';
$labels['markundeleted'] = 'Jako nesmazané';
$labels['moreactions'] = 'Další akce...';
$labels['markallread'] = 'Označit vše jako přečtené';
$labels['folders-cur'] = 'Vybrat pouze složku';
$labels['folders-sub'] = 'Vybrat složku a její podsložky';
$labels['folders-all'] = 'Všechny složky';
$labels['more'] = 'Více';
$labels['back'] = 'Zpět';
$labels['options'] = 'Možnosti';
$labels['composeoptions'] = 'Možnosti psaní';
$labels['optionsandattachments'] = 'Nastavení a přílohy';
$labels['actions'] = 'Akce';
$labels['first'] = 'První';
$labels['last'] = 'Poslední';
$labels['previous'] = 'Předchozí';
$labels['next'] = 'Následující';
$labels['select'] = 'Vybrat';
$labels['selection'] = 'Výběr';
$labels['all'] = 'Vše';
$labels['none'] = 'Nic';
$labels['currpage'] = 'Aktuální stránka';
$labels['isread'] = 'Přečtené';
$labels['unread'] = 'Nepřečtené';
$labels['flagged'] = 'Označené';
$labels['unflagged'] = 'Neoznačené';
$labels['unanswered'] = 'Nezodpovězené';
$labels['withattachment'] = 'S přílohou';
$labels['deleted'] = 'Smazané';
$labels['undeleted'] = 'Nesmazáno';
$labels['replied'] = 'Odpovězeno';
$labels['forwarded'] = 'Přeposláno';
$labels['invert'] = 'Převrátit';
$labels['filter'] = 'Filtr';
$labels['list'] = 'Seznam';
$labels['threads'] = 'Konverzace';
$labels['expand-all'] = 'Rozbalit všechny';
$labels['expand-unread'] = 'Rozbalit nepřečtené';
$labels['collapse-all'] = 'Sbalit všechny';
$labels['threaded'] = 'Spojovat do konverzací';
$labels['showunread'] = 'Zobrazit nepřečtené zprávy';
$labels['autoexpand_threads'] = 'Rozbalit konverzace';
$labels['do_expand'] = 'všechny konverzace';
$labels['expand_only_unread'] = 'pouze s nepřečtenými zprávami';
$labels['fromto'] = 'Odesílatel/Příjemce';
$labels['flag'] = 'Příznak';
$labels['attachment'] = 'Příloha';
$labels['nonesort'] = 'Nic';
$labels['sentdate'] = 'Datum odeslání';
$labels['arrival'] = 'Datum přijetí';
$labels['asc'] = 'vzestupně';
$labels['desc'] = 'sestupně';
$labels['listcolumns'] = 'Seznam sloupců';
$labels['listsorting'] = 'Třídění sloupců';
$labels['listorder'] = 'Uspořádání';
$labels['listmode'] = 'Režim zobrazení seznamu';
$labels['lmode'] = 'Podoba výpisu';
$labels['layout'] = 'Rozvržení';
$labels['layoutwidescreen'] = 'Widescreen';
$labels['layoutdesktop'] = 'Desktop';
$labels['layoutlist'] = 'Seznam';
$labels['layoutwidescreendesc'] = 'Widescreen (3 sloupce)';
$labels['layoutdesktopdesc'] = 'Desktop (seznam + náhled)';
$labels['layoutlistdesc'] = 'Seznam (bez náhledu)';
$labels['folderactions'] = 'Akce se složkou...';
$labels['compact'] = 'Zmenšit';
$labels['empty'] = 'Vyprázdnit';
$labels['importmessages'] = 'Import zpráv';
$labels['mailimportdesc'] = 'E-mail můžete nahrát pomocí souborů ve formátu <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> a <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Více souborů může být zkomprimováno do ZIP archivu.';
$labels['quota'] = 'Využití schránky';
$labels['unknown'] = 'neznámý';
$labels['unlimited'] = 'neomezený';
$labels['quotatype'] = 'Typ kvóty';
$labels['quotatotal'] = 'Limit';
$labels['quotaused'] = 'Využito';
$labels['quotastorage'] = 'Využití schránky';
$labels['quotamessage'] = 'Počet zpráv';
$labels['shortheaderdate'] = 'Dne $date';
$labels['shortheaderto'] = 'Pro $to dne $date';
$labels['shortheaderfrom'] = 'Od $from dne $date';
$labels['quicksearch'] = 'Rychlé vyhledávání';
$labels['searchplaceholder'] = 'Hledat...';
$labels['resetsearch'] = 'Zrušit vyhledávání';
$labels['searchmod'] = 'Parametry hledání';
$labels['msgtext'] = 'Celá zpráva';
$labels['body'] = 'Tělo';
$labels['type'] = 'Typ';
$labels['namex'] = 'Jméno';
$labels['searchscope'] = 'Rozsah';
$labels['currentfolder'] = 'Aktuální složka';
$labels['subfolders'] = 'Tato a podsložky';
$labels['allfolders'] = 'Všechny složky';
$labels['searchinterval-1W'] = 'starší než týden';
$labels['searchinterval-1M'] = 'starší než měsíc';
$labels['searchinterval-1Y'] = 'starší než rok';
$labels['searchinterval1W'] = 'novější než týden';
$labels['searchinterval1M'] = 'novější než měsíc';
$labels['searchinterval1Y'] = 'novější než rok';
$labels['openinextwin'] = 'Otevřít v novém okně';
$labels['emlsave'] = 'Stáhnout (.eml)';
$labels['changeformattext'] = 'Zobrazit v textovém formátu';
$labels['changeformathtml'] = 'Zobrazit v HTML formátu';
$labels['editasnew'] = 'Upravit jako novou';
$labels['send'] = 'Odeslat';
$labels['sendmessage'] = 'Odeslat zprávu nyní';
$labels['savemessage'] = 'Uložit do rozepsaných';
$labels['addattachment'] = 'Přidat přílohu';
$labels['charset'] = 'Znaková sada';
$labels['editortype'] = 'Typ editoru zpráv';
$labels['returnreceipt'] = 'Doručenka';
$labels['dsn'] = 'Stav doručení';
$labels['keepformatting'] = 'Zachovat formátování';
$labels['mailreplyintro'] = 'Dne $date, $sender napsal:';
$labels['originalmessage'] = 'Původní zpráva';
$labels['selectimage'] = 'Vybrat obrázek';
$labels['addimage'] = 'Přidat obrázek';
$labels['selectmedia'] = 'Vybrat video';
$labels['addmedia'] = 'Přidat video';
$labels['encrypt'] = 'Šifrovat';
$labels['encryptmessage'] = 'Šifrovat zprávu';
$labels['encryptmessagemailvelope'] = 'Šifrovat zprávu pomocí Mailvelope';
$labels['importpubkeys'] = 'Import veřejných klíčů';
$labels['encryptedsendialog'] = 'Odesílání šifrované zprávy';
$labels['encryptandsign'] = 'Šifrovat a podepsat';
$labels['keyid'] = 'ID klíče';
$labels['keylength'] = 'Bitů';
$labels['keyexpired'] = 'Vypršelý';
$labels['keyrevoked'] = 'Odvolaný';
$labels['bccinstead'] = 'Použít skrytou kopii';
$labels['addheader'] = 'Přidat příjemce (hlavička)';
$labels['insert'] = 'Vložit';
$labels['insertcontact'] = 'Vložit kontakty';
$labels['recipient'] = 'Příjemce';
$labels['recipientedit'] = 'Úprava příjemce';
$labels['editidents'] = 'Upravit identity';
$labels['spellcheck'] = 'Pravopis';
$labels['checkspelling'] = 'Zkontrolovat pravopis';
$labels['resumeediting'] = 'Pokračovat v úpravách';
$labels['revertto'] = 'Přejít na';
$labels['restore'] = 'Obnovit';
$labels['restoremessage'] = 'Obnovit zprávu?';
$labels['ignore'] = 'Ignorovat';
$labels['responses'] = 'Odpovědi';
$labels['insertresponse'] = 'Vložit odpověd';
$labels['manageresponses'] = 'Spravovat odpovědi';
$labels['newresponse'] = 'Vytvořit novou odpověď';
$labels['addresponse'] = 'Přidat odpověď';
$labels['editresponse'] = 'Upravit odpověď';
$labels['editresponses'] = 'Upravit odpovědi';
$labels['responsename'] = 'Název';
$labels['responsetext'] = 'Text odpovědi';
$labels['attach'] = 'Přiložit';
$labels['attachments'] = 'Přílohy';
$labels['upload'] = 'Nahrát';
$labels['uploadprogress'] = '$percent ($current z $total)';
$labels['close'] = 'Zavřít';
$labels['messageoptions'] = 'Nastavení zprávy...';
$labels['togglecomposeoptions'] = 'Přepnout možnosti kompozice';
$labels['attachmentrename'] = 'Přejmenovat přílohu';
$labels['low'] = 'Nízká';
$labels['lowest'] = 'Nejnižší';
$labels['normal'] = 'Normální';
$labels['high'] = 'Vysoká';
$labels['highest'] = 'Nejvyšší';
$labels['nosubject'] = '(bez předmětu)';
$labels['showimages'] = 'Zobrazit obrázky';
$labels['allow'] = 'Povolit';
$labels['alwaysshow'] = 'Vždy ukazovat obrázky od $sender';
$labels['alwaysallow'] = 'Vždy povolit od $sender';
$labels['isdraft'] = 'Toto je šablona zprávy.';
$labels['andnmore'] = '$nr dalších...';
$labels['details'] = 'Podrobnosti';
$labels['summary'] = 'Shrnutí';
$labels['headers'] = 'Hlavičky';
$labels['allheaders'] = 'Všechny hlavičky...';
$labels['togglemoreheaders'] = 'Zobrazit více hlaviček zprávy';
$labels['togglefullheaders'] = 'Přepnout skutečné hlavičky zprávy';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Prostý text';
$labels['savesentmessagein'] = 'Ukládat odeslané zprávy v';
$labels['dontsave'] = 'neukládat';
$labels['maxuploadsize'] = 'Maximální povolená velikost souboru je $size';
$labels['addcc'] = 'Přidat pole "Kopie"';
$labels['addbcc'] = 'Přidat pole "Skrytá kopie"';
$labels['addreplyto'] = 'Přidat pole "Odpověď"';
$labels['addfollowupto'] = 'Přidat pole "Followup-To"';
$labels['sendreceipt'] = 'Odeslat potvrzení o přečtení?';
$labels['mdnrequest'] = 'Odesílatel této zprávy si přeje být upozorněn na to, že jste zprávu obdrželi. Chcete přijetí zprávy potvrdit?';
$labels['receiptread'] = 'Potvrzení o přijetí zprávy';
$labels['yourmessage'] = 'Toto je potvrzení o přijetí Vaší zprávy';
$labels['receiptnote'] = 'Poznámka: Toto potvrzení negarantuje, že zpráva byla příjemce přečtena a že porozuměl jejímu obsahu.';
$labels['sendalwaysto'] = 'Vždy odeslat na $email';
$labels['zoomin'] = 'Přiblížit';
$labels['zoomout'] = 'Oddálit';
$labels['rotate'] = 'Otočit';
$labels['increaseimage'] = 'Zvětšit rozměr obrázku';
$labels['decreaseimage'] = 'Zmenšit rozměr obrázku';
$labels['rotateimage'] = 'Otočit obrázek';
$labels['showtools'] = 'Zobrazit nástroje pro obrázky';
$labels['hidetools'] = 'Skrýt nástroje pro obrázky';
$labels['name'] = 'Zobrazit jméno';
$labels['firstname'] = 'Jméno';
$labels['surname'] = 'Příjmení';
$labels['middlename'] = 'Druhé jméno';
$labels['nameprefix'] = 'Titul před';
$labels['namesuffix'] = 'Titul za';
$labels['nickname'] = 'Přezdívka';
$labels['jobtitle'] = 'Pracovní pozice';
$labels['department'] = 'Oddělení';
$labels['gender'] = 'Pohlaví';
$labels['maidenname'] = 'Rodné příjmení';
$labels['email'] = 'E-mail';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Adresa';
$labels['street'] = 'Ulice';
$labels['locality'] = 'Město';
$labels['zipcode'] = 'PSČ';
$labels['region'] = 'Kraj';
$labels['country'] = 'Země';
$labels['birthday'] = 'Datum narození';
$labels['anniversary'] = 'Výročí';
$labels['website'] = 'WWW';
$labels['instantmessenger'] = 'Komunikace (ICQ, messenger...)';
$labels['notes'] = 'Poznámky';
$labels['male'] = 'muž';
$labels['female'] = 'žena';
$labels['manager'] = 'Manažer';
$labels['assistant'] = 'Asistent';
$labels['spouse'] = 'Manžel/ka';
$labels['allfields'] = 'Všechny položky';
$labels['search'] = 'Hledat';
$labels['searchresult'] = 'Výsledek hledání';
$labels['advsearch'] = 'Pokročilé vyhledávání';
$labels['advanced'] = 'Pokročilé';
$labels['other'] = 'Ostatní';
$labels['printcontact'] = 'Vytisknout kontakt';
$labels['qrcode'] = 'QR kód';
$labels['typehome'] = 'Domací';
$labels['typework'] = 'Pracovní';
$labels['typeother'] = 'Ostatní';
$labels['typemobile'] = 'Mobil';
$labels['typemain'] = 'Osobní';
$labels['typehomefax'] = 'Domácí FAX';
$labels['typeworkfax'] = 'Pracovní FAX';
$labels['typecar'] = 'Automobil';
$labels['typepager'] = 'Pager';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Asistent';
$labels['typehomepage'] = 'Domácí stránka';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Přidat položku...';
$labels['addcontact'] = 'Přidání kontaktu';
$labels['editcontact'] = 'Upravit kontakt';
$labels['contacts'] = 'Kontakty';
$labels['contactproperties'] = 'Vlastnosti kontaktu';
$labels['contactnameandorg'] = 'Jméno a Organizace';
$labels['personalinfo'] = 'Osobní informace';
$labels['personal'] = 'Osobní';
$labels['contactphoto'] = 'Fotografie kontaktu';
$labels['edit'] = 'Upravit';
$labels['cancel'] = 'Konec';
$labels['save'] = 'Uložit';
$labels['delete'] = 'Smazat';
$labels['discard'] = 'Zahodit';
$labels['continue'] = 'Pokračovat';
$labels['ok'] = 'OK';
$labels['rename'] = 'Přejmenovat';
$labels['addphoto'] = 'Přidat';
$labels['replacephoto'] = 'Nahradit';
$labels['uploadphoto'] = 'Nahrát fotku';
$labels['choosefile'] = 'Vybrat soubor...';
$labels['choosefiles'] = 'Vybrat soubory...';
$labels['browse'] = 'Procházet';
$labels['newcontact'] = 'Vytvořit nový kontakt';
$labels['deletecontact'] = 'Smazat vybrané kontakty';
$labels['composeto'] = 'Poslat e-mail';
$labels['contactsfromto'] = 'Kontakty $from až $to z celkem $count';
$labels['print'] = 'Tisk';
$labels['export'] = 'Export';
$labels['exportall'] = 'Export všech';
$labels['exportsel'] = 'Export vybraných';
$labels['exportvcards'] = 'Exportovat kontakty ve formátu vCard';
$labels['newgroup'] = 'Vytvořit novou skupinu';
$labels['addgroup'] = 'Přidat skupinu';
$labels['grouprename'] = 'Přejmenovat skupinu';
$labels['groupdelete'] = 'Smazat skupinu';
$labels['groupassign'] = 'Přiřadit do skupiny...';
$labels['groupremove'] = 'Odebrat ze skupiny';
$labels['groupremoveselected'] = 'Odstranit označené kontakty ze skupiny';
$labels['uponelevel'] = 'O jednu úroveň výš';
$labels['previouspage'] = 'Předchozí';
$labels['firstpage'] = 'Zobrazit první zprávy';
$labels['nextpage'] = 'Další';
$labels['lastpage'] = 'Zobrazit poslední zprávy';
$labels['group'] = 'Skupina';
$labels['groups'] = 'Skupiny';
$labels['listgroup'] = ' Seznam členů skupiny';
$labels['personaladrbook'] = 'Osobní kontakty';
$labels['searchsave'] = 'Uložit hledání';
$labels['searchdelete'] = 'Smazat hledání';
$labels['import'] = 'Import';
$labels['importcontacts'] = 'Importovat kontakty';
$labels['importfromfile'] = 'Importovat ze souboru';
$labels['importtarget'] = 'Přidat kontakty k';
$labels['importreplace'] = 'Nahradit celý seznam kontaktů';
$labels['importgroups'] = 'Importovat přiřazení do skupin';
$labels['importgroupsall'] = 'Vše (vytvořit skupiny v případě potřeby)';
$labels['importgroupsexisting'] = 'Pouze pro existující skupiny';
$labels['importdesc'] = 'Kontakty můžete nahrát z existujícího adresáře.<br/>V současnosti je podporováno načtení adres z dat ve formátu <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> a CSV (odděleno čárkou).';
$labels['importmapdesc'] = 'Potvrďte níže zobrazené přiřazení položek před importováním dat z CSV (odděleno čárkou) souboru.';
$labels['fieldnotmapped'] = 'Položka není přiřazena (nebude použita)';
$labels['skipheader'] = 'První řádku neimportovat (hlavičky)';
$labels['done'] = 'Hotovo';
$labels['settingsfor'] = 'Nastavení pro';
$labels['about'] = 'O programu';
$labels['preferences'] = 'Vlastnosti';
$labels['userpreferences'] = 'Vlastnosti uživatele';
$labels['editpreferences'] = 'Upravit vlastnosti uživatele';
$labels['identities'] = 'Profily';
$labels['manageidentities'] = 'Správa profilů';
$labels['newidentity'] = 'Vytvořit nový profil';
$labels['addidentity'] = 'Přidat profil';
$labels['editidentity'] = 'Upravit profil';
$labels['identityencryption'] = 'Šifrování';
$labels['preferhtml'] = 'Upřednostňovat HTML zobrazení';
$labels['defaultcharset'] = 'Výchozí kódování';
$labels['htmlmessage'] = 'HTML zpráva';
$labels['messagepart'] = 'Část';
$labels['digitalsig'] = 'Digitální podpis';
$labels['dateformat'] = 'Formát data';
$labels['timeformat'] = 'Formát času';
$labels['prettydate'] = 'Hezčí datum';
$labels['setdefault'] = 'Nastavit výchozí';
$labels['autodetect'] = 'Automaticky';
$labels['language'] = 'Jazyk';
$labels['timezone'] = 'Časová zóna';
$labels['pagesize'] = 'Řádků na stránku';
$labels['signature'] = 'Podpis';
$labels['dstactive'] = 'Letní čas';
$labels['showinextwin'] = 'Otevřít zprávu v novém okně';
$labels['composeextwin'] = 'Vytvořit v novém okně';
$labels['htmleditor'] = 'Vytvářet HTML zprávy';
$labels['htmlonreply'] = 'jen při odpovědi na HTML zprávy';
$labels['htmlonreplyandforward'] = 'při přeposlání nebo odpovědi na HTML zprávu';
$labels['htmlsignature'] = 'HTML podpis';
$labels['showemail'] = 'Zobrazit e-mailovou adresu se skutečným jménem';
$labels['previewpane'] = 'Zobrazit panel náhledu';
$labels['skin'] = 'Vzhled';
$labels['logoutclear'] = 'Vyprázdnit koš při odhlášení';
$labels['logoutcompact'] = 'Provést údržbu schránky při odhlášení';
$labels['uisettings'] = 'Uživatelské rozhraní';
$labels['serversettings'] = 'Nastavení serveru';
$labels['mailboxview'] = 'Zobrazení schránky';
$labels['mdnrequests'] = 'Oznámení o doručení';
$labels['askuser'] = 'zeptat se';
$labels['autosend'] = 'poslat potvrzení automaticky';
$labels['autosendknown'] = 'poslat potvrzení pouze mým kontaktům, jinak se zeptat';
$labels['autosendknownignore'] = 'poslat potvrzení pouze mým kontaktům, jinak ignorovat';
$labels['autosendtrusted'] = 'odeslat potvrzení pouze důvěryhodným odesilatelům, jinak se mě zeptat';
$labels['autosendtrustedignore'] = 'odeslat potvrzení pouze důvěryhodným odesilatelům, jinak ignorovat';
$labels['ignorerequest'] = 'ignorovat požadavek';
$labels['readwhendeleted'] = 'Při odstranění označit zprávu jako přečtenou';
$labels['flagfordeletion'] = 'Zprávu nemazat, pouze označit pro odstranění';
$labels['skipdeleted'] = 'Nezobrazovat smazané zprávy';
$labels['deletealways'] = 'Odstranit zprávy, pokud selže jejich přesun do koše';
$labels['deletejunk'] = 'Přímo mazat zprávy ze složky Nevyžádaná pošta';
$labels['showremoteimages'] = 'Zobrazovat obrázky uložené mimo mail';
$labels['allowremoteresources'] = 'Povolit vzdálené zdroje (obrázky, styly)';
$labels['fromknownsenders'] = 'od známých uživatelů';
$labels['fromtrustedsenders'] = 'od důvěryhodných odesilatelů';
$labels['frommycontacts'] = 'od mých kontaktů';
$labels['always'] = 'vždy';
$labels['alwaysbutplain'] = 'vždy, pokud se neodpovídá na zprávu ve formátu plain text';
$labels['showinlineimages'] = 'Zobrazovat připojené obrázky pod textem';
$labels['autosavedraft'] = 'Automaticky uložit rozepsané zprávy';
$labels['everynminutes'] = 'každých $n minut';
$labels['refreshinterval'] = 'Obnovit (zkontroluj nové zprávy, atd.)';
$labels['never'] = 'nikdy';
$labels['immediately'] = 'ihned';
$labels['messagesdisplaying'] = 'Zobrazování zpráv';
$labels['messagescomposition'] = 'Psaní zpráv';
$labels['mimeparamfolding'] = 'Jména příloh';
$labels['2231folding'] = 'RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 (ostatní)';
$labels['force7bit'] = 'Použít kódování MIME pro 8-bitové znaky';
$labels['savelocalstorage'] = "Uložit v lokální paměti prohlížeče (dočasně)";
$labels['advancedoptions'] = 'Pokročilá nastavení';
$labels['toggleadvancedoptions'] = 'Přepnout pokročilé možnosti';
$labels['focusonnewmessage'] = 'Aktivovat okno prohlížeče při příchozí zprávě';
$labels['checkallfolders'] = 'Kontrolovat nové zprávy ve všech složkách';
$labels['displaynext'] = 'Zobrazit další záznam po smazání/přesunutí';
$labels['defaultfont'] = 'Výchozí písmo zprávy HTML';
$labels['mainoptions'] = 'Hlavní nastavení';
$labels['browseroptions'] = 'Možnosti prohlížeče';
$labels['section'] = 'Sekce';
$labels['maintenance'] = 'Údržba';
$labels['newmessage'] = 'Nová zpráva';
$labels['signatureoptions'] = 'Nastavení podpisu';
$labels['whenreplying'] = 'Při odpovídání';
$labels['replyempty'] = 'necitovat původní zprávu';
$labels['replytopposting'] = 'začít novou zprávu nad původní';
$labels['replytoppostingnoindent'] = 'Začít novou zprávu nad citovanou (bez odsazení)';
$labels['replybottomposting'] = 'začít novou zprávu pod původní';
$labels['replyremovesignature'] = 'Při odpovídání odstranit ze zprávy původní podpis';
$labels['autoaddsignature'] = 'Automaticky přidat podpis';
$labels['newmessageonly'] = 'pouze k novým zprávám';
$labels['replyandforwardonly'] = 'jen k odpovědi a přeposílané zprávě';
$labels['insertsignature'] = 'Vložit podpis';
$labels['sigbelow'] = 'Vkládat podpis pod citovanou zprávu';
$labels['sigseparator'] = 'Vynutit standardní oddělovač v podpisech';
$labels['automarkread'] = 'Označit zprávy jako přečtené';
$labels['afternseconds'] = 'po $n sekundách';
$labels['reqmdn'] = 'Vždy požadovat doručenku';
$labels['reqdsn'] = 'Vždy požádat o oznámení stavu doručení';
$labels['replysamefolder'] = 'Ukládat odpovědi ve stejné složce jako je zodpovězená zpráva';
$labels['defaultabook'] = 'Výchozí adresář kontaktů';
$labels['autocompletesingle'] = 'Při doplňování adres přeskočit alternativní e-mailovou adresu.';
$labels['listnamedisplay'] = 'Vypsat kontakty jako';
$labels['contactformmode'] = 'Forma kontaktu';
$labels['privatemode'] = 'Osobní (Domácí)';
$labels['businessmode'] = 'Pracovní';
$labels['collectedaddresses'] = 'Shromážděné adresy';
$labels['collectedrecipients'] = 'Shromáždění příjemci';
$labels['collectedrecipientsopt'] = 'Uložení příjemců z odchozích emailů do';
$labels['collectedsendersopt'] = 'Uložení důvěryhodných odesilatelů do';
$labels['trustedsenders'] = 'Důvěryhodní odesilatelé';
$labels['spellcheckbeforesend'] = 'Před odesláním zkontrolovat pravopis';
$labels['spellcheckoptions'] = 'Nastavení pravopisu';
$labels['spellcheckignoresyms'] = 'Ignorovat slova obsahující symboly';
$labels['spellcheckignorenums'] = 'Ignorovat slova obsahující čísla';
$labels['spellcheckignorecaps'] = 'Ignorovat slova psaná velkými písmeny';
$labels['addtodict'] = 'Přidat do slovníku';
$labels['mailtoprotohandler'] = 'Zaregistrovat handler pro odkazy „mailto:“';
$labels['standardwindows'] = 'Zacházet s vyskakovacími okny jako se standardními okny';
$labels['forwardmode'] = 'Přeposlat zprávu';
$labels['inline'] = 'vloženě';
$labels['asattachment'] = 'jako přílohu';
$labels['replyallmode'] = 'Výchozí akce tlačítka [Odpovědět všem]';
$labels['replyalldefault'] = 'odpovědět všem';
$labels['replyalllist'] = 'odpovědět pouze do poštovní konference (pokud je nalezena)';
$labels['allmessages'] = 'Všechny zprávy';
$labels['olderxdays'] = 'starší než $x dní';
$labels['folder'] = 'Složka';
$labels['folders'] = 'Složky';
$labels['foldername'] = 'Jméno složky';
$labels['subscribed'] = 'Vybráno';
$labels['messagecount'] = 'Počet zpráv';
$labels['create'] = 'Vytvořit';
$labels['createfolder'] = 'Vytvořit novou složku';
$labels['managefolders'] = 'Spravovat složky';
$labels['specialfolders'] = 'Speciální složky';
$labels['properties'] = 'Vlastnosti';
$labels['folderproperties'] = 'Vlastnosti složky';
$labels['parentfolder'] = 'Nadřazená složka';
$labels['location'] = 'Umístění';
$labels['info'] = 'Informace';
$labels['getfoldersize'] = 'Kliknutím zjistíte velikost složky';
$labels['changesubscription'] = 'Kliknutím změníte přednastavení';
$labels['foldertype'] = 'Typ složky';
$labels['personalfolder'] = 'Soukromá složka';
$labels['otherfolder'] = 'Složky ostatních uživatelů';
$labels['sharedfolder'] = 'Sdílená složka';
$labels['findfolders'] = 'Hledat složky';
$labels['findcontacts'] = 'Najít kontakty';
$labels['findmail'] = 'Najít zprávy';
$labels['namespace.personal'] = 'Osobní';
$labels['namespace.other'] = 'Jiných uživatelů';
$labels['namespace.shared'] = 'Sdílené';
$labels['dualuselabel'] = 'Může obsahovat pouze';
$labels['dualusemail'] = 'zprávy';
$labels['dualusefolder'] = 'složky';
$labels['generate'] = 'Vygenerovat';
$labels['encryptioncreatekey'] = 'Vytvořit nový pár klíčů';
$labels['openmailvelopesettings'] = 'Otevřít nastavení Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'V klíčence Mailvelope máte $nr odpovídajících privátních PGP klíčů:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Klíčenka Mailvelope neobsahuje privátní PGP klíč identity odesílatele. Chcete ho pro šifrování zpráv vytvořit?';
$labels['encryption'] = 'Šifrování';
$labels['mailvelopeoptions'] = 'Nastavení Mailvelope';
$labels['mailvelopemainkeyring'] = 'Použít hlavní klíčenku Mailvelope';
$labels['mailvelopenotfound'] = 'Rozšíření Mailvelope není povoleno nebo nainstalováno ve vašem prohlížeči.';
$labels['sortby'] = 'Seřadit podle';
$labels['sortasc'] = 'Seřadit vzestupně';
$labels['sortdesc'] = 'Seřadit sestupně';
$labels['undo'] = 'Vrátit zpět';
$labels['installedplugins'] = 'Nainstalované pluginy';
$labels['plugin'] = 'Zásuvný modul';
$labels['version'] = 'Verze';
$labels['source'] = 'Zdroj';
$labels['destination'] = 'Cíl';
$labels['license'] = 'Licence';
$labels['support'] = 'Podpora';
$labels['savedsearches'] = 'Uložená vyhledávání';
$labels['dateformatY'] = 'RRRR';
$labels['dateformaty'] = 'RR';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Angličtina';
$labels['westerneuropean'] = 'Západní Evropa';
$labels['easterneuropean'] = 'Východní Evropa';
$labels['southeasterneuropean'] = 'Jiho-východní Evropa';
$labels['baltic'] = 'Baltština';
$labels['cyrillic'] = 'Cyrilice';
$labels['arabic'] = 'Arabština';
$labels['greek'] = 'Řečtina';
$labels['hebrew'] = 'Hebrejština';
$labels['turkish'] = 'Turečtina';
$labels['nordic'] = 'Nordština';
$labels['thai'] = 'Thajština';
$labels['celtic'] = 'Keltština';
$labels['vietnamese'] = 'Vietnamština';
$labels['japanese'] = 'Japonština';
$labels['korean'] = 'Korejština';
$labels['chinese'] = 'Čínština';
$labels['arialabeltopnav'] = 'Ovládání okna';
$labels['arialabeltasknav'] = 'Úlohy aplikace';
$labels['arialabeltoolbar'] = 'Panel nástrojů aplikace';
$labels['arialabellistnav'] = 'Seznam navigace';
$labels['arialabelactivetask'] = 'Aktivní úloha';
$labels['arialabelmessagessearchfilter'] = 'Filtr seznamu e-mailů';
$labels['arialabelmailsearchform'] = 'Formulář pro vyhledávání e-mailů';
$labels['arialabelcontactsearchform'] = 'Formulář pro vyhledávání kontaktů';
$labels['arialabelmailquicksearchbox'] = 'Vstup pro vyhledávání e-mailu';
$labels['arialabelquicksearchbox'] = 'Vstup pro vyhledávání';
$labels['arialabelfoldersearchfilter'] = 'Filtr pro seznam složek';
$labels['arialabelfoldersearchform'] = 'Formulář pro vyhledávání složek';
$labels['arialabelfolderlist'] = 'Výběr složky s e-mailovými zprávami';
$labels['arialabelmessagelist'] = 'Seznam e-mailových zpráv';
$labels['arialabelmailpreviewframe'] = 'Náhled zprávy';
$labels['arialabelmailboxmenu'] = 'Menu akcí pro složku';
$labels['arialabellistselectmenu'] = 'Menu pro výběr seznamu';
$labels['arialabelthreadselectmenu'] = 'Menu pro seznam vláken';
$labels['arialabelmessagelistoptions'] = 'Možnosti zobrazení a třídění seznamu zpráv';
$labels['arialabelmailimportdialog'] = 'Dialog pro import zpráv';
$labels['arialabelmessagenav'] = 'Navigace zprávy';
$labels['arialabelmessagebody'] = 'Tělo zprávy';
$labels['arialabelmessageactions'] = 'Akce zprávy';
$labels['arialabelcontactquicksearch'] = 'Formulář pro vyhledávání kontaktů';
$labels['arialabelcontactsearchbox'] = 'Vstup pro vyhledávání kontaktů';
$labels['arialabelmessageheaders'] = 'Hlavičky zprávy';
$labels['arialabelforwardingoptions'] = 'Možnosti přeposílání';
$labels['arialabelreplyalloptions'] = 'Možnosti pro "Odpovědět všem"';
$labels['arialabelmoremessageactions'] = 'Více akcí pro zprávu';
$labels['arialabelmorecontactactions'] = 'Další akce pro kontakt';
$labels['arialabelmarkmessagesas'] = 'Označit vybrané zprávy jako...';
$labels['arialabelcomposeoptions'] = 'Možnosti kompozice';
$labels['arialabelresponsesmenu'] = 'Menu pro předpřipravené odpovědi';
$labels['arialabelattachmentuploadform'] = 'Formulář pro vložení přílohy';
$labels['arialabelattachmentmenu'] = 'Možnosti přílohy';
$labels['arialabelmailtomenu'] = 'Možnosti e-mailové adresy';
$labels['arialabelattachmentpreview'] = 'Náhled přílohy';
$labels['ariasummarycomposecontacts'] = 'Seznam kontaktů a skupin pro výběr příjemců';
$labels['arialabelcontactexportoptions'] = 'Možnosti pro export kontaktu';
$labels['arialabelabookgroupoptions'] = 'Možnosti adresáře/skupiny';
$labels['arialabelpreferencesform'] = 'Formulář preferencí';
$labels['arialabelidentityeditfrom'] = 'Formulář pro úpravu identity';
$labels['arialabelresponseeditfrom'] = 'Formulář pro úpravu odpovědi';
$labels['arialabelsearchterms'] = 'Výrazy pro vyhledávání';
$labels['arialabeldropactionmenu'] = 'Drag-n-Drop akční menu';
$labels['arialabelheadersmenu'] = 'Menu přidání příjemce (hlavička)';
$labels['arialabelimagetools'] = 'Nástroje pro obrázky';
$labels['helplistnavigation'] = 'Seznam navigace pomocí klávesnice';
$labels['helplistkeyboardnavigation'] = "Šipky nahoru/dolu: Posunout výběr/označení řádku.
Mezerník: Označit vybraný řádek.
Shift + nahoru/dolu: Vybrat další řádek nad/pod.
Ctrl + Mezerník: Přidat/odebrat označení vybraného řádku.";
$labels['helplistkeyboardnavmessages'] = "Šipky vlevo/vpravo: Rozbalit/zabalit vlákno zprávy (pouze v režimu vláken).
Enter: Otevřít vybranou zprávu.
Delete: Přesunout vybrané zprávy do Koše.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Otevřít označený/vybraný kontakt.";
