<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Dobrodošli na $product';
$labels['username'] = 'Korisničko ime';
$labels['password'] = 'Lozinka';
$labels['server'] = 'Poslužitelj';
$labels['login'] = 'Prijava';
$labels['logout'] = 'Odjava';
$labels['mail'] = 'Pošta';
$labels['settings'] = 'Postavke';
$labels['addressbook'] = 'Imenik';
$labels['inbox'] = 'Pristigla pošta';
$labels['drafts'] = 'Predlošci';
$labels['sent'] = 'Poslano';
$labels['trash'] = 'Smeće';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Prikaži prava imena specijalnih mapa';
$labels['subject'] = 'Naslov';
$labels['from'] = 'Od';
$labels['sender'] = 'Pošiljatelj';
$labels['to'] = 'Za';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Odgovori';
$labels['followupto'] = 'Nastavi-na';
$labels['date'] = 'Datum';
$labels['size'] = 'Veličina';
$labels['priority'] = 'Prioritet';
$labels['organization'] = 'Organizacija';
$labels['readstatus'] = 'Pročitano';
$labels['listoptions'] = 'Opcije lista...';
$labels['mailboxlist'] = 'Mape';
$labels['messagesfromto'] = 'Poruke od $from do $to od ukupno $count';
$labels['threadsfromto'] = 'Teme od $from do $to od ukupno $count';
$labels['messagenrof'] = 'Poruka broj $nr od $count';
$labels['fromtoshort'] = '$from - $to od $count';
$labels['copy'] = 'Kopiraj';
$labels['move'] = 'Premjesti';
$labels['moveto'] = 'Premjesti u...';
$labels['copyto'] = 'Kopiraj u...';
$labels['download'] = 'Preuzmi (download)';
$labels['open'] = 'Otvori';
$labels['showattachment'] = 'Prikaži';
$labels['showanyway'] = 'Prikaži svejedno';
$labels['filename'] = 'Ime datoteke';
$labels['filesize'] = 'Veličina datoteke';
$labels['addtoaddressbook'] = 'Dodaj u imenik';
$labels['sun'] = 'Ned';
$labels['mon'] = 'Pon';
$labels['tue'] = 'Uto';
$labels['wed'] = 'Sri';
$labels['thu'] = 'Čet';
$labels['fri'] = 'Pet';
$labels['sat'] = 'Sub';
$labels['sunday'] = 'Nedjelja';
$labels['monday'] = 'Ponedjeljak';
$labels['tuesday'] = 'Utorak';
$labels['wednesday'] = 'Srijeda';
$labels['thursday'] = 'Četvrtak';
$labels['friday'] = 'Petak';
$labels['saturday'] = 'Subota';
$labels['jan'] = 'Sij';
$labels['feb'] = 'Velj';
$labels['mar'] = 'Ožu';
$labels['apr'] = 'Tra';
$labels['may'] = 'Svi';
$labels['jun'] = 'Lip';
$labels['jul'] = 'Srp';
$labels['aug'] = 'Kol';
$labels['sep'] = 'Ruj';
$labels['oct'] = 'Lis';
$labels['nov'] = 'Stu';
$labels['dec'] = 'Pro';
$labels['longjan'] = 'Siječanj';
$labels['longfeb'] = 'Veljača';
$labels['longmar'] = 'Ožujak';
$labels['longapr'] = 'Travanj';
$labels['longmay'] = 'Svibanj';
$labels['longjun'] = 'Lipanj';
$labels['longjul'] = 'Srpanj';
$labels['longaug'] = 'Kolovoz';
$labels['longsep'] = 'Rujan';
$labels['longoct'] = 'Listopad';
$labels['longnov'] = 'Studeni';
$labels['longdec'] = 'Prosinac';
$labels['today'] = 'Danas';
$labels['refresh'] = 'Osvježi';
$labels['checkmail'] = 'Provjera novih poruka';
$labels['compose'] = 'Nova poruka';
$labels['writenewmessage'] = 'Stvori novu poruku';
$labels['reply'] = 'Odgovori';
$labels['replytomessage'] = 'Odgovori pošiljatelju';
$labels['replytoallmessage'] = 'Odgovori listi ili pošiljatelju i svim primateljima';
$labels['replyall'] = 'Odgovori svima';
$labels['replylist'] = 'Odgovori listi';
$labels['forward'] = 'Proslijedi';
$labels['forwardinline'] = 'Proslijedi umetnuto';
$labels['forwardattachment'] = 'Proslijedi kao privitak';
$labels['forwardmessage'] = 'Proslijedi poruku';
$labels['deletemessage'] = 'Obriši poruku';
$labels['movemessagetotrash'] = 'Preseli poruke u smeće';
$labels['printmessage'] = 'Ispiši ovu poruku';
$labels['previousmessage'] = 'Prikaži prethodnu poruku';
$labels['firstmessage'] = 'Prikaži prvu poruku';
$labels['nextmessage'] = 'Prikaži slijedeću poruku';
$labels['lastmessage'] = 'Prikaži zadnju poruku';
$labels['backtolist'] = 'Povratak na listu poruka';
$labels['viewsource'] = 'Prikaži poruku u izvornom obliku';
$labels['mark'] = 'Označi';
$labels['markmessages'] = 'Označi poruke';
$labels['markread'] = 'Kao pročitano';
$labels['markunread'] = 'Kao nepročitano';
$labels['markflagged'] = 'Kao označeno';
$labels['markunflagged'] = 'Kao neoznačeno';
$labels['moreactions'] = 'Više akcija...';
$labels['folders-all'] = 'Sve mape';
$labels['more'] = 'Više';
$labels['back'] = 'Natrag';
$labels['options'] = 'Postavke';
$labels['actions'] = 'Radnje';
$labels['select'] = 'Odaberi';
$labels['all'] = 'Sve';
$labels['none'] = 'Ništa';
$labels['currpage'] = 'Trenutna stranica';
$labels['isread'] = 'Čitanje';
$labels['unread'] = 'Nepročitano';
$labels['flagged'] = 'Označeno';
$labels['unanswered'] = 'Neodgovoreno';
$labels['withattachment'] = 'S privitkom';
$labels['deleted'] = 'Obrisano';
$labels['undeleted'] = 'Neobrisano';
$labels['invert'] = 'Obrni';
$labels['filter'] = 'Filtriraj';
$labels['list'] = 'Lista';
$labels['threads'] = 'Teme';
$labels['expand-all'] = 'Proširi sve';
$labels['expand-unread'] = 'Proširi nepročitano';
$labels['collapse-all'] = 'Zatvori sve';
$labels['threaded'] = 'Tematski prikaz';
$labels['autoexpand_threads'] = 'Proširi teme poruka';
$labels['do_expand'] = 'sve teme';
$labels['expand_only_unread'] = 'samo s nepročitanim porukama';
$labels['fromto'] = 'Pošiljatelj/Primatelj';
$labels['flag'] = 'Oznaka';
$labels['attachment'] = 'Privitak';
$labels['nonesort'] = 'Ništa';
$labels['sentdate'] = 'Datum slanja';
$labels['arrival'] = 'Datum primitka';
$labels['asc'] = 'uzlazno';
$labels['desc'] = 'silazno';
$labels['listcolumns'] = 'Stupci';
$labels['listsorting'] = 'Sortirajući stupac';
$labels['listorder'] = 'Redoslijed sortiranja';
$labels['listmode'] = 'Model pregleda listi';
$labels['layoutlist'] = 'Lista';
$labels['folderactions'] = 'Akcije mapa...';
$labels['compact'] = 'Kompresiraj (sažmi)';
$labels['empty'] = 'Isprazni';
$labels['importmessages'] = 'Uvoz poruka';
$labels['quota'] = 'Iskorištenost diska';
$labels['unknown'] = 'nepoznato';
$labels['unlimited'] = 'neograničeno';
$labels['quicksearch'] = 'Brza pretraga';
$labels['resetsearch'] = 'Vrati pretragu u početno stanje';
$labels['searchmod'] = 'Postavke pretrage';
$labels['msgtext'] = 'Cijela poruka';
$labels['body'] = 'Tijelo poruke';
$labels['type'] = 'Tip';
$labels['namex'] = 'Ime';
$labels['searchscope'] = 'Djelokrug';
$labels['currentfolder'] = 'Trenutna mapa';
$labels['subfolders'] = 'Ovo i podmape';
$labels['allfolders'] = 'Sve mape';
$labels['openinextwin'] = 'Otvori u novom prozoru';
$labels['emlsave'] = 'Preuzmi (.eml)';
$labels['changeformattext'] = 'Prikaži kao običan tekst';
$labels['changeformathtml'] = 'Prikaži kao HTML';
$labels['editasnew'] = 'Uredi kao novo';
$labels['send'] = 'Pošalji';
$labels['sendmessage'] = 'Pošalji poruku';
$labels['savemessage'] = 'Spremi kao predložak';
$labels['addattachment'] = 'Priloži datoteku';
$labels['charset'] = 'Kodna stranica';
$labels['editortype'] = 'Tip uređivača teksta';
$labels['returnreceipt'] = 'Potvrda o primitku poruke';
$labels['dsn'] = 'Obavijest o statusu isporuke';
$labels['mailreplyintro'] = 'Dana $date, $sender je napisao(la):';
$labels['originalmessage'] = 'Izvorna poruka';
$labels['encrypt'] = 'Šifriraj';
$labels['keyid'] = 'ID ključa';
$labels['insert'] = 'Umetni';
$labels['recipient'] = 'Primatelj';
$labels['editidents'] = 'Uredi identitete';
$labels['spellcheck'] = 'Pravopis';
$labels['checkspelling'] = 'Provjera pravopisa';
$labels['resumeediting'] = 'Nastavi uređivanje';
$labels['revertto'] = 'Vrati na';
$labels['restore'] = 'Povrat';
$labels['restoremessage'] = 'Povrat poruke?';
$labels['ignore'] = 'Zanemari';
$labels['responses'] = 'Odgovori';
$labels['insertresponse'] = 'Umetni odgovor';
$labels['manageresponses'] = 'Upravljanje odgovorima';
$labels['editresponse'] = 'Uredi odgovor';
$labels['editresponses'] = 'Uredi odgovore';
$labels['responsename'] = 'Naziv';
$labels['responsetext'] = 'Tekst odgovora';
$labels['attach'] = 'Priloži';
$labels['attachments'] = 'Privitci (Attachments)';
$labels['upload'] = 'Dodaj';
$labels['close'] = 'Zatvori';
$labels['messageoptions'] = 'Postavke poruka...';
$labels['low'] = 'Nizak';
$labels['lowest'] = 'Najniži';
$labels['normal'] = 'Srednji';
$labels['high'] = 'Visok';
$labels['highest'] = 'Najviši';
$labels['nosubject'] = '(bez naslova)';
$labels['showimages'] = 'Prikaži slike';
$labels['alwaysshow'] = 'Uvijek prikaži slike od $sender';
$labels['isdraft'] = 'Ova poruka je predložak.';
$labels['andnmore'] = '$nr više...';
$labels['togglemoreheaders'] = 'Prikaži još zaglavlja poruke';
$labels['togglefullheaders'] = 'Prikaži neuređena zaglavlja poruke';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Samo tekst';
$labels['savesentmessagein'] = 'Spremi poslane poruke u';
$labels['dontsave'] = 'ne spremaj';
$labels['maxuploadsize'] = 'Maksimalna dozvoljena veličina datoteke je $size';
$labels['addcc'] = 'Dodaj Cc';
$labels['addbcc'] = 'Dodaj Bcc';
$labels['addreplyto'] = 'Dodaj Odgovori-na';
$labels['addfollowupto'] = 'Dodaj Nastavak-na';
$labels['mdnrequest'] = 'Pošiljatelj ove poruke je tražio da bude obaviješten o njenom primitku. Želite li obavijestiti pošiljatelja?';
$labels['receiptread'] = 'Potvrda o primitku (pročitano)';
$labels['yourmessage'] = 'Ovo je potvrda o primitku vaše poruke';
$labels['receiptnote'] = 'Info: Ova poruka o primitku samo potvrđuje da se poruka prikazala na računalu primatelja. Nema garancije da je primatelj pročitao ili razumio sadržaj poruke.';
$labels['name'] = 'Puno ime';
$labels['firstname'] = 'Ime';
$labels['surname'] = 'Prezime';
$labels['middlename'] = 'Srednje ime';
$labels['nameprefix'] = 'Prefiks';
$labels['namesuffix'] = 'Sufiks';
$labels['nickname'] = 'Nadimak';
$labels['jobtitle'] = 'Titula';
$labels['department'] = 'Odjel';
$labels['gender'] = 'Spol';
$labels['maidenname'] = 'Djevojačko prezime';
$labels['email'] = 'E-mail';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Adresa';
$labels['street'] = 'Ulica';
$labels['locality'] = 'Grad';
$labels['zipcode'] = 'Poštanski broj';
$labels['region'] = 'Oblast';
$labels['country'] = 'Država';
$labels['birthday'] = 'Rođendan';
$labels['anniversary'] = 'Godišnjica';
$labels['website'] = 'Web stranica';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Bilješke';
$labels['male'] = 'muško';
$labels['female'] = 'žensko';
$labels['manager'] = 'Menadžer';
$labels['assistant'] = 'Asistent';
$labels['spouse'] = 'Suprug/a';
$labels['allfields'] = 'Sva polja';
$labels['search'] = 'Pretraga';
$labels['advsearch'] = 'Napredna pretraga';
$labels['advanced'] = 'Napredno';
$labels['other'] = 'Ostalo';
$labels['typehome'] = 'Kuća';
$labels['typework'] = 'Posao';
$labels['typeother'] = 'Ostalo';
$labels['typemobile'] = 'Mobitel';
$labels['typemain'] = 'Glavni';
$labels['typehomefax'] = 'Fax kuća';
$labels['typeworkfax'] = 'Fax posao';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Pejdžer';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Asistent';
$labels['typehomepage'] = 'Početna stranica';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Dodaj polje...';
$labels['addcontact'] = 'Dodaj kontakt';
$labels['editcontact'] = 'Uredi kontakt';
$labels['contacts'] = 'Kontakti';
$labels['contactproperties'] = 'Svojstva kontakta';
$labels['personalinfo'] = 'Osobni podaci';
$labels['edit'] = 'Uredi';
$labels['cancel'] = 'Odustani';
$labels['save'] = 'Spremi';
$labels['delete'] = 'Obriši';
$labels['rename'] = 'Preimenuj';
$labels['addphoto'] = 'Dodaj';
$labels['replacephoto'] = 'Zamijeni';
$labels['uploadphoto'] = 'Postavi fotografiju';
$labels['deletecontact'] = 'Obriši odabrane kontakte';
$labels['composeto'] = 'Napiši mail za';
$labels['contactsfromto'] = 'Kontakti od $from do $to od ukupno $count';
$labels['print'] = 'Ispis';
$labels['export'] = 'Izvoz';
$labels['exportall'] = 'Izvezi sve';
$labels['exportsel'] = 'Izvezi odabrano';
$labels['exportvcards'] = 'Izvezi kontakte u vCard formatu';
$labels['grouprename'] = 'Preimenuj grupu';
$labels['groupdelete'] = 'Obriši grupu';
$labels['groupremoveselected'] = 'Obriši odabrane kontakte iz grupe ';
$labels['previouspage'] = 'Prethodna strana';
$labels['firstpage'] = 'Prva strana';
$labels['nextpage'] = 'Slijedeća strana';
$labels['lastpage'] = 'Zadnja strana';
$labels['group'] = 'Grupa';
$labels['groups'] = 'Grupe';
$labels['listgroup'] = 'Prikaži članove grupe';
$labels['personaladrbook'] = 'Privatna adresa';
$labels['searchsave'] = 'Spremi pretragu';
$labels['searchdelete'] = 'Obriši pretragu';
$labels['import'] = 'Uvoz';
$labels['importcontacts'] = 'Uvoz kontakta';
$labels['importfromfile'] = 'Uvezi iz datoteke';
$labels['importtarget'] = 'Dodaj kontakte u';
$labels['importreplace'] = 'Prepiši cijeli imenik';
$labels['importgroups'] = 'Uvezi zadatke grupe';
$labels['importgroupsall'] = 'Sve (stvori grupe ako je potrebno)';
$labels['importgroupsexisting'] = 'Samo za postojeće grupe';
$labels['done'] = 'Završeno';
$labels['settingsfor'] = 'Postavke za';
$labels['about'] = 'O programu';
$labels['preferences'] = 'Postavke';
$labels['userpreferences'] = 'Korisničke postavke';
$labels['editpreferences'] = 'Uredi korisničke postavke';
$labels['identities'] = 'Identiteti';
$labels['manageidentities'] = 'Upravljanje identitetima';
$labels['newidentity'] = 'Stvori novi identitet';
$labels['addidentity'] = 'Dodaj identitet';
$labels['identityencryption'] = 'Šifriranje';
$labels['preferhtml'] = 'Prikaži HTML';
$labels['defaultcharset'] = 'Zadana kodna stranica';
$labels['htmlmessage'] = 'HTML format poruke';
$labels['messagepart'] = 'Dio';
$labels['digitalsig'] = 'Digitalni potpis';
$labels['dateformat'] = 'Format datuma';
$labels['timeformat'] = 'Format vremena';
$labels['prettydate'] = 'Formatirani datum';
$labels['setdefault'] = 'Postavi zadano';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Jezik';
$labels['timezone'] = 'Vremenska zona';
$labels['pagesize'] = 'Redaka po stranici';
$labels['signature'] = 'Potpis';
$labels['dstactive'] = 'Ljetno/zimsko računanje vremena';
$labels['showinextwin'] = 'Otvori poruku u novom prozoru';
$labels['composeextwin'] = 'Sastavi poruku u novom prozoru';
$labels['htmleditor'] = 'Sastavi poruke u HTML formatu';
$labels['htmlonreply'] = 'pri odgovaranju na HTML poruku';
$labels['htmlonreplyandforward'] = 'pri prosljeđivanju ili odgovaranju na HTML poruku';
$labels['htmlsignature'] = 'HTML potpis';
$labels['showemail'] = 'Prikaži e-mail adresu s imenom';
$labels['previewpane'] = 'Prikaži područje pregleda';
$labels['skin'] = 'Tema sučelja';
$labels['logoutclear'] = 'Očisti smeće pri odjavi';
$labels['logoutcompact'] = 'Sažmi Inbox pri odjavi';
$labels['uisettings'] = 'Korisničko sučelje';
$labels['serversettings'] = 'Postavke poslužitelja';
$labels['mailboxview'] = 'Pregled sandučića';
$labels['mdnrequests'] = 'na zahtjev za potvrdom primitka';
$labels['askuser'] = 'pitaj me';
$labels['autosend'] = 'pošalji potvrdu';
$labels['autosendknown'] = 'pošalji potvrdu ako je pošiljatelj u mom imeniku, u suprotnom me pitaj';
$labels['autosendknownignore'] = 'pošalji potvrdu ako je pošiljatelj u mom imeniku, u suprotnom zanemari';
$labels['readwhendeleted'] = 'Označi poruku kao pročitanu pri brisanju';
$labels['flagfordeletion'] = 'Označi poruku za brisanje umjesto brisanja';
$labels['skipdeleted'] = 'Ne prikazuj obrisane poruke';
$labels['deletealways'] = 'Ukoliko premještanje poruka u mapu smeće ne uspije, izbriši poruku';
$labels['deletejunk'] = 'Odmah obriši poruke u mapi Smeće';
$labels['showremoteimages'] = 'Prikaži umetnute slike s interneta';
$labels['fromknownsenders'] = 'od poznatih pošiljatelja';
$labels['always'] = 'uvijek';
$labels['showinlineimages'] = 'Prikaži slike iz privitka ispod poruke';
$labels['autosavedraft'] = 'Automatski spremi predložak';
$labels['everynminutes'] = 'svakih $n minuta';
$labels['refreshinterval'] = 'Osvježi (provjeri nove poruke, itd.)';
$labels['never'] = 'nikad';
$labels['immediately'] = 'odmah';
$labels['messagesdisplaying'] = 'Prikaz poruka';
$labels['messagescomposition'] = 'Sastavljanje poruka';
$labels['mimeparamfolding'] = 'Nazivi privitaka';
$labels['2231folding'] = 'Prema RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Prema RFC 2047 (ostali)';
$labels['force7bit'] = 'Koristi MIME kodiranje za 8-bitne znakove';
$labels['advancedoptions'] = 'Napredne postavke';
$labels['focusonnewmessage'] = 'Fokusiraj prozor preglednika pri primitku nove poruke';
$labels['checkallfolders'] = 'Provjeri nove poruke u svim mapama';
$labels['defaultfont'] = 'Zadani font HTML poruke';
$labels['mainoptions'] = 'Glavne postavke';
$labels['browseroptions'] = 'Postavke preglednika';
$labels['section'] = 'Odjeljak';
$labels['maintenance'] = 'Održavanje';
$labels['newmessage'] = 'Nova poruka';
$labels['signatureoptions'] = 'Postavke potpisa';
$labels['whenreplying'] = 'Prilikom odgovora';
$labels['replyempty'] = 'ne citiraj originalnu poruku';
$labels['replytopposting'] = 'započni novu poruku iznad originalne';
$labels['replybottomposting'] = 'započni novu poruku ispod originalne';
$labels['replyremovesignature'] = 'Kod odgovaranja, makni originalni potpis iz poruke';
$labels['autoaddsignature'] = 'Automatski dodaj potpis';
$labels['newmessageonly'] = 'samo za nove poruke';
$labels['replyandforwardonly'] = 'samo pri odgovaranju i proslijeđivanju';
$labels['insertsignature'] = 'Umetni potpis';
$labels['afternseconds'] = 'nakon $n sekundi';
$labels['reqmdn'] = 'Uvijek zatraži potvrdu o primitku';
$labels['reqdsn'] = 'Uvijek zatraži obavijest o stanju isporuke';
$labels['replysamefolder'] = 'Spremi odgovore u mapu gdje se nalazi originalna poruka';
$labels['defaultabook'] = 'Zadani imenik';
$labels['autocompletesingle'] = 'Preskoči alternativne email adrese u autocomplete prijedlozima';
$labels['listnamedisplay'] = 'Prikaži kontakte kao';
$labels['spellcheckbeforesend'] = 'Provjeri pravopis prije slanja poruke';
$labels['spellcheckoptions'] = 'Postavke provjere pravopisa';
$labels['spellcheckignoresyms'] = 'Zanemari riječi koje sadrže simbole';
$labels['spellcheckignorenums'] = 'Zanemari riječi koje sadrže brojeve';
$labels['spellcheckignorecaps'] = 'Zanemari riječi sa svim velikim slovima';
$labels['addtodict'] = 'Dodaj u rječnik';
$labels['mailtoprotohandler'] = 'Registriraj upravitelj protokola za mailto: linkove';
$labels['standardwindows'] = 'Tretiraj skočne prozore kao standardne';
$labels['forwardmode'] = 'Prosljeđivanje poruka';
$labels['inline'] = 'umetnuto';
$labels['asattachment'] = 'kao privitak';
$labels['replyallmode'] = 'Zadana akcija [Reply all] gumba';
$labels['replyalldefault'] = 'odgovori svima';
$labels['replyalllist'] = 'odgovori samo listi (ako postoji)';
$labels['allmessages'] = 'sve poruke';
$labels['folder'] = 'Mapa';
$labels['folders'] = 'Mape';
$labels['foldername'] = 'Naziv mape';
$labels['subscribed'] = 'Pretplaćen';
$labels['messagecount'] = 'Poruke';
$labels['create'] = 'Stvori';
$labels['createfolder'] = 'Stvori novu mapu';
$labels['managefolders'] = 'Upravljanje mapama';
$labels['specialfolders'] = 'Specijalne mape';
$labels['properties'] = 'Svojstva';
$labels['folderproperties'] = 'Svojstva mape';
$labels['parentfolder'] = 'Glavna mapa';
$labels['location'] = 'Lokacija';
$labels['info'] = 'Informacije';
$labels['getfoldersize'] = 'Kliknite za prikaz veličine mape';
$labels['changesubscription'] = 'Kliknite da biste promijenili pretplatu';
$labels['foldertype'] = 'Vrsta mape';
$labels['personalfolder'] = 'Privatna mapa';
$labels['otherfolder'] = 'Mapa drugog korisnika';
$labels['sharedfolder'] = 'Javna mapa';
$labels['encryption'] = 'Šifriranje';
$labels['sortby'] = 'Sortiraj po';
$labels['sortasc'] = 'Sortiraj uzlaznim nizom';
$labels['sortdesc'] = 'Sortiraj silaznim nizom';
$labels['undo'] = 'Poništi';
$labels['installedplugins'] = 'Instalirani dodaci';
$labels['plugin'] = 'Dodatak';
$labels['version'] = 'Inačica';
$labels['source'] = 'Izvorni kod';
$labels['license'] = 'Licenca';
$labels['support'] = 'Podrška';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Engleski';
$labels['westerneuropean'] = 'Zapadnoeuropski';
$labels['easterneuropean'] = 'Istočnoeuropski';
$labels['southeasterneuropean'] = 'Jugoistočnoeuropski';
$labels['baltic'] = 'Baltički';
$labels['cyrillic'] = 'Čirilićni';
$labels['arabic'] = 'Arapski';
$labels['greek'] = 'Grčki';
$labels['hebrew'] = 'Hebrejski';
$labels['turkish'] = 'Turski';
$labels['nordic'] = 'Nordijski';
$labels['thai'] = 'Tajlandski';
$labels['celtic'] = 'Keltski';
$labels['vietnamese'] = 'Vijetnamski';
$labels['japanese'] = 'Japanski';
$labels['korean'] = 'Korejski';
$labels['chinese'] = 'Kineski';
