<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Help plugin                |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-help/
*/

$labels['help'] = '도움말';
$labels['about'] = '정보';
$labels['license'] = '라이선스';
$labels['csrfinfo'] = 'CSRF 및 사용자 보호에 대해 더 많은 정보 확인';
$labels['arialabelhelpcontent'] = '도움말 컨텐츠';
