<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filteri';
$labels['managefilters'] = 'Upravljanje dolaznim email filterima';
$labels['filtername'] = 'Naziv filtera';
$labels['newfilter'] = 'Novi filter';
$labels['filteradd'] = 'Dodaj filter';
$labels['filterdel'] = 'Obriši filter';
$labels['scope'] = 'Opseg';
$labels['moveup'] = 'Pomjeri gore';
$labels['movedown'] = 'Pomjeri dole';
$labels['filterallof'] = 'poklapa se sa svim sljedećim pravilima';
$labels['filteranyof'] = 'poklapa se sa bilo kojim od sljedećih pravila';
$labels['filterany'] = 'sve poruke';
$labels['filtercontains'] = 'sadrži';
$labels['filternotcontains'] = 'ne sadrži';
$labels['filteris'] = 'jednako';
$labels['filterisnot'] = 'nije jednako';
$labels['filterexists'] = 'postoji';
$labels['filternotexists'] = 'ne postoji';
$labels['filtermatches'] = 'poklapa se sa izrazom';
$labels['filternotmatches'] = 'ne poklapa se sa izrazom';
$labels['filterregex'] = 'poklapa se sa regularnim izrazom';
$labels['filternotregex'] = 'ne poklapa se sa regularnim izrazom';
$labels['filterunder'] = 'ispod';
$labels['filterover'] = 'iznad';
$labels['addrule'] = 'Dodaj pravilo';
$labels['delrule'] = 'Obriši pravilo';
$labels['messagemoveto'] = 'Premjesti poruku u';
$labels['messageredirect'] = 'Preusmjeri poruku ka';
$labels['messagecopyto'] = 'Kopiraj poruku u';
$labels['messagesendcopy'] = 'Pošalji kopiju poruke';
$labels['messagereply'] = 'Odgovori';
$labels['messagedelete'] = 'Obriši poruku';
$labels['messagediscard'] = 'Odbaci sa porukom';
$labels['messagekeep'] = 'Zadrži poruku u sandučetu';
$labels['messagesrules'] = 'Za dolazne emailove:';
$labels['messagesactions'] = '...izvrši sljedeće akcije:';
$labels['add'] = 'Dodaj';
$labels['del'] = 'Obriši';
$labels['sender'] = 'Pošiljaoc';
$labels['recipient'] = 'Primaoc';
$labels['vacationaddr'] = 'Moje email adrese:';
$labels['vacationdays'] = 'Frekvencija slanja poruka (u danima):';
$labels['vacationinterval'] = 'Frekvencija slanja poruka:';
$labels['vacationreason'] = 'Tijelo poruke (razlog za odmor):';
$labels['vacationsubject'] = 'Naslov poruke:';
$labels['days'] = 'dana';
$labels['seconds'] = 'sekundi';
$labels['rulestop'] = 'Prestani procjenjivati pravila';
$labels['enable'] = 'Omogući/Onemogući';
$labels['filtersets'] = 'Setovi filtera';
$labels['filterdef'] = 'Definicija filtera';
$labels['active'] = 'aktivno';
$labels['none'] = 'ništa';
$labels['fromset'] = 'iz seta';
$labels['fromfile'] = 'iz datoteke';
$labels['filterdisabled'] = 'Filter je onemogućen';
$labels['countisgreaterthan'] = 'brojač je veći od';
$labels['countisgreaterthanequal'] = 'brojač je veći ili jednak';
$labels['countislessthan'] = 'brojač je manji od';
$labels['countislessthanequal'] = 'brojač je manji ili jednak';
$labels['countequals'] = 'brojač je jednak';
$labels['countnotequals'] = 'zbir nije jednak';
$labels['valueisgreaterthan'] = 'vrijednost je veća od';
$labels['valueisgreaterthanequal'] = 'vrijednost je veća ili jednaka';
$labels['valueislessthan'] = 'vrijednost je manja od';
$labels['valueislessthanequal'] = 'vrijednost je manja ili jednaka';
$labels['valueequals'] = 'vrijednost je jednaka';
$labels['valuenotequals'] = 'vrijednost nije jednaka';
$labels['setflags'] = 'Postavi oznake za poruku';
$labels['addflags'] = 'Dodaj oznake u poruku';
$labels['removeflags'] = 'Ukloni oznake iz poruke';
$labels['flagread'] = 'Pročitano';
$labels['flagdeleted'] = 'Obrisano';
$labels['flaganswered'] = 'Odgovoreno';
$labels['flagflagged'] = 'Važno';
$labels['flagdraft'] = 'Skica';
$labels['setvariable'] = 'Postavi promjenjivu';
$labels['setvarname'] = 'Naziv promjenjive:';
$labels['setvarvalue'] = 'Vrijednost promjenjive:';
$labels['setvarmodifiers'] = 'Parametri:';
$labels['varlower'] = 'mala slova';
$labels['varupper'] = 'velika slova';
$labels['varlowerfirst'] = 'prvi znak malim slovom';
$labels['varupperfirst'] = 'prvi znak velikim slovom';
$labels['varquotewildcard'] = 'citiraj specijalne znakove';
$labels['varlength'] = 'dužina';
$labels['notify'] = 'Pošalji napomenu';
$labels['notifytarget'] = 'Odredište napomene:';
$labels['notifymessage'] = 'Poruka napomene (neobavezno):';
$labels['notifyoptions'] = 'Opcije napomene (neobavezno):';
$labels['notifyfrom'] = 'Pošiljalac napomene (neobavezno):';
$labels['notifyimportance'] = 'Prioritet:';
$labels['notifyimportancelow'] = 'mali';
$labels['notifyimportancenormal'] = 'obični';
$labels['notifyimportancehigh'] = 'veliki';
$labels['notifymethodmailto'] = 'Email';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Kreiraj filter';
$labels['usedata'] = 'Koristite sljedeće podatke u filteru:';
$labels['nextstep'] = 'Sljedeći korak';
$labels['...'] = '...';
$labels['currdate'] = 'Trenutni datum';
$labels['datetest'] = 'Datum';
$labels['dateheader'] = 'zaglavlje:';
$labels['year'] = 'godina';
$labels['month'] = 'mjesec';
$labels['day'] = 'dan';
$labels['date'] = 'datum (gggg-mm-dd)';
$labels['julian'] = 'datum (julijanski)';
$labels['hour'] = 'sat';
$labels['minute'] = 'minuta';
$labels['second'] = 'sekunda';
$labels['time'] = 'vrijeme (hh:mm:ss)';
$labels['iso8601'] = 'datum (ISO8601)';
$labels['std11'] = 'datum (RFC2822)';
$labels['zone'] = 'vremenska zona';
$labels['weekday'] = 'sedmica (0-6)';
$labels['advancedopts'] = 'Napredne opcije';
$labels['body'] = 'Tijelo';
$labels['address'] = 'adresa';
$labels['envelope'] = 'koverta';
$labels['modifier'] = 'prilagođavanje:';
$labels['text'] = 'tekst';
$labels['undecoded'] = 'nekodiran (obični)';
$labels['contenttype'] = 'vrsta sadržaja';
$labels['modtype'] = 'vrsta:';
$labels['allparts'] = 'sve';
$labels['domain'] = 'domena';
$labels['localpart'] = 'lokalni dio';
$labels['user'] = 'korisnik';
$labels['detail'] = 'detalji';
$labels['comparator'] = 'upoređivač:';
$labels['default'] = 'početno';
$labels['octet'] = 'striktno (oktet)';
$labels['asciicasemap'] = 'osjetljivo na velika/mala slova (ascii-casemap)';
$labels['asciinumeric'] = 'numerički (ascii-numeric)';
$labels['index'] = 'indeks:';
$labels['indexlast'] = 'unazad';
$labels['spamtestequals'] = 'jednako';
$labels['spamtestnotequals'] = 'nije jednako';
$labels['vacation.reply'] = 'Poruka sa odgovorom';
$labels['vacation.advanced'] = 'Napredmen postavke';
$labels['vacation.subject'] = 'Naslov';
$labels['vacation.body'] = 'Tijelo';
$labels['vacation.status'] = 'Status';
$labels['vacation.on'] = 'Uključeno';
$labels['vacation.off'] = 'Isključeno';
$labels['vacation.addresses'] = 'Moje email adrese';
$labels['vacation.interval'] = 'Interval odgovora';
$labels['vacation.saving'] = 'Snimam podatke...';
$labels['vacation.action'] = 'Akcija za dolazne poruke';
$labels['vacation.keep'] = 'Zadrži';
$labels['vacation.discard'] = 'Odbaci';
$labels['vacation.redirect'] = 'Preusmeri ka';
$labels['vacation.copy'] = 'Pošalji kopiju na';
$labels['forward.redirect'] = 'Preusmeri ka';
$labels['forward.copy'] = 'Pošalji kopiju na';
$labels['forward.on'] = 'Uključeno';
$labels['forward.off'] = 'Isključeno';
$labels['forward.saving'] = 'Snimam podatke...';
$labels['filladdresses'] = 'Popuni svim mojim adresama';
$labels['arialabelfiltersetactions'] = 'Akcije za filterske setove';
$labels['arialabelfilteractions'] = 'Filterske akcije';
$labels['arialabelfilterform'] = 'Svojstva filtera';
$labels['ariasummaryfilterslist'] = 'Lista filtera';
$labels['ariasummaryfiltersetslist'] = 'Lista filterskih setova';
$labels['filterstitle'] = 'Uredi filtere za dolazni email';
$labels['vacationtitle'] = 'Uredi pravila kada nisam na poslu';
$labels['duplicate.header'] = 'zaglavlje:';
$messages['filterunknownerror'] = 'Nepoznata serverska greška.';
$messages['filterconnerror'] = 'Nije se moguće povezati na server.';
$messages['filterdeleteerror'] = 'Nije moguće obrisati filter. Desila se serverska greška.';
$messages['filterdeleted'] = 'Filter je uspješno obrisan.';
$messages['filtersaved'] = 'Filter je uspješno sačuvan.';
$messages['filtersaveerror'] = 'Nije moguće sačuvati filter. Desila se serverska greška.';
$messages['filterdeleteconfirm'] = 'Da li zaista želite obrisati označeni filter?';
$messages['ruledeleteconfirm'] = 'Jeste li sigurni da želite obrisati označeno pravilo?';
$messages['actiondeleteconfirm'] = 'Jeste li sigurni da želite obrisati označenu akciju?';
$messages['forbiddenchars'] = 'U polje su uneseni nedozvoljeni znakovi.';
$messages['cannotbeempty'] = 'Polje ne može biti prazno.';
$messages['ruleexist'] = 'Filter s tim imenom već postoji.';
$messages['activateerror'] = 'Nije moguće omogućiti označene filtere. Desila se serverska greška.';
$messages['deactivateerror'] = 'Nije moguće onemogućiti označene filtere. Desila se serverska greška.';
$messages['deactivated'] = 'Filteri su uspješno omogućeni.';
$messages['activated'] = 'Filteri su uspješno onemogućeni.';
$messages['moved'] = 'Filteri su uspješno premješteni.';
$messages['moveerror'] = 'Nije moguće premjestiti označeni filter. Desila se serverska greška.';
$messages['nametoolong'] = 'Ime je predugo.';
$messages['namereserved'] = 'Ime je rezervisano.';
$messages['setexist'] = 'Set već postoji.';
$messages['nodata'] = 'Morate označiti barem jednu poziciju!';
$messages['invaliddateformat'] = 'Netačan datum ili dio formata datuma';
$messages['saveerror'] = 'Nije moguće snimiti podatke. Desila se serverska greška.';
$messages['emptyvacationbody'] = 'Tijelo poruke za odmor je neophodno!';
