<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Zipdownload plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-zipdownload/
*/

$labels['downloadall'] = 'להוריד את כל הצרופות';
$labels['download'] = 'מוריד כעת...';
$labels['downloadmbox'] = 'פורמט Mbox  &rlm;(zip.)';
$labels['downloadmaildir'] = 'פורמט Maildir  &rlm;(zip.)';
$labels['downloademl'] = 'מקור (eml.)';
$labels['sizelimiterror'] = 'הגודל הכולל של ההודעות שנבחרו עולה על הכמות שהוגדרה בסך ($size)';
