<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Hide-Blockquote plugin     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-hide_blockquote/
*/

$labels['hide'] = 'مخفی کردن';
$labels['show'] = 'نشان دادن';
$labels['quotelimit'] = 'پنهان کردن نقل‌قول وقتی تعداد خطوط بیشتر است از';
