<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Vælkomin til $product';
$labels['username'] = 'Brúkaranavn';
$labels['password'] = 'Loyniorð';
$labels['server'] = 'Ambætari';
$labels['login'] = 'Rita inn';
$labels['oauthlogin'] = 'Fita inn við $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Rita út';
$labels['mail'] = 'Teldupostur';
$labels['settings'] = 'Stillingar';
$labels['addressbook'] = 'Búðstaðarsavn';
$labels['darkmode'] = 'Myrkt snið';
$labels['lightmode'] = 'LJóst snið';
$labels['inbox'] = 'Postur';
$labels['drafts'] = 'Skitsur';
$labels['sent'] = 'Sent';
$labels['trash'] = 'Skrell';
$labels['junk'] = 'Møsn';
$labels['show_real_foldernames'] = 'Vís verulig nøvn til serligar mappur';
$labels['subject'] = 'Evni';
$labels['from'] = 'Frá';
$labels['sender'] = 'Sendari';
$labels['to'] = 'Til';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Svara-til';
$labels['followupto'] = 'Fylg við-til';
$labels['date'] = 'Tann';
$labels['size'] = 'Stødd';
$labels['priority'] = 'Raðfesting';
$labels['organization'] = 'Fyritøka';
$labels['readstatus'] = 'Lesistøða';
$labels['listoptions'] = 'Lýs valmøguleikar...';
$labels['listoptionstitle'] = 'Finn boð';
$labels['mailboxlist'] = 'Mappur';
$labels['messagesfromto'] = 'Boðini frá $from til $to ið tilsamans eru $count';
$labels['threadsfromto'] = 'Tráðirnir frá $from til $to ið eru $count';
$labels['messagenrof'] = 'Boð nummar $nr, av $count';
$labels['fromtoshort'] = '$from - $to ið eru $count';
$labels['copy'] = 'Avrita';
$labels['move'] = 'Flyt';
$labels['moveto'] = 'Flyt til...';
$labels['copyto'] = 'Avrita til...';
$labels['download'] = 'Heinta';
$labels['open'] = 'Lat upp';
$labels['showattachment'] = 'Vís';
$labels['showanyway'] = 'Vís tað avlíkavæl';
$labels['filename'] = 'Fílu navn';
$labels['filesize'] = 'Fílu stødd';
$labels['addtoaddressbook'] = 'Legg aftrat búðstaðar bók';
$labels['sun'] = 'Sun';
$labels['mon'] = 'Mán';
$labels['tue'] = 'Týs';
$labels['wed'] = 'Mik';
$labels['thu'] = 'Hós';
$labels['fri'] = 'Frí';
$labels['sat'] = 'Ley';
$labels['sunday'] = 'Sunnudagur';
$labels['monday'] = 'Mánadagur';
$labels['tuesday'] = 'Týsdagur';
$labels['wednesday'] = 'Mikudagur';
$labels['thursday'] = 'Hósdagur';
$labels['friday'] = 'Fríggjardagur';
$labels['saturday'] = 'Leygardagur';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Maj';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Des';
$labels['longjan'] = 'Januar';
$labels['longfeb'] = 'Februar';
$labels['longmar'] = 'Mars';
$labels['longapr'] = 'Apríl';
$labels['longmay'] = 'Maj';
$labels['longjun'] = 'Juni';
$labels['longjul'] = 'July';
$labels['longaug'] = 'August';
$labels['longsep'] = 'Septembur';
$labels['longoct'] = 'Oktobur';
$labels['longnov'] = 'Novembur';
$labels['longdec'] = 'Desembur';
$labels['today'] = 'Í dag';
$labels['refresh'] = 'Endur innles';
$labels['checkmail'] = 'Kann fyri nýggj boð.';
$labels['compose'] = 'Stovna';
$labels['writenewmessage'] = 'Stovna nýggj boð';
$labels['reply'] = 'Svara';
$labels['replytomessage'] = 'Svara til sendara';
$labels['replytoallmessage'] = 'Svara til listan ella til sendara og allir móttakarir';
$labels['replyall'] = 'Svara øllum';
$labels['replylist'] = 'Svara lista';
$labels['forward'] = 'Send víðari';
$labels['forwardinline'] = 'Svara víðari, við gomlum teksti';
$labels['forwardattachment'] = 'Send víðari sum viðhefting';
$labels['forwardmessage'] = 'Send hesi boð víðari';
$labels['bouncemsg'] = 'Send umaftur (bounce)';
$labels['bounce'] = 'Send umaftur';
$labels['deletemessage'] = 'Strika boð';
$labels['movemessagetotrash'] = 'Koyr boð í skrell';
$labels['printmessage'] = 'Útskriva hesi boð';
$labels['previousmessage'] = 'Vís seinastu boð';
$labels['firstmessage'] = 'Vís fyrstu boð';
$labels['nextmessage'] = 'Vís næstu boð';
$labels['lastmessage'] = 'Vís seinastu boð';
$labels['backtolist'] = 'Aftur til boð lista';
$labels['viewsource'] = 'Vís keldu';
$labels['mark'] = 'Merk';
$labels['markmessages'] = 'Merk boð';
$labels['markread'] = 'Sum lisin';
$labels['markunread'] = 'Sum ólisin';
$labels['markflagged'] = 'Sum viðmerkt';
$labels['markunflagged'] = 'Sum óviðmerkt';
$labels['moreactions'] = 'Fleiri gerir...';
$labels['markallread'] = 'Merk alt sum lisið';
$labels['folders-cur'] = 'Einans vald mappa';
$labels['folders-sub'] = 'Einans vald mappa og undirmappa';
$labels['folders-all'] = 'Allar mappur';
$labels['more'] = 'Meira';
$labels['back'] = 'Aftur';
$labels['options'] = 'Valmøguleikar';
$labels['actions'] = 'Gerðir';
$labels['first'] = 'Fyrst';
$labels['last'] = 'Síðst';
$labels['previous'] = 'Fyrra';
$labels['next'] = 'Seinna';
$labels['select'] = 'Vel';
$labels['all'] = 'Alt';
$labels['none'] = 'Einki';
$labels['currpage'] = 'Hesa síðu';
$labels['isread'] = 'Les';
$labels['unread'] = 'Ólisið';
$labels['flagged'] = 'Viðmerkt';
$labels['unflagged'] = 'Ikk merkt';
$labels['unanswered'] = 'Ikki svara';
$labels['withattachment'] = 'Við viðhefting';
$labels['deleted'] = 'Strika';
$labels['undeleted'] = 'Ikki strika';
$labels['replied'] = 'Svara';
$labels['forwarded'] = 'Víðari sent';
$labels['invert'] = 'Vend við';
$labels['filter'] = 'Síla';
$labels['list'] = 'Listið';
$labels['threads'] = 'Tráðir';
$labels['expand-all'] = 'Spreið alt';
$labels['expand-unread'] = 'Spreið ólisið';
$labels['collapse-all'] = 'Sett saman alt';
$labels['threaded'] = 'Tráða';
$labels['showunread'] = 'Vís ólisin boð';
$labels['autoexpand_threads'] = 'Spreið boð tráðir';
$labels['do_expand'] = 'Allir tráðir';
$labels['expand_only_unread'] = 'einans við ólisin boð';
$labels['fromto'] = 'Frá/Til';
$labels['flag'] = 'Viðmerk';
$labels['attachment'] = 'Viðhefting';
$labels['nonesort'] = 'Einki';
$labels['sentdate'] = 'Sent dato';
$labels['arrival'] = 'Móttikið dato';
$labels['asc'] = 'hækkandi';
$labels['desc'] = 'lækkandi';
$labels['listcolumns'] = 'List teigar';
$labels['listsorting'] = 'Sorterar teiga';
$labels['listorder'] = 'Sorterar rekkjufylgju';
$labels['listmode'] = 'Lista vísing';
$labels['layout'] = 'Snið';
$labels['layoutwidescreen'] = 'Breiðan skíggja';
$labels['layoutdesktop'] = 'Skriviborð';
$labels['layoutlist'] = 'Listið';
$labels['folderactions'] = 'Mappu gerir...';
$labels['compact'] = 'Trýst saman';
$labels['empty'] = 'Tøm';
$labels['importmessages'] = 'Innflyt boð';
$labels['quota'] = 'Disk nýtsla';
$labels['unknown'] = 'ókent';
$labels['unlimited'] = 'óavmarka';
$labels['quotatype'] = 'Kvotu slag';
$labels['quotatotal'] = 'Mark';
$labels['quotaused'] = 'Brúkt';
$labels['quotastorage'] = 'Driv pláss';
$labels['quotamessage'] = 'Tal av boðum';
$labels['shortheaderdate'] = 'Tann $date';
$labels['shortheaderto'] = 'Til $to tann $date';
$labels['shortheaderfrom'] = 'Frá $to tann $date';
$labels['quicksearch'] = 'Skjót leiting';
$labels['searchplaceholder'] = 'Leita...';
$labels['resetsearch'] = 'Nulstilla leiting';
$labels['searchmod'] = 'Leiti minkarir';
$labels['msgtext'] = 'Øll boðini';
$labels['body'] = 'Kroppur';
$labels['type'] = 'Slag';
$labels['namex'] = 'Navn';
$labels['searchscope'] = 'Leita frá';
$labels['currentfolder'] = 'Verandi mappa';
$labels['subfolders'] = 'Hendan og mappur undir hesari';
$labels['allfolders'] = 'Allar mappur';
$labels['searchinterval-1W'] = 'eldri enn eina viku';
$labels['searchinterval-1M'] = 'eldri enn ein mána';
$labels['searchinterval-1Y'] = 'eldri enn eitt ár';
$labels['searchinterval1W'] = 'yngri enn ein vika';
$labels['searchinterval1M'] = 'yngri enn ein mána';
$labels['searchinterval1Y'] = 'yngri enn eitt ár';
$labels['openinextwin'] = 'Opna í nýggjum vindeyga';
$labels['emlsave'] = 'Heinta (.eml)';
$labels['changeformattext'] = 'Vís í reinun teksti formati';
$labels['changeformathtml'] = 'Vís í HTML formati';
$labels['editasnew'] = 'Broyt sum nýtt';
$labels['send'] = 'Send';
$labels['sendmessage'] = 'Send boð';
$labels['savemessage'] = 'Goym sum skitsa';
$labels['addattachment'] = 'Viðheft fíl';
$labels['charset'] = 'Stavusett';
$labels['editortype'] = 'Útgevara slag';
$labels['returnreceipt'] = 'Lat aftur kvittan';
$labels['dsn'] = 'Útflýggja støðu kunngerð';
$labels['mailreplyintro'] = 'Tann $date, skrivaði $sender:';
$labels['originalmessage'] = 'Uppruna boð';
$labels['selectimage'] = 'Vel mynd';
$labels['addimage'] = 'Legg aftar mynd';
$labels['selectmedia'] = 'Vel film';
$labels['addmedia'] = 'Legg aftrat film';
$labels['encrypt'] = 'Brongla';
$labels['encryptmessage'] = 'Brongla boð';
$labels['encryptmessagemailvelope'] = 'Brongla tíni boð við Mailvelo';
$labels['importpubkeys'] = 'Innflyt allmennar lyklar';
$labels['encryptedsendialog'] = 'Sendur brongla boð';
$labels['encryptandsign'] = 'Talgyld og signera';
$labels['keyid'] = 'Lykla ID';
$labels['keylength'] = 'Bit';
$labels['keyexpired'] = 'Útgingi';
$labels['keyrevoked'] = 'Sagt úr gildi';
$labels['bccinstead'] = 'Nýt Bcc';
$labels['insert'] = 'Legg inn';
$labels['recipient'] = 'Móttakari';
$labels['editidents'] = 'Broyt samleikar';
$labels['spellcheck'] = 'Stava';
$labels['checkspelling'] = 'Kanna staving';
$labels['resumeediting'] = 'Taka uppaftur skriving';
$labels['revertto'] = 'Vend aftur til';
$labels['restore'] = 'Endurstovna';
$labels['restoremessage'] = 'Endurstovna boð?';
$labels['ignore'] = 'Skúgva til viks';
$labels['responses'] = 'Svør';
$labels['insertresponse'] = 'Innset eitt svar';
$labels['manageresponses'] = 'Umsit svør';
$labels['newresponse'] = 'Stovna nýtt svar';
$labels['addresponse'] = 'Svara';
$labels['editresponse'] = 'Broyt svar';
$labels['editresponses'] = 'Broyt svør';
$labels['responsename'] = 'Navn';
$labels['responsetext'] = 'Svar tekstur';
$labels['attach'] = 'Viðheft';
$labels['attachments'] = 'Viðheftingar';
$labels['upload'] = 'Uppsend';
$labels['uploadprogress'] = '$percent ($current av $total)';
$labels['close'] = 'Lat aftur';
$labels['messageoptions'] = 'Boð valmøguleikar...';
$labels['togglecomposeoptions'] = 'Skift stovningar møguleikar';
$labels['low'] = 'Lágt';
$labels['lowest'] = 'Lágst';
$labels['normal'] = 'Vanligt';
$labels['high'] = 'Høgt';
$labels['highest'] = 'Hagst';
$labels['nosubject'] = '(einki evni)';
$labels['showimages'] = 'Vís myndir';
$labels['allow'] = 'Loyv';
$labels['alwaysshow'] = 'Vís altíð myndir frá $sender';
$labels['alwaysallow'] = 'Loyv altíð frá $sender';
$labels['isdraft'] = 'Hetta er eini skitsu boð.';
$labels['andnmore'] = '$nr meir...';
$labels['details'] = 'Upplýsingar';
$labels['togglemoreheaders'] = 'Vís meiri boð teksthøvd ';
$labels['togglefullheaders'] = 'Vel ráðan boð teksthøvd';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Reiður tekstur';
$labels['savesentmessagein'] = 'Goym boð í ';
$labels['dontsave'] = 'goym ikki';
$labels['maxuploadsize'] = 'Stórsta fílu stødd loyvd er $size';
$labels['addcc'] = 'Legg aftrat Cc';
$labels['addbcc'] = 'Legg aftrat Bcc';
$labels['addreplyto'] = 'Legg aftrat Svara-til';
$labels['addfollowupto'] = 'Legg aftrat Fylg við-til';
$labels['mdnrequest'] = 'Sendarin av hesi boð biður um at verða kunngjørdur tá ið tú lesur hesið boð. Vilt tú kunngerða sendaran?';
$labels['receiptread'] = 'Svara móttakara (les)';
$labels['yourmessage'] = 'Hetta er ein afturvend kvittan av tíni boð';
$labels['receiptnote'] = 'Gevið gætur: Hendan kvittan vísir einans á um boðini vóru sýnd á teldu mótakarans. Har er eingin trygging fyri at móttakarin hevur lisið ella skilt tað ið er í boðunum';
$labels['sendalwaysto'] = 'Send altíð til $email';
$labels['name'] = 'Fult navn';
$labels['firstname'] = 'Fornavn';
$labels['surname'] = 'Eftirnavn';
$labels['middlename'] = 'Millunnavn';
$labels['nameprefix'] = 'Forskoyti';
$labels['namesuffix'] = 'Eftirskoyti';
$labels['nickname'] = 'Eyknevni';
$labels['jobtitle'] = 'Starvsheiti';
$labels['department'] = 'Deild';
$labels['gender'] = 'Kyn';
$labels['maidenname'] = 'Gentunavn';
$labels['email'] = 'Teldupostur';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Búðstaður';
$labels['street'] = 'Gøta';
$labels['locality'] = 'Býur';
$labels['zipcode'] = 'Post kota';
$labels['region'] = 'Kommuna';
$labels['country'] = 'Land';
$labels['birthday'] = 'Føðingardagur';
$labels['anniversary'] = 'Ársdagur';
$labels['website'] = 'Heimasíða';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Notatir';
$labels['male'] = 'maður';
$labels['female'] = 'kona';
$labels['manager'] = 'Leiðari';
$labels['assistant'] = 'Hjálparfólk';
$labels['spouse'] = 'Hjúnafelagi';
$labels['allfields'] = 'Allir teigar';
$labels['search'] = 'Leita';
$labels['searchresult'] = 'Leiti úrslit';
$labels['advsearch'] = 'Framkomin leiting';
$labels['advanced'] = 'Framkomin';
$labels['other'] = 'Annað';
$labels['printcontact'] = 'Útskriva persón';
$labels['typehome'] = 'Heim';
$labels['typework'] = 'Arbeiði';
$labels['typeother'] = 'Annað';
$labels['typemobile'] = 'Fartelefon';
$labels['typemain'] = 'Høvuðs';
$labels['typehomefax'] = 'Heima faks';
$labels['typeworkfax'] = 'Arbeiðis faks';
$labels['typecar'] = 'Bilur';
$labels['typepager'] = 'Persónleitari';
$labels['typevideo'] = 'Sjónband';
$labels['typeassistant'] = 'Hjálparfólk';
$labels['typehomepage'] = 'Heimasíða';
$labels['typeblog'] = 'Bloggur';
$labels['typeprofile'] = 'Umhvarv ';
$labels['addfield'] = 'Legg aftrat teiga...';
$labels['addcontact'] = 'Stovna persón';
$labels['editcontact'] = 'Broyt persón';
$labels['contacts'] = 'Persónar';
$labels['contactproperties'] = 'Persóna eginleikar';
$labels['contactnameandorg'] = 'Navn og felag';
$labels['personalinfo'] = 'Persónligar upplýsingar';
$labels['personal'] = 'Persónlig';
$labels['contactphoto'] = 'Mynd av persóni';
$labels['edit'] = 'Broyt';
$labels['cancel'] = 'Ógilda';
$labels['save'] = 'Goym';
$labels['delete'] = 'Strika';
$labels['discard'] = 'Strika';
$labels['continue'] = 'Víðari';
$labels['ok'] = 'OK';
$labels['rename'] = 'Umdoyp';
$labels['addphoto'] = 'Legg aftrat';
$labels['replacephoto'] = 'Skift út';
$labels['uploadphoto'] = 'Uppsend mynd';
$labels['choosefile'] = 'Vel fíl...';
$labels['choosefiles'] = 'Vel fílar...';
$labels['browse'] = 'Kaga';
$labels['newcontact'] = 'Stovna nýggjan persón';
$labels['deletecontact'] = 'Strika valdir persónar';
$labels['composeto'] = 'Skriva boð til';
$labels['contactsfromto'] = 'Persónar frá $from til $to ið eru $count';
$labels['print'] = 'Skriva út';
$labels['export'] = 'Flyt út';
$labels['exportall'] = 'Flyt út alt';
$labels['exportsel'] = 'Flyt út valt';
$labels['exportvcards'] = 'Út flyt persónar við vCard slagið';
$labels['newgroup'] = 'Stovna nýggjan bólk';
$labels['addgroup'] = 'Stovna bólk';
$labels['grouprename'] = 'Umdoyp bólk';
$labels['groupdelete'] = 'Strika bólk';
$labels['groupassign'] = 'Legg til bólk';
$labels['groupremove'] = 'Strika frá bólkið';
$labels['groupremoveselected'] = 'Strika valdar persónar frá bólki';
$labels['uponelevel'] = 'Upp eitt stig';
$labels['previouspage'] = 'Vís fyrrverandi síðu';
$labels['firstpage'] = 'Vís fyrstu síðu';
$labels['nextpage'] = 'Vís næstu síðu';
$labels['lastpage'] = 'Vís seinastu síðu';
$labels['group'] = 'Bólkur';
$labels['groups'] = 'Bólkar';
$labels['listgroup'] = 'Vís bólka limir';
$labels['personaladrbook'] = 'Persónligir búðstaðir';
$labels['searchsave'] = 'Goym leiting';
$labels['searchdelete'] = 'Strika leiting';
$labels['import'] = 'Innflyt';
$labels['importcontacts'] = 'Innflyt persónar';
$labels['importfromfile'] = 'Inflyt frá fílu';
$labels['importtarget'] = 'Legg persón til';
$labels['importreplace'] = 'Skift út alt búðstaðarsavni';
$labels['importgroups'] = 'Innflyt bólka ásetan';
$labels['importgroupsall'] = 'Øll (stovna bólkar um neyðugt)';
$labels['importgroupsexisting'] = 'Einans fyri bólkar ið longu eru til';
$labels['done'] = 'Liðugt';
$labels['settingsfor'] = 'Stillingar til';
$labels['about'] = 'Um';
$labels['preferences'] = 'Vælmøguleikar';
$labels['userpreferences'] = 'Brúkara vælmøguleikar';
$labels['editpreferences'] = 'Broyt brúkara framíhjárættindi';
$labels['identities'] = 'Samleikar';
$labels['manageidentities'] = 'Umsit samleikar';
$labels['newidentity'] = 'Stovna nýggjan samleika';
$labels['addidentity'] = 'Stovna samleika';
$labels['editidentity'] = 'Broyt samleika';
$labels['identityencryption'] = 'Brongla';
$labels['preferhtml'] = 'Vís HTML';
$labels['defaultcharset'] = 'Sjálvset tekin set';
$labels['htmlmessage'] = 'HTML boð';
$labels['messagepart'] = 'Deilur';
$labels['digitalsig'] = 'Dalgylt Undirskrift';
$labels['dateformat'] = 'Dato format';
$labels['timeformat'] = 'Tíðs format';
$labels['prettydate'] = 'Pen dato';
$labels['setdefault'] = 'Set vanligt';
$labels['autodetect'] = 'Sjálvirki';
$labels['language'] = 'Mál';
$labels['timezone'] = 'Tíðarsona';
$labels['pagesize'] = 'Rekkjur per síðu';
$labels['signature'] = 'Undirskrift';
$labels['dstactive'] = 'Summartíð';
$labels['showinextwin'] = 'Opna boðí nýggjun vindeyga';
$labels['composeextwin'] = 'Stovna í nýggjum vindeyga';
$labels['htmleditor'] = 'Stovna HTML boð';
$labels['htmlonreply'] = 'til svar til HTML boð';
$labels['htmlonreplyandforward'] = 'til víðari sending ella svar til HTML boð';
$labels['htmlsignature'] = 'HTML undirskrift';
$labels['showemail'] = 'Vís teldupostar búðstað við fullum navni';
$labels['previewpane'] = 'Vís undansýningar rút';
$labels['skin'] = 'Markamóts skinn';
$labels['logoutclear'] = 'Strika Skrell tá ið tú út ritar';
$labels['logoutcompact'] = 'Trýst saman postkassa tá ið tú ritar út';
$labels['uisettings'] = 'Brúkaraøki';
$labels['serversettings'] = 'Ambætara stillingar';
$labels['mailboxview'] = 'Postkassa sjón';
$labels['mdnrequests'] = 'Bið um kvittan';
$labels['askuser'] = 'spyr me';
$labels['autosend'] = 'send kvittan';
$labels['autosendknown'] = 'send kvittan til mínir persónar, annars spyr me';
$labels['autosendknownignore'] = 'send kvittan til mínir persónar, annars skúgv til vigs';
$labels['ignorerequest'] = 'skúgva umbøn til viks';
$labels['readwhendeleted'] = 'Merk boði sum lisið á striking';
$labels['flagfordeletion'] = 'Viðmerk boði til strikingar ístaðin fyri at strika';
$labels['skipdeleted'] = 'Vís ikki strika boð';
$labels['deletealways'] = 'Um flyting av boðum til Skrell ikki riggar, strika tey so';
$labels['deletejunk'] = 'Strika boð beinleiðis í Møsn';
$labels['showremoteimages'] = 'Vís regluligar fjarmyndir';
$labels['fromknownsenders'] = 'frá ókendum sendarum';
$labels['always'] = 'altíð';
$labels['alwaysbutplain'] = 'altíð. Fyri uftan tá svara verður reinun teksti';
$labels['showinlineimages'] = 'Vís viðheftar myndir niðanfyri boðini';
$labels['autosavedraft'] = 'Goym skitsu sjálvirkandi';
$labels['everynminutes'] = 'hvønn $n minutt(ir)';
$labels['refreshinterval'] = 'Endur innles (kannað fyri nýggjum boðum, o.s.fv.)';
$labels['never'] = 'aldrin';
$labels['immediately'] = 'í stundini';
$labels['messagesdisplaying'] = 'Vísir boð';
$labels['messagescomposition'] = 'Stovnar boð';
$labels['mimeparamfolding'] = 'Viðheftingar nøvn';
$labels['2231folding'] = 'Fult RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Fult RFC 2047 (other)';
$labels['force7bit'] = 'Nýt MIME kodingar til 8-bit tekin';
$labels['savelocalstorage'] = "Goym í lokal goymslu á kaga (fyribils)";
$labels['advancedoptions'] = 'Víðkaðir valmøguleikar';
$labels['toggleadvancedoptions'] = 'Skift víðkaðar møguleikar';
$labels['focusonnewmessage'] = 'Legg dent á kaga vindeyga tá ið nýtt boð verður stovna';
$labels['checkallfolders'] = 'Kannað allar mappur fyri nýggj boð';
$labels['defaultfont'] = 'Vanligi stavsnið av HTML boði';
$labels['mainoptions'] = 'Høvuðs Vælmøguleikar';
$labels['browseroptions'] = 'Kaga Valmøguleikar';
$labels['section'] = 'Partur';
$labels['maintenance'] = 'Umsiting';
$labels['newmessage'] = 'Nýggj boð';
$labels['signatureoptions'] = 'Undirskrift vælmøguleikar';
$labels['whenreplying'] = 'Tá ið skriving verður framd';
$labels['replyempty'] = 'sitera ikki uppruna boðini';
$labels['replytopposting'] = 'byrja eini nýggj boð uppiyvir sitatinum';
$labels['replybottomposting'] = 'byrja eini nýggj boð undir sitatinum';
$labels['replyremovesignature'] = 'Tá ið svaring verðurframd, strika so uppruna sitati frá boðinum';
$labels['autoaddsignature'] = 'Legg undirskrift á sjálvirkandi';
$labels['newmessageonly'] = 'Nýggj boð einans';
$labels['replyandforwardonly'] = 'svar og víðarsendingar einans';
$labels['insertsignature'] = 'Innset undirskrift';
$labels['sigbelow'] = 'Set undirskrift undir tey siteraðu boðini';
$labels['sigseparator'] = 'Tvinga vanliga hvørviskilju í undirskriftum';
$labels['automarkread'] = 'Merk boð sum lisin';
$labels['afternseconds'] = 'eftir $n sekund';
$labels['reqmdn'] = 'Bið altíð um eina kvittan';
$labels['reqdsn'] = 'Bið altíð um status kunngerð';
$labels['replysamefolder'] = 'Koyr svar í somu mappuna ið boðini komu frá';
$labels['defaultabook'] = 'Sjálvset búðstaðar bók';
$labels['autocompletesingle'] = 'Leyp um aðrar teldupost búðstaðar í sjálvirkandi skrivingini';
$labels['listnamedisplay'] = 'Vís persónar sum ';
$labels['spellcheckbeforesend'] = 'Kannað stavuvillur áðrenn boðini verða send';
$labels['spellcheckoptions'] = 'Stavuvilli kanningar vælmøguleikar';
$labels['spellcheckignoresyms'] = 'Leyp um orð við teknum';
$labels['spellcheckignorenums'] = 'Leyp um orð við tølum';
$labels['spellcheckignorecaps'] = 'Leyp um øll orð við øll bókstavum í stórum';
$labels['addtodict'] = 'Legg aftrat orðabók';
$labels['mailtoprotohandler'] = 'Skráset samskiftisreglur handfara til mailto: leinki';
$labels['standardwindows'] = 'Handfar upplatingarvindeygu sum vanlig vindeygu';
$labels['forwardmode'] = 'Víðarsending av boðum';
$labels['inline'] = 'innanreglis';
$labels['asattachment'] = 'sum viðhefting';
$labels['replyallmode'] = 'Sjálvset gerð til [Reply all] knap';
$labels['replyalldefault'] = 'Svara øllum';
$labels['replyalllist'] = 'svara til teldupostalista einans (um funnin)';
$labels['allmessages'] = 'øll boð';
$labels['folder'] = 'Mappa';
$labels['folders'] = 'Mappur';
$labels['foldername'] = 'Mappu navn';
$labels['subscribed'] = 'Teknaður til';
$labels['messagecount'] = 'Boð';
$labels['create'] = 'Stovna';
$labels['createfolder'] = 'Stovna nýggja mappu';
$labels['managefolders'] = 'Umsit mappur';
$labels['specialfolders'] = 'Serligar Mappur';
$labels['properties'] = 'Vælmøguleikar';
$labels['folderproperties'] = 'Mappu vælmøguleikar';
$labels['parentfolder'] = 'Foreldra mappu';
$labels['location'] = 'Stað';
$labels['info'] = 'Upplýsing';
$labels['getfoldersize'] = 'Trýst fyri at seta mappu stødd';
$labels['changesubscription'] = 'Trýst fyri at broyta tekning';
$labels['foldertype'] = 'Mappu slag';
$labels['personalfolder'] = 'Einskild Mappa';
$labels['otherfolder'] = 'Mappur hjá ørðum brúkarum';
$labels['sharedfolder'] = 'Almennar mappur';
$labels['findfolders'] = 'Finn mappur';
$labels['findmail'] = 'Finn boð';
$labels['namespace.personal'] = 'Persónlig';
$labels['namespace.other'] = 'Aðrir brúkarir';
$labels['namespace.shared'] = 'Deilt';
$labels['dualuselabel'] = 'Kann bert innihalda';
$labels['dualusemail'] = 'boð';
$labels['dualusefolder'] = 'mappur';
$labels['generate'] = 'Framleið';
$labels['encryptioncreatekey'] = 'Skapa nýtt lykla par';
$labels['encryption'] = 'Brongla';
$labels['sortby'] = 'Sortera eftir';
$labels['sortasc'] = 'Sortera hækkandi';
$labels['sortdesc'] = 'Sortera lækkandi';
$labels['undo'] = 'Angra';
$labels['installedplugins'] = 'Innløgd ískoyti';
$labels['plugin'] = 'Ískoyti';
$labels['version'] = 'Útgáva';
$labels['source'] = 'Kelda';
$labels['license'] = 'Heimildarskjal';
$labels['support'] = 'Fá hjálp';
$labels['savedsearches'] = 'Goymdar leitanir';
$labels['dateformatY'] = 'ÁÁÁÁ';
$labels['dateformaty'] = 'ÁÁ';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Eingilst';
$labels['westerneuropean'] = 'Vestur Evoropeist';
$labels['easterneuropean'] = 'Estur Everopeist';
$labels['southeasterneuropean'] = 'Útsynnings Everopeist';
$labels['baltic'] = 'Eystursjógvurin';
$labels['cyrillic'] = 'Cyrillic';
$labels['arabic'] = 'Arabist';
$labels['greek'] = 'Grekst';
$labels['hebrew'] = 'Hebraiskt';
$labels['turkish'] = 'Turkist';
$labels['nordic'] = 'Norðurlengst';
$labels['thai'] = 'Tailenskt';
$labels['celtic'] = 'Keltiskt';
$labels['vietnamese'] = 'Vietmanesiskt';
$labels['japanese'] = 'Japanskt';
$labels['korean'] = 'Koreanskt';
$labels['chinese'] = 'Kinesiskt';
$labels['arialabeltopnav'] = 'Vindeyga kontro';
$labels['arialabeltasknav'] = 'Uppgávur forrits';
$labels['arialabeltoolbar'] = 'Amboðsbjálki';
$labels['arialabelactivetask'] = 'Tendra uppgáva';
$labels['arialabelmessagessearchfilter'] = 'Telduposta skráinga filtur';
$labels['arialabelmailsearchform'] = 'Teldupost boð leiti frymil';
$labels['arialabelcontactsearchform'] = 'Persóna leiti felt';
$labels['arialabelmailquicksearchbox'] = 'Teldupost leiti felt';
$labels['arialabelquicksearchbox'] = 'Leitingar orð';
$labels['arialabelfoldersearchfilter'] = 'Mappu skráingingar filtur';
$labels['arialabelfoldersearchform'] = 'Mappu leiti frymil';
$labels['arialabelfolderlist'] = 'Teldupost mappu val';
$labels['arialabelmessagelist'] = 'Telduposta boð skráing';
$labels['arialabelmailpreviewframe'] = 'Brot av boðið';
$labels['arialabelmailboxmenu'] = 'Mappu gerða valmynd';
$labels['arialabellistselectmenu'] = 'Vís valdu menu';
$labels['arialabelthreadselectmenu'] = 'Tráa skráingar valmynd';
$labels['arialabelmessagelistoptions'] = 'Boð skrá vísnáður og sorteringa valmøguleikar';
$labels['arialabelmailimportdialog'] = 'Influttning av boð dialogur';
$labels['arialabelmessagenav'] = 'Boð navigering';
$labels['arialabelmessagebody'] = 'Innihald í boðið';
$labels['arialabelmessageactions'] = 'Boð gerðir';
$labels['arialabelcontactquicksearch'] = 'Persóna leiti felt';
$labels['arialabelcontactsearchbox'] = 'Persón leiti orð';
$labels['arialabelmessageheaders'] = 'Teksthøvd av boð';
$labels['arialabelforwardingoptions'] = 'Víðarisend møguleikar';
$labels['arialabelreplyalloptions'] = 'Valmøguleikar til at svara øllum';
$labels['arialabelmoremessageactions'] = 'Meiri valmøguleikar til boð gerðir';
$labels['arialabelmarkmessagesas'] = 'Merk valdu boð sum...';
$labels['arialabelcomposeoptions'] = 'Stovningar møguleikar';
$labels['arialabelresponsesmenu'] = 'Skapilón svar valmynd';
$labels['arialabelattachmentuploadform'] = 'Viðheftingar uppsendingar frymil';
$labels['arialabelattachmentmenu'] = 'Viðheftingar valmøguleikar';
$labels['arialabelmailtomenu'] = 'Teldupost búðstaðar valmøguleikar';
$labels['arialabelattachmentpreview'] = 'Brot av víðheftingum';
$labels['ariasummarycomposecontacts'] = 'Listi av persónum og bólkum at velja sum móttakarar';
$labels['arialabelcontactexportoptions'] = 'Valmøguleikar fyri persóna útflytan';
$labels['arialabelabookgroupoptions'] = 'Bústaðarsavn/bólka valmøguleikar';
$labels['arialabelpreferencesform'] = 'Stillinga frymil';
$labels['arialabelidentityeditfrom'] = 'Samleika broytingar formur';
$labels['arialabelresponseeditfrom'] = 'Svar broytingar frymil';
$labels['arialabelsearchterms'] = 'Leiti orð';
$labels['arialabelimagetools'] = 'Mynda tól';
$labels['helplistnavigation'] = 'Vís knappaborð sniðvegir';
$labels['helplistkeyboardnavigation'] = "Pílar upp/niður: Flyt rekkju
Millumglopp: Vel verandi rekkju
Shift + upp/niður: Vel fleiri rekkjur uppi yvir/niðri undir
Ctrl + millumglopp: Legg verandi rekkju aftrat/tak frá ";
$labels['helplistkeyboardnavmessages'] = "Pílar vinstru/høgru: vaksa/minka boð trá (í tráar hátt einans)
Enter: Opna valdu boð
Delete: Flyt valdu boð til skrelluspann.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Opna verandi persón";
