<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Argyf';
$labels['buttontitle'] = 'Pleats yn argyf';
$labels['archived'] = 'Mei sukses nei argyf ferpleatst';
$labels['archivedreload'] = 'Mei sukses nei argyf ferpleatst. Ferfarskje dizze side om de nije argyf mappen te sjen.';
$labels['archiveerror'] = 'Guon berjochten koenen net ferpleatst wurde nei it argyf';
$labels['archivefolder'] = 'Argyf';
$labels['settingstitle'] = 'Argyf';
$labels['archivetype'] = 'Ferdiel argyf troch';
$labels['archivetypeyear'] = 'Jier (bygelyks Argyf/2012)';
$labels['archivetypemonth'] = 'Moanne (bygelyks Argyf/2012/06)';
$labels['archivetypefolder'] = 'Oarspronklike map';
$labels['archivetypesender'] = 'Stjoerder e-post';
$labels['unkownsender'] = 'ûnbekend';
$labels['readonarchive'] = 'Markearje it berjocht as lêzen op argyf';
