<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtros';
$labels['managefilters'] = 'Alministrar filtros de corréu entrante';
$labels['filtername'] = 'Nome del filtru';
$labels['newfilter'] = 'Filtru nuevu';
$labels['filteradd'] = 'Amestar filtru';
$labels['filterdel'] = 'Desaniciar filtru';
$labels['scope'] = 'Algame';
$labels['moveup'] = 'Mover arriba';
$labels['movedown'] = 'Mover abaxo';
$labels['filterany'] = 'tolos mensaxes';
$labels['filtercontains'] = 'contien';
$labels['filternotcontains'] = 'nun contien';
$labels['filteris'] = 'ye igual a';
$labels['filterisnot'] = 'nun ye igual a';
$labels['filterexists'] = 'esiste';
$labels['filternotexists'] = 'nun esiste';
$labels['filtermatches'] = 'espresiones que concasen';
$labels['filternotmatches'] = 'espresiones que nun concasen';
$labels['addrule'] = 'Amestar regla';
$labels['delrule'] = 'Desaniciar regla';
$labels['messagemoveto'] = 'Mover mensaxe a';
$labels['messageredirect'] = 'Redireicionar mensaxe a';
$labels['messagecopyto'] = 'Copiar mensaxe a';
$labels['messagedelete'] = 'Desaniciar mensaxe';
$labels['messagesrules'] = 'Pa corréu entrante:';
$labels['messagesactions'] = '...executar les aiciones siguientes:';
$labels['add'] = 'Amestar';
$labels['del'] = 'Desaniciar';
$labels['sender'] = 'Remitente';
$labels['enable'] = 'Habilitar/Deshabilitar';
$labels['flagread'] = 'Lleer';
$labels['flagdeleted'] = 'Desaniciáu';
$labels['flaganswered'] = 'Respondíu';
$labels['flagflagged'] = 'Etiquetaos';
$labels['notifymethodmailto'] = 'Corréu';
$labels['notifymethodtel'] = 'Teléfonu';
$labels['datetest'] = 'Data';
$labels['advancedopts'] = 'Opciones avanzaes';
$labels['body'] = 'Cuerpu';
$labels['spamtestequals'] = 'ye igual a';
$labels['spamtestnotequals'] = 'nun ye igual a';
$labels['vacation.subject'] = 'Asuntu';
$labels['vacation.body'] = 'Cuerpu';
$labels['vacation.keep'] = 'Caltener';
