<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Parvekirin';
$labels['myrights'] = 'Mafên Têketinê';
$labels['username'] = 'Bikarhêner:';
$labels['advanced'] = 'Moda pêşketî';
$labels['add'] = 'Tev bike';
$labels['newuser'] = 'Têketinek zêde bike';
$labels['editperms'] = 'Destûrdayînan Sererast Bike';
$labels['actions'] = 'Digihîje tevgerên çê..';
$labels['anyone'] = 'Hemû bikarhêner (her kes)';
$labels['anonymous'] = 'Mêvan (gelêrî)';
$labels['identifier'] = 'Danasîner';
$labels['acll'] = 'Lê bigere';
$labels['aclr'] = 'Peyaman bixwîne';
$labels['aclw'] = 'Alayan binivîse';
$labels['acli'] = 'Têxe (Heman bike li)';
$labels['aclp'] = 'Şandî';
$labels['aclc'] = 'Bindosyeyan çêke';
$labels['aclk'] = 'Bindosyeyan çêke';
$labels['acld'] = 'Peyaman binivîse';
$labels['aclt'] = 'Peyaman jê bibe';
$labels['acle'] = 'Jê derxîne';
$labels['aclx'] = 'Dosyeyê jê bibe';
$labels['acla'] = 'Birêvebir';
$labels['acln'] = 'Bi nîşeyan peyaman rave bike';
$labels['aclfull'] = 'Tam venêrîn';
$labels['aclother'] = 'Ên din';
$labels['aclread'] = 'Bixwîne';
$labels['aclwrite'] = 'Binivîse';
$labels['acldelete'] = 'Jê bibe';
$labels['shortacll'] = 'Lê bigere';
$labels['shortaclr'] = 'Bixwîne';
$labels['shortacls'] = 'Bihêle';
$labels['shortaclw'] = 'Binivîse';
$labels['shortacli'] = 'Tev bike';
$labels['shortaclp'] = 'Bişîne';
$labels['shortaclc'] = 'Çêke';
$labels['shortaclk'] = 'Çêke';
$labels['shortacld'] = 'Jê bibe';
$labels['shortaclt'] = 'Jê bibe';
$labels['shortacle'] = 'Jê derxîne';
$labels['shortaclx'] = 'Dosye-jêbirin';
$labels['shortacla'] = 'Bikarhêner';
$labels['shortacln'] = 'Bi nîşeyan rave bike';
$labels['shortaclother'] = 'Ên din';
$labels['shortaclread'] = 'Bixwîne';
$labels['shortaclwrite'] = 'Binivîse';
$labels['shortacldelete'] = 'Jê bibe';
$labels['longaclr'] = 'Dosye ji bo xwendinê dikare bê vekirin';
$labels['longacls'] = 'Alaya peyamên Dîtî dikare bête guhartin';
$labels['longaclc'] = 'Dosye dikarin bin vê dosyeyê bêne çêkirin (an jî binavkirin)';
$labels['longaclk'] = 'Dosye dikarin bin vê dosyeyê bêne çêkirin (an jî binavkirin)';
$labels['longaclx'] = 'Dosye dikare bê jêbirin an jî binavkirin';
$labels['longacla'] = 'Mafê gihîştina dosyeyê dikare bê guhartin';
$labels['longaclfull'] = 'Tam venêrîn bi birêvebirina dosyeyê';
$labels['longaclread'] = 'Dosye ji bo xwendinê dikare bê vekirin';
$labels['longaclwrite'] = 'Peyam dikarin kopiyî dosyeyê bên kirin, nîşankirin, nivîsandin.';
$labels['longacldelete'] = 'Hêmî peyam dikarin werin jêbirin';
$labels['longaclother'] = 'Mafên din ên têketinê';
$labels['ariasummaryacltable'] = 'Lîsteya mafên têketinê';
$labels['arialabelaclactions'] = 'Tevgeran liste bike';
$labels['arialabelaclform'] = 'Forma mafên têketinê';
$messages['deleting'] = 'Mafên têketinê tên jêbirin...';
$messages['saving'] = 'Mafên têketinê tên tomarkirin...';
$messages['updatesuccess'] = 'Mafên têketinê bi serkeftin hatin guhartin';
$messages['deletesuccess'] = 'Mafên têketinê bi serkeftin hatin jêbirin';
$messages['createsuccess'] = 'Mafên têketinê bi serkeftin hatin tevkirin';
$messages['updateerror'] = 'Nûkirina mafên têketinê bigire';
$messages['deleteerror'] = 'Jêbirina mafên têketinê bigire';
$messages['createerror'] = 'Tevkirina mafên têketinê bigire';
$messages['deleteconfirm'] = 'Tu ewle yî, dixwazî mafên têketinê yên bikarhênerê(n) bijartî rakî?';
$messages['norights'] = 'Tu maf nehat diyarkirin!';
$messages['nouser'] = 'Tu bikarhêner nehat diyarkirin!';
