<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Välkommen till $product';
$labels['username'] = 'Användarnamn';
$labels['password'] = 'Lösenord';
$labels['server'] = 'Server';
$labels['login'] = 'Logga in';
$labels['oauthlogin'] = 'Logga in med $provider';
$labels['menu'] = 'Meny';
$labels['logout'] = 'Logga ut';
$labels['mail'] = 'Meddelanden';
$labels['settings'] = 'Inställningar';
$labels['addressbook'] = 'Adressbok';
$labels['darkmode'] = 'Mörkt läge';
$labels['lightmode'] = 'Ljust läge';
$labels['inbox'] = 'Inkorg';
$labels['drafts'] = 'Utkast';
$labels['sent'] = 'Skickat';
$labels['trash'] = 'Papperskorg';
$labels['junk'] = 'Skräp';
$labels['show_real_foldernames'] = 'Visa verkliga namn på särskilda mappar';
$labels['subject'] = 'Ämne';
$labels['from'] = 'Från';
$labels['sender'] = 'Avsändare';
$labels['to'] = 'Mottagare';
$labels['cc'] = 'Kopia';
$labels['bcc'] = 'Dold kopia';
$labels['replyto'] = 'Svar till';
$labels['followupto'] = 'Uppföljning till';
$labels['date'] = 'Datum';
$labels['size'] = 'Storlek';
$labels['priority'] = 'Prioritet';
$labels['organization'] = 'Organisation';
$labels['readstatus'] = 'Lässtatus';
$labels['listoptions'] = 'Listalternativ...';
$labels['listoptionstitle'] = 'Listalternativ';
$labels['mailboxlist'] = 'Mappar';
$labels['messagesfromto'] = 'Meddelande $from till $to av $count';
$labels['threadsfromto'] = 'Tråd $from till $to av $count';
$labels['messagenrof'] = 'Meddelande $nr av $count';
$labels['fromtoshort'] = '$from – $to av $count';
$labels['copy'] = 'Kopiera';
$labels['move'] = 'Flytta';
$labels['moveto'] = 'Flytta till...';
$labels['copyto'] = 'Kopiera till...';
$labels['download'] = 'Hämta';
$labels['open'] = 'Öppna';
$labels['showattachment'] = 'Visa';
$labels['showanyway'] = 'Visa det ändå';
$labels['filename'] = 'Filnamn';
$labels['filesize'] = 'Filstorlek';
$labels['addtoaddressbook'] = 'Lägg till i adressbok';
$labels['sun'] = 'sön';
$labels['mon'] = 'mån';
$labels['tue'] = 'tis';
$labels['wed'] = 'ons';
$labels['thu'] = 'tor';
$labels['fri'] = 'fre';
$labels['sat'] = 'lör';
$labels['sunday'] = 'söndag';
$labels['monday'] = 'måndag';
$labels['tuesday'] = 'tisdag';
$labels['wednesday'] = 'onsdag';
$labels['thursday'] = 'torsdag';
$labels['friday'] = 'fredag';
$labels['saturday'] = 'lördag';
$labels['jan'] = 'jan';
$labels['feb'] = 'feb';
$labels['mar'] = 'mar';
$labels['apr'] = 'apr';
$labels['may'] = 'maj';
$labels['jun'] = 'jun';
$labels['jul'] = 'jul';
$labels['aug'] = 'aug';
$labels['sep'] = 'sep';
$labels['oct'] = 'okt';
$labels['nov'] = 'nov';
$labels['dec'] = 'dec';
$labels['longjan'] = 'januari';
$labels['longfeb'] = 'februari';
$labels['longmar'] = 'mars';
$labels['longapr'] = 'april';
$labels['longmay'] = 'maj';
$labels['longjun'] = 'juni';
$labels['longjul'] = 'juli';
$labels['longaug'] = 'augusti';
$labels['longsep'] = 'september';
$labels['longoct'] = 'oktober';
$labels['longnov'] = 'november';
$labels['longdec'] = 'december';
$labels['today'] = 'idag';
$labels['refresh'] = 'Uppdatera';
$labels['checkmail'] = 'Hämta nya meddelanden';
$labels['compose'] = 'Skriv';
$labels['writenewmessage'] = 'Skapa ett nytt meddelande';
$labels['reply'] = 'Svara';
$labels['replytomessage'] = 'Svara avsändaren';
$labels['replytoallmessage'] = 'Svara avsändaren och alla mottagare';
$labels['replyall'] = 'Svara alla';
$labels['replylist'] = 'Svara lista';
$labels['forward'] = 'Vidarebefordra';
$labels['forwardinline'] = 'Vidarebefordra infogat';
$labels['forwardattachment'] = 'Vidarebefordra som bilaga';
$labels['forwardmessage'] = 'Vidarebefordra meddelandet';
$labels['bouncemsg'] = 'Skicka igen (studsa)';
$labels['bounce'] = 'Skicka igen';
$labels['deletemessage'] = 'Ta bort meddelandet';
$labels['movemessagetotrash'] = 'Flytta meddelandet till Papperskorg';
$labels['printmessage'] = 'Skriv ut det här meddelandet';
$labels['previousmessage'] = 'Visa föregående meddelande';
$labels['firstmessage'] = 'Visa första meddelandet';
$labels['nextmessage'] = 'Visa nästa meddelande';
$labels['lastmessage'] = 'Visa sista meddelandet';
$labels['backtolist'] = 'Bakåt till meddelandelistan';
$labels['viewsource'] = 'Visa källkod';
$labels['mark'] = 'Markera';
$labels['markmessages'] = 'Markera meddelanden';
$labels['markread'] = 'Läst';
$labels['markunread'] = 'Oläst';
$labels['markflagged'] = 'Flaggat';
$labels['markunflagged'] = 'Oflaggat';
$labels['markundeleted'] = 'Inte borttaget';
$labels['moreactions'] = 'Fler åtgärder...';
$labels['markallread'] = 'Markera alla som lästa';
$labels['folders-cur'] = 'Markerad mapp';
$labels['folders-sub'] = 'Markerad mapp med undermappar';
$labels['folders-all'] = 'Alla mappar';
$labels['more'] = 'Fler';
$labels['back'] = 'Bakåt';
$labels['options'] = 'Alternativ';
$labels['composeoptions'] = 'Skapandeinställningar';
$labels['optionsandattachments'] = 'Alternativ och bilagor';
$labels['actions'] = 'Funktioner';
$labels['first'] = 'Första';
$labels['last'] = 'Sista';
$labels['previous'] = 'Föregående';
$labels['next'] = 'Nästa';
$labels['select'] = 'Välj';
$labels['selection'] = 'Markering';
$labels['all'] = 'Alla';
$labels['none'] = 'Inga';
$labels['currpage'] = 'Aktuell sida';
$labels['isread'] = 'Läst';
$labels['unread'] = 'Olästa';
$labels['flagged'] = 'Flaggade';
$labels['unflagged'] = 'Inte flaggat';
$labels['unanswered'] = 'Obesvarade';
$labels['withattachment'] = 'Med bilaga';
$labels['deleted'] = 'Borttagna';
$labels['undeleted'] = 'Inte borttagna';
$labels['replied'] = 'Besvarat';
$labels['forwarded'] = 'Vidareskickat';
$labels['invert'] = 'Invertera';
$labels['filter'] = 'Filter';
$labels['list'] = 'Lista';
$labels['threads'] = 'Trådar';
$labels['expand-all'] = 'Visa alla';
$labels['expand-unread'] = 'Visa olästa';
$labels['collapse-all'] = 'Dölj alla';
$labels['threaded'] = 'Trådat';
$labels['showunread'] = 'Visa olästa meddelanden';
$labels['autoexpand_threads'] = 'Visa trådade meddelanden';
$labels['do_expand'] = 'Alla trådar';
$labels['expand_only_unread'] = 'Trådar med olästa meddelanden';
$labels['fromto'] = 'Från/Till';
$labels['flag'] = 'Flagga';
$labels['attachment'] = 'Bilaga';
$labels['nonesort'] = 'Ingen';
$labels['sentdate'] = 'Datum skickat';
$labels['arrival'] = 'Datum mottaget';
$labels['asc'] = 'Stigande';
$labels['desc'] = 'Fallande';
$labels['listcolumns'] = 'Kolumner';
$labels['listsorting'] = 'Sortering';
$labels['listorder'] = 'Ordning';
$labels['listmode'] = 'Visningsläge';
$labels['lmode'] = 'Listläge';
$labels['layout'] = 'Layout';
$labels['layoutwidescreen'] = 'Bred skärm';
$labels['layoutdesktop'] = 'Skrivbord';
$labels['layoutlist'] = 'Lista';
$labels['layoutwidescreendesc'] = 'Bred skärm (visning i 3 kolumner)';
$labels['layoutdesktopdesc'] = 'Skrivbord (bred lista med förhandsvisning nedanför)';
$labels['layoutlistdesc'] = 'Lista (utan förhandsvisning)';
$labels['folderactions'] = 'Mappåtgärder...';
$labels['compact'] = 'Packa';
$labels['empty'] = 'Töm';
$labels['importmessages'] = 'Importera meddelanden';
$labels['mailimportdesc'] = 'Meddelanden kan laddas upp från filer i formatet <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> eller formatet <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Flera filer kan komprimeras till zip-arkiv.';
$labels['quota'] = 'Diskutrymme';
$labels['unknown'] = 'okänt';
$labels['unlimited'] = 'obegränsat';
$labels['quotatype'] = 'Typ av kvot';
$labels['quotatotal'] = 'Gräns';
$labels['quotaused'] = 'Utnyttjad';
$labels['quotastorage'] = 'Storlek';
$labels['quotamessage'] = 'Antal meddelanden';
$labels['shortheaderdate'] = 'På $date';
$labels['shortheaderto'] = 'Till $to på $date';
$labels['shortheaderfrom'] = 'Från $from på $date';
$labels['quicksearch'] = 'Snabbsök';
$labels['searchplaceholder'] = 'Sök...';
$labels['resetsearch'] = 'Återställ sökning';
$labels['searchmod'] = 'Sökalternativ';
$labels['msgtext'] = 'Hela meddelandet';
$labels['body'] = 'Innehåll';
$labels['type'] = 'Typ';
$labels['namex'] = 'Namn';
$labels['searchscope'] = 'Sökomfattning';
$labels['currentfolder'] = 'Aktuell mapp';
$labels['subfolders'] = 'Denna och undermappar';
$labels['allfolders'] = 'Alla mappar';
$labels['searchinterval-1W'] = 'äldre än en vecka';
$labels['searchinterval-1M'] = 'äldre än en månad';
$labels['searchinterval-1Y'] = 'äldre än ett år';
$labels['searchinterval1W'] = 'nyare än en vecka';
$labels['searchinterval1M'] = 'nyare än en månad';
$labels['searchinterval1Y'] = 'nyare än ett år';
$labels['openinextwin'] = 'Öppna i nytt fönster';
$labels['emlsave'] = 'Hämta';
$labels['changeformattext'] = 'Visa i text-format';
$labels['changeformathtml'] = 'Visa i HTML-format';
$labels['editasnew'] = 'Redigera som nytt';
$labels['send'] = 'Skicka';
$labels['sendmessage'] = 'Skicka meddelande';
$labels['savemessage'] = 'Spara utkast';
$labels['addattachment'] = 'Bifoga fil';
$labels['charset'] = 'Teckenkodning';
$labels['editortype'] = 'Textredigerare';
$labels['returnreceipt'] = 'Mottagarkvitto';
$labels['dsn'] = 'Leveransstatusmeddelande';
$labels['keepformatting'] = 'Behåll formatering';
$labels['mailreplyintro'] = '$date skrev $sender:';
$labels['originalmessage'] = 'Ursprungligt meddelande';
$labels['selectimage'] = 'Välj bild';
$labels['addimage'] = 'Lägg till bild';
$labels['selectmedia'] = 'Välj film';
$labels['addmedia'] = 'Lägg till film';
$labels['encrypt'] = 'Kryptera';
$labels['encryptmessage'] = 'Kryptera meddelande';
$labels['encryptmessagemailvelope'] = 'Kryptera meddelande med Mailvelope';
$labels['importpubkeys'] = 'Importera offentliga nycklar';
$labels['encryptedsendialog'] = 'Skickar krypterat meddelande';
$labels['encryptandsign'] = 'Kryptera och signera';
$labels['keyid'] = 'Nyckel-ID';
$labels['keylength'] = 'Bitar';
$labels['keyexpired'] = 'Utgången';
$labels['keyrevoked'] = 'Upphävd';
$labels['bccinstead'] = 'Använd Dold kopia';
$labels['addheader'] = 'Lägg till mottagare (meddelandeinfo)';
$labels['insert'] = 'Infoga';
$labels['insertcontact'] = 'Infoga kontakt(er)';
$labels['recipient'] = 'Mottagare';
$labels['recipientedit'] = 'Ändra mottagare';
$labels['editidents'] = 'Ändra identiteter';
$labels['spellcheck'] = 'Rättstava';
$labels['checkspelling'] = 'Kontrollera stavning';
$labels['resumeediting'] = 'Återuppta redigering';
$labels['revertto'] = 'Återgå till';
$labels['restore'] = 'Återskapa';
$labels['restoremessage'] = 'Återskapa meddelande?';
$labels['ignore'] = 'Ignorera';
$labels['responses'] = 'Responser';
$labels['insertresponse'] = 'Infoga respons';
$labels['manageresponses'] = 'Hantera responser';
$labels['newresponse'] = 'Ny respons';
$labels['addresponse'] = 'Lägg till respons';
$labels['editresponse'] = 'Ändra respons';
$labels['editresponses'] = 'Ändra responser';
$labels['responsename'] = 'Responsnamn';
$labels['responsetext'] = 'Responstext';
$labels['attach'] = 'Bifoga';
$labels['attachments'] = 'Bilagor';
$labels['upload'] = 'Bifoga';
$labels['uploadprogress'] = '$percent ($current av $total)';
$labels['close'] = 'Stäng';
$labels['messageoptions'] = 'Meddelandealternativ...';
$labels['togglecomposeoptions'] = 'Växla skapandeinställningar';
$labels['attachmentrename'] = 'Ändra bilagans namn';
$labels['low'] = 'Låg';
$labels['lowest'] = 'Lägst';
$labels['normal'] = 'Normal';
$labels['high'] = 'Hög';
$labels['highest'] = 'Högst';
$labels['nosubject'] = '(inget ämne)';
$labels['showimages'] = 'Visa bilder';
$labels['allow'] = 'Tillåt';
$labels['alwaysshow'] = 'Visa alltid bilder från $sender';
$labels['alwaysallow'] = 'Tillåt alltid från $sender';
$labels['isdraft'] = 'Detta meddelande är ett utkast.';
$labels['andnmore'] = '$nr fler...';
$labels['details'] = 'Detaljerad information';
$labels['summary'] = 'Sammanfattning';
$labels['headers'] = 'Meddelandeinfo';
$labels['allheaders'] = 'All meddelandeinfo...';
$labels['togglemoreheaders'] = 'Växla ytterligare meddelandeinfo';
$labels['togglefullheaders'] = 'Växla teknisk meddelandeinfo';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Oformatterad text';
$labels['savesentmessagein'] = 'Spara skickat meddelande i';
$labels['dontsave'] = 'Spara inte';
$labels['maxuploadsize'] = 'Tillåten filstorlek är $size';
$labels['addcc'] = 'Kopia';
$labels['addbcc'] = 'Dold kopia';
$labels['addreplyto'] = 'Svar till';
$labels['addfollowupto'] = 'Uppföljning till';
$labels['sendreceipt'] = 'Skicka läskvitto?';
$labels['mdnrequest'] = 'Avsändaren har begärt mottagarkvitto för det här meddelandet. Vill du skicka ett mottagarkvitto?';
$labels['receiptread'] = 'Mottagarkvitto (läst)';
$labels['yourmessage'] = 'Det här är ett mottagarkvitto för ditt meddelande';
$labels['receiptnote'] = 'Notera: Mottagarkvittot innebär bara att meddelandet visats på mottagarens dator. Därmed finns ingen garanti att mottagaren har läst och förstått meddelandet.';
$labels['sendalwaysto'] = 'Skicka alltid till $email';
$labels['zoomin'] = 'Zooma in';
$labels['zoomout'] = 'Zooma ut';
$labels['rotate'] = 'Rotera';
$labels['increaseimage'] = 'Öka bildstorlek';
$labels['decreaseimage'] = 'Minska bildstorlek';
$labels['rotateimage'] = 'Rotera bild';
$labels['showtools'] = 'Visa bildverktyg';
$labels['hidetools'] = 'Göm bildverktyg';
$labels['name'] = 'Namn';
$labels['firstname'] = 'Förnamn';
$labels['surname'] = 'Efternamn';
$labels['middlename'] = 'Mellannamn';
$labels['nameprefix'] = 'Prefix';
$labels['namesuffix'] = 'Suffix';
$labels['nickname'] = 'Smeknamn';
$labels['jobtitle'] = 'Titel';
$labels['department'] = 'Avdelning';
$labels['gender'] = 'Kön';
$labels['maidenname'] = 'Flicknamn';
$labels['email'] = 'Mailadress';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Postadress';
$labels['street'] = 'Gata';
$labels['locality'] = 'Ort';
$labels['zipcode'] = 'Postnummer';
$labels['region'] = 'Region';
$labels['country'] = 'Land';
$labels['birthday'] = 'Födelsedag';
$labels['anniversary'] = 'Årsdag';
$labels['website'] = 'Webbplats';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Anteckningar';
$labels['male'] = 'Man';
$labels['female'] = 'Kvinna';
$labels['manager'] = 'Chef';
$labels['assistant'] = 'Assistent';
$labels['spouse'] = 'Make/Maka';
$labels['allfields'] = 'Alla fält';
$labels['search'] = 'Sök';
$labels['searchresult'] = 'Sökresultat';
$labels['advsearch'] = 'Avancerad sökning';
$labels['advanced'] = 'Avancerad';
$labels['other'] = 'Annat';
$labels['printcontact'] = 'Skriv ut kontakt';
$labels['qrcode'] = 'QR-kod';
$labels['typehome'] = 'Hem';
$labels['typework'] = 'Arbete';
$labels['typeother'] = 'Annat';
$labels['typemobile'] = 'Mobil';
$labels['typemain'] = 'Huvudsakligt';
$labels['typehomefax'] = 'Fax hem';
$labels['typeworkfax'] = 'Fax arbete';
$labels['typecar'] = 'Bil';
$labels['typepager'] = 'Personsökare';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Assistent';
$labels['typehomepage'] = 'Webbplats';
$labels['typeblog'] = 'Blogg';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Lägg till fält...';
$labels['addcontact'] = 'Lägg till kontakt';
$labels['editcontact'] = 'Ändra kontakt';
$labels['contacts'] = 'Kontakter';
$labels['contactproperties'] = 'Kontaktegenskaper';
$labels['contactnameandorg'] = 'Namn och organisation';
$labels['personalinfo'] = 'Personlig information';
$labels['personal'] = 'Personliga';
$labels['contactphoto'] = 'Kontaktfoto';
$labels['edit'] = 'Redigera';
$labels['cancel'] = 'Avbryt';
$labels['save'] = 'Spara';
$labels['delete'] = 'Ta bort';
$labels['discard'] = 'Förkasta';
$labels['continue'] = 'Fortsätt';
$labels['ok'] = 'OK';
$labels['rename'] = 'Ändra namn';
$labels['addphoto'] = 'Lägg till';
$labels['replacephoto'] = 'Ersätt';
$labels['uploadphoto'] = 'Ladda upp foto';
$labels['choosefile'] = 'Välj fil...';
$labels['choosefiles'] = 'Välj filer...';
$labels['browse'] = 'Bläddra';
$labels['newcontact'] = 'Ny kontakt';
$labels['deletecontact'] = 'Ta bort vald kontakt';
$labels['composeto'] = 'Nytt meddelande till';
$labels['contactsfromto'] = 'Kontakt $from till $to av $count';
$labels['print'] = 'Skriv ut';
$labels['export'] = 'Exportera';
$labels['exportall'] = 'Exportera alla';
$labels['exportsel'] = 'Exportera markerade';
$labels['exportvcards'] = 'Exportera kontakter';
$labels['newgroup'] = 'Ny grupp';
$labels['addgroup'] = 'Lägg till grupp';
$labels['grouprename'] = 'Ändra gruppnamn';
$labels['groupdelete'] = 'Ta bort grupp';
$labels['groupassign'] = 'Lägg in i grupp...';
$labels['groupremove'] = 'Ta bort från grupp';
$labels['groupremoveselected'] = 'Ta bort markerade kontakter från gruppen';
$labels['uponelevel'] = 'Upp en nivå';
$labels['previouspage'] = 'Visa föregående sida';
$labels['firstpage'] = 'Visa första sidan';
$labels['nextpage'] = 'Visa nästa sida';
$labels['lastpage'] = 'Visa sista sidan';
$labels['group'] = 'Grupp';
$labels['groups'] = 'Kontaktgrupper';
$labels['listgroup'] = 'Visa gruppmedlemmar';
$labels['personaladrbook'] = 'Personliga adresser';
$labels['searchsave'] = 'Spara sökning';
$labels['searchdelete'] = 'Ta bort sökning';
$labels['import'] = 'Importera';
$labels['importcontacts'] = 'Importera kontakter';
$labels['importfromfile'] = 'Importera från fil';
$labels['importtarget'] = 'Lägg till kontakter i';
$labels['importreplace'] = 'Ersätt samtliga kontakter i adressboken';
$labels['importgroups'] = 'Importera grupptillhörigheter';
$labels['importgroupsall'] = 'Alla (skapa grupper om nödvändigt)';
$labels['importgroupsexisting'] = 'Endast till befintliga grupper';
$labels['importdesc'] = 'Kontakter kan importeras från en befintlig adressbok.<br/>Programmet stödjer inläsning av kontakter i formatet <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> eller formatet CSV (kommaseparerad data).';
$labels['importmapdesc'] = 'Bekräfta att fältkopplingarna nedan är korrekta innan du fortsätter med importen av CSV-filen.';
$labels['fieldnotmapped'] = 'Fältet är inte kopplat (importeras inte)';
$labels['skipheader'] = 'Importera inte första raden (rubriker)';
$labels['done'] = 'Klart';
$labels['settingsfor'] = 'Inställningar för';
$labels['about'] = 'Om';
$labels['preferences'] = 'Inställningar';
$labels['userpreferences'] = 'Användarinställningar';
$labels['editpreferences'] = 'Ändra användarinställningar';
$labels['identities'] = 'Identiteter';
$labels['manageidentities'] = 'Hantera identiteter';
$labels['newidentity'] = 'Ny identitet';
$labels['addidentity'] = 'Lägg till identitet';
$labels['editidentity'] = 'Ändra identitet';
$labels['identityencryption'] = 'Kryptering';
$labels['preferhtml'] = 'Visa meddelanden i HTML-format';
$labels['defaultcharset'] = 'Förvald teckenkodning';
$labels['htmlmessage'] = 'HTML-meddelande';
$labels['messagepart'] = 'Del';
$labels['digitalsig'] = 'Digital signatur';
$labels['dateformat'] = 'Datumformat';
$labels['timeformat'] = 'Tidformat';
$labels['prettydate'] = 'Fina datum';
$labels['setdefault'] = 'Sätt som förval';
$labels['autodetect'] = 'Automatiskt';
$labels['language'] = 'Språk';
$labels['timezone'] = 'Tidszon';
$labels['pagesize'] = 'Rader per sida';
$labels['signature'] = 'Signatur';
$labels['dstactive'] = 'Sommartid';
$labels['showinextwin'] = 'Öppna i nytt fönster';
$labels['composeextwin'] = 'Skriv i nytt fönster';
$labels['htmleditor'] = 'Skriv meddelanden i HTML-format';
$labels['htmlonreply'] = 'Endast vid svar på meddelande i HTML-format';
$labels['htmlonreplyandforward'] = 'Vid svar på eller vidareskickande av meddelande i HTML-format';
$labels['htmlsignature'] = 'HTML-signatur';
$labels['showemail'] = 'Visa namn och adress';
$labels['previewpane'] = 'Visa meddelandefältet';
$labels['skin'] = 'Stilmall för användargränssnitt';
$labels['logoutclear'] = 'Töm Papperskorg vid utloggning';
$labels['logoutcompact'] = 'Packa Inkorg vid utloggning';
$labels['uisettings'] = 'Användargränssnitt';
$labels['serversettings'] = 'Serverinställningar';
$labels['mailboxview'] = 'Hantering av meddelanden';
$labels['mdnrequests'] = 'Skicka mottagarkvitton';
$labels['askuser'] = 'Fråga';
$labels['autosend'] = 'Automatiskt';
$labels['autosendknown'] = 'Skicka kvitto till mina kontakter, fråga för övriga';
$labels['autosendknownignore'] = 'Skicka kvitto till mina kontakter, ignorera övriga';
$labels['autosendtrusted'] = 'skicka kvitto till betrodda avsändare, annars fråga mig';
$labels['autosendtrustedignore'] = 'skicka kvitto till betrodda avsändare, annars ignorera';
$labels['ignorerequest'] = 'ignorera begäran';
$labels['readwhendeleted'] = 'Markera meddelande som läst vid borttagning';
$labels['flagfordeletion'] = 'Flagga meddelande för borttagning istället för att ta bort direkt';
$labels['skipdeleted'] = 'Visa inte borttagna meddelanden';
$labels['deletealways'] = 'Ta bort meddelande om flyttning till Papperskorg misslyckas';
$labels['deletejunk'] = 'Radera meddelanden i Skräp direkt';
$labels['showremoteimages'] = 'Visa externt länkade bilder i meddelande';
$labels['allowremoteresources'] = 'Tillåt externt länkade resurser (bilder, stilmallar)';
$labels['fromknownsenders'] = 'Från kända avsändare';
$labels['fromtrustedsenders'] = 'från betrodda avsändare';
$labels['frommycontacts'] = 'från mina kontakter';
$labels['always'] = 'Alltid';
$labels['alwaysbutplain'] = 'alltid, utom vid svar på textmeddelande';
$labels['showinlineimages'] = 'Visa bifogade bilder efter meddelande';
$labels['autosavedraft'] = 'Spara utkast med automatiskt intervall';
$labels['everynminutes'] = '$n min';
$labels['refreshinterval'] = 'Uppdatera (hämta nya meddelanden, o.s.v.)';
$labels['never'] = 'Aldrig';
$labels['immediately'] = 'Direkt';
$labels['messagesdisplaying'] = 'Visning av meddelanden';
$labels['messagescomposition'] = 'Redigering av meddelanden';
$labels['mimeparamfolding'] = 'Kodning av namn på bifogade filer';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (övriga)';
$labels['force7bit'] = 'Använd MIME-kodning för tecken med 8-bitar';
$labels['savelocalstorage'] = "Spara lokalt (tillfälligt)";
$labels['advancedoptions'] = 'Avancerade inställningar';
$labels['toggleadvancedoptions'] = 'Växla avancerade inställningar';
$labels['focusonnewmessage'] = 'Fokusera webbläsarens fönster vid nytt meddelande';
$labels['checkallfolders'] = 'Kontrollera alla mappar för nya meddelanden';
$labels['displaynext'] = 'Visa nästa i listan efter ta bort eller flytta';
$labels['defaultfont'] = 'Förvalt teckensnitt i HTML-meddelande';
$labels['mainoptions'] = 'Huvudalternativ';
$labels['browseroptions'] = 'Webbläsaralternativ';
$labels['section'] = 'Avdelning';
$labels['maintenance'] = 'Underhåll';
$labels['newmessage'] = 'Nytt meddelande';
$labels['signatureoptions'] = 'Signaturalternativ';
$labels['whenreplying'] = 'Vid svar';
$labels['replyempty'] = 'Inkludera inte ursprungligt meddelande';
$labels['replytopposting'] = 'Skriv nytt meddelande ovanför befintligt';
$labels['replytoppostingnoindent'] = 'Skriv nytt meddelande ovanför befintligt (utan indrag)';
$labels['replybottomposting'] = 'Skriv nytt meddelande nedanför befintligt';
$labels['replyremovesignature'] = 'Ta bort befintlig signatur från meddelandet vid svar';
$labels['autoaddsignature'] = 'Infoga signatur automatiskt';
$labels['newmessageonly'] = 'Vid nytt meddelande';
$labels['replyandforwardonly'] = 'Vid svar och vidareskickande';
$labels['insertsignature'] = 'Infoga signatur';
$labels['sigbelow'] = 'Placera signatur efter meddelandet';
$labels['sigseparator'] = 'Använd alltid avdelare enligt standard i signaturer';
$labels['automarkread'] = 'Markera meddelanden som lästa';
$labels['afternseconds'] = 'Efter $n sekunder';
$labels['reqmdn'] = 'Begär alltid mottagarkvitto';
$labels['reqdsn'] = 'Begär alltid leveransstatusmeddelande';
$labels['replysamefolder'] = 'Placera svar i samma mapp som besvarat meddelande';
$labels['defaultabook'] = 'Förvald adressbok';
$labels['autocompletesingle'] = 'Hoppa över alternativa adresser vid automatisk komplettering';
$labels['listnamedisplay'] = 'Lista kontakter med';
$labels['contactformmode'] = 'Kontaktformulär-läge';
$labels['privatemode'] = 'Privat (hem)';
$labels['businessmode'] = 'Företag (arbete)';
$labels['collectedaddresses'] = 'Samlade adresser';
$labels['collectedrecipients'] = 'Samlade mottagare';
$labels['collectedrecipientsopt'] = 'Lagra utgående mottagare i';
$labels['collectedsendersopt'] = 'Lagra betrodda avsändare i';
$labels['trustedsenders'] = 'Betrodda avsändare';
$labels['spellcheckbeforesend'] = 'Kontrollera stavning innan meddelanden skickas';
$labels['spellcheckoptions'] = 'Rättstavningsalternativ';
$labels['spellcheckignoresyms'] = 'Ignorera ord med symboler';
$labels['spellcheckignorenums'] = 'Ignorera ord med siffror';
$labels['spellcheckignorecaps'] = 'Ignorera ord med enbart stora bokstäver';
$labels['addtodict'] = 'Lägg till i ordlista';
$labels['mailtoprotohandler'] = 'Ange program för hantering av mailto-länkar';
$labels['standardwindows'] = 'Hantera popup-rutor som standardfönster';
$labels['forwardmode'] = 'Skicka meddelande vidare';
$labels['inline'] = 'Infogat';
$labels['asattachment'] = 'Bilaga';
$labels['replyallmode'] = 'Standardfunktion för knappen Svara alla';
$labels['replyalldefault'] = 'Svara alla';
$labels['replyalllist'] = 'Svara endast lista (i förekommande fall)';
$labels['allmessages'] = 'alla meddelanden';
$labels['olderxdays'] = 'äldre än $x dagar';
$labels['folder'] = 'Mapp';
$labels['folders'] = 'Mappar';
$labels['foldername'] = 'Mappnamn';
$labels['subscribed'] = 'Prenumererad';
$labels['messagecount'] = 'Meddelanden';
$labels['create'] = 'Skapa';
$labels['createfolder'] = 'Ny mapp';
$labels['managefolders'] = 'Hantera mappar';
$labels['specialfolders'] = 'Speciella mappar';
$labels['properties'] = 'Egenskaper';
$labels['folderproperties'] = 'Mappegenskaper';
$labels['parentfolder'] = 'Överliggande mapp';
$labels['location'] = 'Plats';
$labels['info'] = 'Information';
$labels['getfoldersize'] = 'Klicka för att få mappstorlek';
$labels['changesubscription'] = 'Klicka för att ändra prenumeration';
$labels['foldertype'] = 'Mapptyp';
$labels['personalfolder'] = 'Privat mapp';
$labels['otherfolder'] = 'Annan användares mapp';
$labels['sharedfolder'] = 'Offentlig mapp';
$labels['findfolders'] = 'Hitta mappar';
$labels['findcontacts'] = 'Hitta kontakter';
$labels['findmail'] = 'Hitta meddelanden';
$labels['namespace.personal'] = 'Personliga';
$labels['namespace.other'] = 'Andra användares';
$labels['namespace.shared'] = 'Delade';
$labels['dualuselabel'] = 'Kan endast innehålla';
$labels['dualusemail'] = 'meddelanden';
$labels['dualusefolder'] = 'mappar';
$labels['generate'] = 'Skapa';
$labels['encryptioncreatekey'] = 'Nytt nyckelpar ';
$labels['openmailvelopesettings'] = 'Öppna inställningar för Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Du har $nr passande privata nycklar i din Mailvelope-nyckelring:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Avsändaridentiteten har ännu ingen privat PGP-nyckel lagrad i Mailvelope-tillägget. Vill du skapa en för att kunna skicka krypterade meddelanden?';
$labels['encryption'] = 'Kryptering';
$labels['mailvelopeoptions'] = 'Mailvelope-alternativ';
$labels['mailvelopemainkeyring'] = 'Använd Mailvelopes huvudnyckelring';
$labels['mailvelopenotfound'] = 'Mailvelope-tillägg är inte aktiverat/installerat i din webbläsare.';
$labels['sortby'] = 'Sortera på';
$labels['sortasc'] = 'Sortera stigande';
$labels['sortdesc'] = 'Sortera fallande';
$labels['undo'] = 'Ångra';
$labels['installedplugins'] = 'Installerade tillägg';
$labels['plugin'] = 'Tillägg';
$labels['version'] = 'Version';
$labels['source'] = 'Källkod';
$labels['destination'] = 'Destination';
$labels['license'] = 'Licens';
$labels['support'] = 'Hjälp';
$labels['savedsearches'] = 'Sparade sökningar';
$labels['dateformatY'] = 'ÅÅÅÅ';
$labels['dateformaty'] = 'ÅÅ';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Engelsk';
$labels['westerneuropean'] = 'Västeuropeisk';
$labels['easterneuropean'] = 'Östeuropeisk';
$labels['southeasterneuropean'] = 'Sydösteuropeisk';
$labels['baltic'] = 'Baltisk';
$labels['cyrillic'] = 'Kyrillisk';
$labels['arabic'] = 'Arabisk';
$labels['greek'] = 'Grekisk';
$labels['hebrew'] = 'Hebreisk';
$labels['turkish'] = 'Turkisk';
$labels['nordic'] = 'Skandinavisk';
$labels['thai'] = 'Thailändsk';
$labels['celtic'] = 'Keltisk';
$labels['vietnamese'] = 'Vietnamesisk';
$labels['japanese'] = 'Japansk';
$labels['korean'] = 'Koreansk';
$labels['chinese'] = 'Kinesisk';
$labels['arialabeltopnav'] = 'Fönsterkontroll';
$labels['arialabeltasknav'] = 'Programuppgifter';
$labels['arialabeltoolbar'] = 'Programmets verktygslist';
$labels['arialabellistnav'] = 'Listnavigering';
$labels['arialabelactivetask'] = 'Aktiv uppgift';
$labels['arialabelmessagessearchfilter'] = 'Meddelandelistningsfilter';
$labels['arialabelmailsearchform'] = 'Sökformulär för meddelande';
$labels['arialabelcontactsearchform'] = 'Sökformulär för kontakter';
$labels['arialabelmailquicksearchbox'] = 'Meddelandesökfält';
$labels['arialabelquicksearchbox'] = 'Sökfält';
$labels['arialabelfoldersearchfilter'] = 'Mapplistningsfilter';
$labels['arialabelfoldersearchform'] = 'Sökformulär för mappar';
$labels['arialabelfolderlist'] = 'Markering av meddelandemapp';
$labels['arialabelmessagelist'] = 'Meddelandelistning';
$labels['arialabelmailpreviewframe'] = 'Förhandsvisning av meddelande';
$labels['arialabelmailboxmenu'] = 'Mappåtgärdsmeny';
$labels['arialabellistselectmenu'] = 'Listmarkeringsmeny';
$labels['arialabelthreadselectmenu'] = 'Trådlistningsmeny';
$labels['arialabelmessagelistoptions'] = 'Alternativ för visning och sortering av meddelandelista';
$labels['arialabelmailimportdialog'] = 'Dialog för import av meddelande';
$labels['arialabelmessagenav'] = 'Meddelandenavigering';
$labels['arialabelmessagebody'] = 'Meddelandeinnehåll';
$labels['arialabelmessageactions'] = 'Meddelandehantering';
$labels['arialabelcontactquicksearch'] = 'Sökformulär för kontakter';
$labels['arialabelcontactsearchbox'] = 'Kontaktsökfält';
$labels['arialabelmessageheaders'] = 'Meddelandeinfo';
$labels['arialabelforwardingoptions'] = 'Alternativ för vidareskickande';
$labels['arialabelreplyalloptions'] = 'Alternativ för svara alla';
$labels['arialabelmoremessageactions'] = 'Ytterligare meddelandehantering';
$labels['arialabelmorecontactactions'] = 'Ytterligare kontakthantering';
$labels['arialabelmarkmessagesas'] = 'Markera markerat meddelande som...';
$labels['arialabelcomposeoptions'] = 'Skapandeinställningar';
$labels['arialabelresponsesmenu'] = 'Responsmeny';
$labels['arialabelattachmentuploadform'] = 'Uppladdningsformulär för bilaga';
$labels['arialabelattachmentmenu'] = 'Alternativ för bilagor';
$labels['arialabelmailtomenu'] = 'Adressalternativ';
$labels['arialabelattachmentpreview'] = 'Förhandsvisning av bilaga';
$labels['ariasummarycomposecontacts'] = 'Lista med kontakter och grupper att använda som mottagare';
$labels['arialabelcontactexportoptions'] = 'Exportalternativ för kontakter';
$labels['arialabelabookgroupoptions'] = 'Alternativ för adressbok/kontaktgrupp';
$labels['arialabelpreferencesform'] = 'Inställningsformulär';
$labels['arialabelidentityeditfrom'] = 'Ändringsformulär för identitet';
$labels['arialabelresponseeditfrom'] = 'Ändringsformulär för respons';
$labels['arialabelsearchterms'] = 'Sökord';
$labels['arialabeldropactionmenu'] = 'Dra-och-släpp-hanteringsmeny';
$labels['arialabelheadersmenu'] = 'Meny lägg till mottagare (meddelandeinfo)';
$labels['arialabelimagetools'] = 'Bildverktyg';
$labels['helplistnavigation'] = 'Listnavigering';
$labels['helplistkeyboardnavigation'] = "Piltangent upp/ner: Flytta radfokus/radmarkering.
Mellanslag: Välj fokuserad rad.
Shift + upp/ner: Välj ytterligare rad över/under.
Ctrl + mellanslag: Lägg till/ta bort fokuserad rad i markering.";
$labels['helplistkeyboardnavmessages'] = "Piltangent höger/vänster: visa/göm meddelandetråd (endast i trådvisningsläge).
Retur: Öppna markerat/fokuserat meddelande.
Backsteg: Flytta markerat meddelande till Papperskorg.";
$labels['helplistkeyboardnavcontacts'] = "Retur: Öppna markerad/fokuserad kontakt.";
