<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['changepasswd']  = 'Broyt loyniorð';
$labels['curpasswd']  = 'Nú verandi loyniorð:';
$labels['newpasswd']  = 'Nýtt loyniorð:';
$labels['confpasswd']  = 'Endurtak nýggja loyniorð:';
$messages['nopassword'] = 'Vinarliga skriva inn nýtt loyniorð.';
$messages['nocurpassword'] = 'Vinarliga skriva inn núverandi loyniorð.';
$messages['passwordincorrect'] = 'Verandi loyniorð er skeift.';
$messages['passwordinconsistency'] = 'Loyniorðini eru ikki líka, vinarliga royn aftur.';
$messages['crypterror'] = 'Kann ikki goyma nýggja loyniorð. Brongling manglar.';
$messages['connecterror'] = 'Kann ikki goyma nýtt loyniorð. Sambands feilur.';
$messages['internalerror'] = 'Kundi ikki goyma nýggja loyniorðið.';
$messages['passwordshort'] = 'Loyniorði má hvørfall verða $length tekin langt.';
$messages['passwordweak'] = 'Loyniorði má innihalda minst eitt nummar og eitt punktum tekin.';
$messages['passwordforbidden'] = 'Loyniorð inniheldur ólóglig tekin.';
$messages['firstloginchange'] = 'Hetta er tín fyrsta innriting. Vinarliga broyt títt loyniorð.';
$messages['disablednotice'] = 'Skipanin er í verandi stunduni dagførd. Av tí sama, er ikki loyvt at broyta loyniorði í løtuni. Alt skuldi verið aftur til tað vanliga skjótt. Tað muga tygum orsaka. ';
