<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = '$product वरती स्वागत आहे';
$labels['username'] = 'वापरकर्त्याचे नाव(तुमचे इमेल)';
$labels['password'] = 'परवलीचा शब्द';
$labels['server'] = 'सर्व्हर';
$labels['login'] = 'प्रवेश';
$labels['logout'] = 'बाहेर जा';
$labels['mail'] = 'इ-मेल';
$labels['settings'] = 'तुमची पसंती';
$labels['addressbook'] = 'पत्ता नोंदवही';
$labels['inbox'] = 'आलेले संदेश';
$labels['drafts'] = 'मसुदा';
$labels['sent'] = 'पाठवलेले';
$labels['trash'] = 'कचरा पेटी';
$labels['junk'] = 'नको असलेले कचरा संदेश';
$labels['subject'] = 'विषय';
$labels['from'] = 'प्रेषक';
$labels['sender'] = 'प्रेषक';
$labels['to'] = 'प्रती';
$labels['cc'] = 'प्रत';
$labels['bcc'] = 'गुप्त प्रत';
$labels['replyto'] = 'यास उत्तर द्या';
$labels['date'] = 'दिनांक';
$labels['size'] = 'आकार';
$labels['priority'] = 'प्राधान्य';
$labels['organization'] = 'संस्था';
$labels['readstatus'] = 'वाचन स्थिती';
$labels['listoptions'] = 'विकल्प सूची';
$labels['mailboxlist'] = 'फोल्डर्स';
$labels['messagesfromto'] = 'संदेश $from कडून $to साठी $count वा';
$labels['threadsfromto'] = 'धागे $from कडून $to साठी $count वा';
$labels['messagenrof'] = 'Message $nr of $count';
$labels['copy'] = 'नक्‍कल';
$labels['move'] = 'हलवा';
$labels['moveto'] = 'या फोल्डरमधे ठेवा';
$labels['download'] = 'उतरवून घ्या';
$labels['filename'] = 'फाईलचे नाव';
$labels['filesize'] = 'फाईलचा आकार';
$labels['addtoaddressbook'] = 'पत्ता नोंदवहीत नोंदवा';
$labels['sun'] = 'रवी';
$labels['mon'] = 'सोम';
$labels['tue'] = 'मंगळ';
$labels['wed'] = 'बुध';
$labels['thu'] = 'गुरु';
$labels['fri'] = 'शुक्र';
$labels['sat'] = 'शनी';
$labels['sunday'] = 'रविवार';
$labels['monday'] = 'सोमवार';
$labels['tuesday'] = 'मंगळवार';
$labels['wednesday'] = 'बुधवार';
$labels['thursday'] = 'गुरुवार';
$labels['friday'] = 'शुक्रवार';
$labels['saturday'] = 'शनीवार';
$labels['jan'] = 'जाने';
$labels['feb'] = 'फेब्';
$labels['mar'] = 'मार्च';
$labels['apr'] = 'एप्रिल';
$labels['may'] = 'मे';
$labels['jun'] = 'जून';
$labels['jul'] = 'जुलै';
$labels['aug'] = 'ऑगस्ट';
$labels['sep'] = 'सप्टें';
$labels['oct'] = 'ऑक्टो';
$labels['nov'] = 'नोव्हें';
$labels['dec'] = 'डिसें';
$labels['longjan'] = 'जानेवारी';
$labels['longfeb'] = 'फेब्रूवारी';
$labels['longmar'] = 'मार्च';
$labels['longapr'] = 'एप्रिल';
$labels['longmay'] = 'मे';
$labels['longjun'] = 'जून';
$labels['longjul'] = 'जुलै';
$labels['longaug'] = 'ऑगस्ट';
$labels['longsep'] = 'सप्टेंबर';
$labels['longoct'] = 'ऑक्टोबर';
$labels['longnov'] = 'नोव्हेंबर';
$labels['longdec'] = 'डिसेंबर';
$labels['today'] = 'आज';
$labels['refresh'] = 'अद्ययावत करा';
$labels['checkmail'] = 'नवीन संदेश आले आहेत का पहा';
$labels['compose'] = 'नवीन संदेश तयार करा';
$labels['writenewmessage'] = 'नवीन संदेश तयार करा';
$labels['reply'] = 'उत्तर दया';
$labels['replytomessage'] = 'पाठवणार्‍याला उत्तर द्या';
$labels['replytoallmessage'] = 'पाठवणार्‍याला आणि प्रत केलेल्या सर्वांना संदेश पाठवा';
$labels['replyall'] = 'सर्वांना उत्तर दया';
$labels['forwardmessage'] = 'हा संदेश पुढे पाठवा';
$labels['deletemessage'] = 'संदेश काढून टाका';
$labels['movemessagetotrash'] = 'संदेश कचरापेटीत टाका';
$labels['printmessage'] = 'हा संदेश छापा';
$labels['previousmessage'] = 'आधिचा संदेश दाखवा';
$labels['firstmessage'] = 'पहिला संदेश दाखवा';
$labels['nextmessage'] = 'नंतरचा संदेश दाखवा';
$labels['lastmessage'] = 'शेवटचा संदेश दाखवा';
$labels['backtolist'] = 'संदेशांच्या यादीकडे परत चला';
$labels['viewsource'] = 'मूळ संदेशाचा प्रोग्राम कोड दाखवा';
$labels['mark'] = 'खूण';
$labels['markmessages'] = 'संदेशांना खूण करा';
$labels['markread'] = 'वाचलेला म्हणून खूण करा';
$labels['markunread'] = 'न वाचलेला म्हणून खूण करा';
$labels['markflagged'] = 'खूण लावलेला म्हणून खूण करा';
$labels['markunflagged'] = 'खूण काढलेला म्हणून खूण करा';
$labels['moreactions'] = 'अधिक कृती..';
$labels['more'] = 'अधिक';
$labels['back'] = 'मागे';
$labels['options'] = 'पर्याय';
$labels['select'] = 'निवडा';
$labels['all'] = 'सर्व';
$labels['none'] = 'कोणताही नाही';
$labels['currpage'] = 'सध्‍याचे पान';
$labels['unread'] = 'न वाचलेले';
$labels['flagged'] = 'खूण लावलेले';
$labels['unanswered'] = 'उत्तर न दिलेले';
$labels['deleted'] = 'काढून टाकलेला(ले)';
$labels['invert'] = 'उलट करा';
$labels['filter'] = 'गाळणी';
$labels['list'] = 'यादी';
$labels['threads'] = 'धागे';
$labels['expand-all'] = 'सर्व विस्‍तारीत करा';
$labels['expand-unread'] = 'न वाचलेला विस्‍तारा';
$labels['collapse-all'] = 'सर्व मिटवा';
$labels['threaded'] = 'धागा लावलेला';
$labels['autoexpand_threads'] = 'संदेश धागे विस्‍तारा';
$labels['do_expand'] = 'सर्व धागे';
$labels['expand_only_unread'] = 'फक्‍त न वाचलेल्‍या संदेशांबददल';
$labels['fromto'] = 'पाठवणारा/प्रती';
$labels['flag'] = 'खूण';
$labels['attachment'] = 'जोड';
$labels['nonesort'] = 'कोणताही नाही';
$labels['sentdate'] = 'पाठवणी दिनांक';
$labels['arrival'] = 'आगमन दिनांक';
$labels['asc'] = 'चढत्‍या क्रमाने';
$labels['desc'] = 'उतरत्‍या क्रमाने';
$labels['listcolumns'] = 'सुची स्‍तंभ';
$labels['listsorting'] = 'स्‍तंभ वर्गीकरण';
$labels['listorder'] = 'वर्गीकरण क्रम';
$labels['listmode'] = 'यादी दर्शक पध्‍दत';
$labels['layoutlist'] = 'यादी';
$labels['folderactions'] = 'फोल्डर कृती..';
$labels['compact'] = 'छोटा';
$labels['empty'] = 'रिकामा';
$labels['quota'] = 'डिस्कचा वापर';
$labels['unknown'] = 'माहित नसलेला';
$labels['unlimited'] = 'अमर्याद';
$labels['quicksearch'] = 'चटकन शोध';
$labels['resetsearch'] = 'परत शोध';
$labels['searchmod'] = 'बदलकर्त्‍यांना शोधा';
$labels['msgtext'] = 'संपूर्ण संदेश';
$labels['openinextwin'] = 'नवीन खिडकी उघडा';
$labels['emlsave'] = 'इएमएल स्‍वरूपात उतरवून घ्या';
$labels['editasnew'] = 'नवीन आहे असा संपादित करा';
$labels['sendmessage'] = 'आत्ता पाठवा';
$labels['savemessage'] = 'हा मसूदा साठवून ठेवा';
$labels['addattachment'] = 'फाईल सोबत जोडा';
$labels['charset'] = 'कॅरेक्टर सेट';
$labels['editortype'] = 'संपादकाचा प्रकार';
$labels['returnreceipt'] = 'पोच पावती';
$labels['dsn'] = 'पोच स्थिती निर्देशक';
$labels['mailreplyintro'] = '$date या दिवशी $sender ने लिहीले :';
$labels['originalmessage'] = 'खरा संदेश';
$labels['editidents'] = 'ओळख संपादित करा';
$labels['spellcheck'] = 'लिखाण';
$labels['checkspelling'] = 'शुध्द लेखन';
$labels['resumeediting'] = 'परत संदेश संपादित करा';
$labels['revertto'] = 'परत जा';
$labels['attach'] = 'जोडा';
$labels['attachments'] = 'जोडलेल्या';
$labels['upload'] = 'चढवा';
$labels['close'] = 'बंद';
$labels['messageoptions'] = 'संदेश पर्याय..';
$labels['low'] = 'कमी';
$labels['lowest'] = 'कमित कमी';
$labels['normal'] = 'नेहमी प्रमाणे';
$labels['high'] = 'तातडीचे';
$labels['highest'] = 'अतिशय तातडीचे';
$labels['nosubject'] = '(विषय नाही)';
$labels['showimages'] = 'चित्र दाखवा';
$labels['alwaysshow'] = '$sender कडून आलेल्या संदेशातील चित्रे नेहमी दाखवा';
$labels['isdraft'] = 'हा मसुदा संदेश आहे';
$labels['htmltoggle'] = 'एच टी एम एल';
$labels['plaintoggle'] = 'साधे लिखाण';
$labels['savesentmessagein'] = 'पाठवलेला संदेश या फोल्डरमधे ठेवा';
$labels['dontsave'] = 'संदेश साठवू नका';
$labels['maxuploadsize'] = 'जास्‍तीत जास्‍त फाइलचा आकार $size असू शकतो';
$labels['addcc'] = 'प्रत करा';
$labels['addbcc'] = 'गुप्त प्रत करा';
$labels['addreplyto'] = 'आणखी लोकांना संदेश पाठवा';
$labels['mdnrequest'] = 'हा संदेश पाठवणार्‍याने हा संदेश तुम्ही वाचल्यावर कळवावयाला सांगितले आहे. तुम्हाला असे कळवणे चालेल ना?';
$labels['receiptread'] = 'पोच पावती (संदेश वाचला)';
$labels['yourmessage'] = 'ही तुमच्या संदेशाची पोच पावती आहे.';
$labels['receiptnote'] = 'सूचना: ही पोच पावती तुम्ही ज्यांना  संदेश पाठवला त्यांच्या संगणकावर दिसला एवढेच सांगते. तुम्ही ज्यांना हा संदेश पाठवला, त्यांनी तो वाचला, आणि त्यांना तो नक्की समजला हे मात्र सांगत नाही.';
$labels['name'] = 'टोपणनाव';
$labels['firstname'] = 'नाव';
$labels['surname'] = 'आडनाव';
$labels['middlename'] = 'मधले नाव';
$labels['nickname'] = 'टोपणनाव';
$labels['jobtitle'] = 'कामाचे शिर्षक';
$labels['department'] = 'विभाग';
$labels['gender'] = 'लिंग';
$labels['email'] = 'इ-मेल्';
$labels['phone'] = 'दूरध्वनी';
$labels['address'] = 'पत्ता';
$labels['street'] = 'रस्ता';
$labels['locality'] = 'शहर';
$labels['region'] = 'राज्य / संस्थान';
$labels['country'] = 'देश';
$labels['birthday'] = 'वाढदिवस';
$labels['website'] = 'संकेतस्थळ';
$labels['notes'] = 'टिपा';
$labels['male'] = 'पुरूष';
$labels['female'] = 'स्त्री';
$labels['manager'] = 'व्यवस्थापक';
$labels['assistant'] = 'सहाय्यक';
$labels['search'] = 'शोध';
$labels['advsearch'] = 'प्रगत शोध';
$labels['advanced'] = 'आधुनिक';
$labels['other'] = 'इतर';
$labels['typehome'] = 'मुख्यपृष्ठ';
$labels['typework'] = 'काम';
$labels['typeother'] = 'इतर';
$labels['typemobile'] = 'भ्रमणध्वनी';
$labels['typemain'] = 'मुख्य';
$labels['typevideo'] = 'चलचित्र';
$labels['typeassistant'] = 'सहाय्यक';
$labels['typehomepage'] = 'मुख्य पृष्ठ';
$labels['editcontact'] = 'नोंदवहीतील पत्ता सुधारा';
$labels['contacts'] = 'संपर्क';
$labels['personalinfo'] = 'वैयक्तिक माहिती';
$labels['edit'] = 'संदेश तयार करा';
$labels['cancel'] = 'रद्द करा';
$labels['save'] = 'ठेवून द्या';
$labels['delete'] = 'काढून टाका';
$labels['rename'] = 'दूसरे नाव द्या';
$labels['addphoto'] = 'समावेश करा';
$labels['replacephoto'] = 'बदला';
$labels['deletecontact'] = 'खूण केलेले सर्व संपर्काचे पत्ते काढून टाका';
$labels['composeto'] = 'साठी नवीन संदेश तयार करा';
$labels['contactsfromto'] = '$from पासून ते $to पर्यंत $count पैकी';
$labels['print'] = 'छापा';
$labels['export'] = 'निर्यात करा';
$labels['exportvcards'] = 'व्ही कार्ड स्वरुपात पत्ते निर्यात करा';
$labels['groupdelete'] = 'गट नष्ट करा';
$labels['previouspage'] = 'आधिचा संच दाखवा';
$labels['firstpage'] = 'पहिला संच दाखवा';
$labels['nextpage'] = 'नंतरचा संच दाखवा';
$labels['lastpage'] = 'शेवटचा संच दाखवा';
$labels['group'] = 'गट';
$labels['groups'] = 'अनेक गट';
$labels['personaladrbook'] = 'वैयक्तिक पत्ते';
$labels['searchsave'] = 'शोध जतन करा';
$labels['searchdelete'] = 'शोध नष्ट करा';
$labels['import'] = 'आयात करा';
$labels['importcontacts'] = 'पत्ते आयात करा';
$labels['importreplace'] = 'संपूर्ण पत्ता नोंदवही बदला';
$labels['done'] = 'झाले';
$labels['settingsfor'] = 'साठी सेटिंग्ज';
$labels['about'] = 'च्या विषयी';
$labels['preferences'] = 'तुमची पसंती';
$labels['userpreferences'] = 'वापरकर्त्याची पसंती';
$labels['editpreferences'] = 'वापरकर्त्याची पसंती सुधारा';
$labels['identities'] = 'ओळख';
$labels['preferhtml'] = 'एच टी एम एल दाखवा';
$labels['defaultcharset'] = 'नेहमीचा अक्षर संच';
$labels['htmlmessage'] = 'एच टी एम एल संदेश';
$labels['prettydate'] = 'विशेष दिवस';
$labels['setdefault'] = 'हा नेहमीसाठी वापरा';
$labels['autodetect'] = 'स्वयंचलित';
$labels['language'] = 'भाषा';
$labels['timezone'] = 'वेळ  क्षेत्र';
$labels['pagesize'] = 'प्रत्येक पानावरील ओळी';
$labels['signature'] = 'सही';
$labels['dstactive'] = 'दिवसाची वेळ';
$labels['htmleditor'] = 'एच टी एम एल संदेश तयारा करा';
$labels['htmlsignature'] = 'एच टी एम एल सही';
$labels['previewpane'] = 'प्रक्रियापूर्व तावदान दाखवा';
$labels['skin'] = 'दृष्य गोष्टी';
$labels['logoutclear'] = 'खात्यातून बाहेर पडतांना कचरा पेटी साफ करा';
$labels['logoutcompact'] = 'खात्यातून बाहेर पडतांना आलेल्या संदेशांना छोटे आणि व्यवस्थित करा';
$labels['uisettings'] = 'वापरकर्त्यासाठीचा इंटरफेस';
$labels['serversettings'] = 'सर्व्हरची सेटिंग्ज';
$labels['mailboxview'] = 'टपालपेटी पहाणे';
$labels['mdnrequests'] = 'पाठवणार्‍याच्या सूचना';
$labels['askuser'] = 'वापरकर्त्याला विचारा';
$labels['autosend'] = 'स्वयंचलित (आपोआप पाठवणे)';
$labels['readwhendeleted'] = 'काढून टाकल्यावर संदेश वाचला असे दाखवा';
$labels['flagfordeletion'] = 'संदेश काढून टाकण्या ऎवजी संदेश काढून टाकण्यासाठी आहे अशी खूण करा';
$labels['skipdeleted'] = 'काढून टाकलेले संदेश दाखवू नका';
$labels['deletealways'] = 'जर संदेश कचरापेटीत गेले नाहीत तर काढून टाका';
$labels['showremoteimages'] = 'संदेशातील चित्रे दाखवा';
$labels['fromknownsenders'] = 'माहितीतील पाठवणार्‍याकडून संदेश';
$labels['always'] = 'नेहमी';
$labels['showinlineimages'] = 'सोबत जोडलेली चित्रे संदेशाच्या खाली दाखवा';
$labels['autosavedraft'] = 'मसूदा आपोआप जतन करा';
$labels['everynminutes'] = 'प्रत्येक $n मिनिटांनी';
$labels['never'] = 'कधीच नाही';
$labels['immediately'] = 'ताबडतोब';
$labels['messagesdisplaying'] = 'संदेश दाखवा';
$labels['messagescomposition'] = 'संदेश तयार करा';
$labels['mimeparamfolding'] = 'सोबत दिलेल्या फाईल्सची नावे';
$labels['2231folding'] = 'संपूर्ण आर एफ सी 2231(थंडरबर्ड)';
$labels['miscfolding'] = 'आर एफ सी  2047/2231 (मायक्रोसॉफ़्ट आऊटलूक)';
$labels['2047folding'] = 'संपूर्ण आर एफ सी 2047(ईतर)';
$labels['force7bit'] = '8 अक्षरी एमआयएमई संक्षिप्‍तरूप वापरा';
$labels['advancedoptions'] = 'अधिक पर्याय';
$labels['focusonnewmessage'] = 'ब्राऊझर खिडकी नवीन संदेशावर केंद्रित करा';
$labels['checkallfolders'] = 'सर्व फोल्डरमधे नवीन संदेश शोधा';
$labels['mainoptions'] = 'मुख्‍य पर्याय';
$labels['section'] = 'भाग';
$labels['maintenance'] = 'देखभाल';
$labels['newmessage'] = 'नवीन संदेश';
$labels['signatureoptions'] = 'सही पर्याय';
$labels['whenreplying'] = 'उत्‍तर देताना';
$labels['replytopposting'] = 'नवीन संदेश मुळ संदेशाच्‍या वर चालू करा';
$labels['replybottomposting'] = 'नवीन संदेश मुळ संदेशाच्‍या खाली चालू करा';
$labels['replyremovesignature'] = 'उत्‍तर देताना मुळ सही संदेशातून काढून टाका';
$labels['autoaddsignature'] = 'आपोआप सही करा';
$labels['newmessageonly'] = 'फक्‍त नवीन संदेश';
$labels['replyandforwardonly'] = 'फक्‍त उत्‍तरे आ‍णी पुढे पाठवलेले संदेश';
$labels['insertsignature'] = 'सही मध्‍ये टाका';
$labels['afternseconds'] = '$n क्षणानंतर';
$labels['reqmdn'] = 'नेहमी पोचपावतीची विनंती करा';
$labels['reqdsn'] = 'नेहमी पोचपावती स्थिती निर्देशाची विनंती करा';
$labels['allmessages'] = 'सर्व संदेश';
$labels['folder'] = 'फोल्डर';
$labels['folders'] = 'फोल्डर्स';
$labels['foldername'] = 'फोल्डरचे नाव';
$labels['subscribed'] = 'वर्गणिदार होणे';
$labels['messagecount'] = 'संदेश';
$labels['create'] = 'तयार करा';
$labels['createfolder'] = 'नवीन फोल्डर तयार करा';
$labels['managefolders'] = 'फोल्डर्सचे नियोजन करा';
$labels['specialfolders'] = 'विषेश फोल्डर';
$labels['sortby'] = 'ने वर्गवारी करा';
$labels['sortasc'] = 'चढत्या क्रमाने';
$labels['sortdesc'] = 'उतरत्या क्रमाने';
$labels['B'] = 'बाइट';
$labels['KB'] = 'केबी';
$labels['MB'] = 'एमबी';
$labels['GB'] = 'जीबी';
$labels['unicode'] = 'युनिकोड';
$labels['english'] = 'इंग्रजी';
$labels['westerneuropean'] = 'पश्चिम युरोपियन';
$labels['easterneuropean'] = 'पूर्व युरोपियन';
$labels['southeasterneuropean'] = 'दक्षिणपूर्व युरोपियन';
$labels['baltic'] = 'बाल्‍टीक';
$labels['cyrillic'] = 'सिरीलिक';
$labels['arabic'] = 'अरेबिक';
$labels['greek'] = 'ग्रीक';
$labels['hebrew'] = 'हिब्रु';
$labels['turkish'] = 'तुर्कि';
$labels['nordic'] = 'नॉर्डिक';
$labels['thai'] = 'थाइ';
$labels['celtic'] = 'सेल्टिक';
$labels['vietnamese'] = 'व्हिएतनामी';
$labels['japanese'] = 'जपानी';
$labels['korean'] = 'कोरियन';
$labels['chinese'] = 'चिनी';
