<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['messagedelete'] = 'წაშლა';
$labels['add'] = 'დამატება';
$labels['del'] = 'წაშლა';
$labels['sender'] = 'გამგზავნელი';
$labels['flagread'] = 'წაკითხვა';
$labels['flagdeleted'] = 'წაშლილი';
$labels['flagflagged'] = 'მონიშნული';
$labels['notifymethodmailto'] = 'ელ–ფოსტა';
$labels['notifymethodtel'] = 'ტელეფონი';
$labels['datetest'] = 'თარიღი';
$labels['advancedopts'] = 'დამატებითი პარამეტრები';
$labels['body'] = 'შეტყობინების ტექსტი';
$labels['vacation.subject'] = 'სათაური';
$labels['vacation.body'] = 'შეტყობინების ტექსტი';
