<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Prišlo je do napake!';
$messages['loginfailed']  = 'Prijava ni uspela';
$messages['cookiesdisabled'] = 'Vaš spletni brskalnik ne sprejema piškotkov.';
$messages['sessionerror'] = 'Seja je neveljavna ali je potekla.';
$messages['storageerror'] = 'Povezava z IMAP strežnikom je spodletela.';
$messages['servererror'] = 'Napaka strežnika!';
$messages['servererrormsg'] = 'Napaka strežnika $msg';
$messages['accountlocked'] = 'Preveliko število napačnih prijav. Poskusite znova kasneje.';
$messages['connerror'] = 'Napaka pri povezavi do strežnika.';
$messages['dberror'] = 'Napaka v bazi';
$messages['windowopenerror'] = 'Onemogočen prikaz pojavnih oken.';
$messages['requesttimedout'] = 'Zahteva je potekla';
$messages['errorreadonly'] = 'Operacije ni bilo mogoče izvršiti. Mapa je na voljo samo za branje.';
$messages['errornoperm'] = 'Operacije ni bilo mogoče izvršiti. Dostop zavrnjen.';
$messages['erroroverquota'] = 'Operacije ni mogoče izvršiti. Diskovni prostor je zaseden.';
$messages['erroroverquotadelete'] = 'Zmanjkalo je diskovnega prostora. Za izbris sporočila uporabite tipki SHIFT+DEL.';
$messages['invalidrequest'] = 'Neveljavna zahteva. Podatki niso bili shranjeni.';
$messages['invalidhost'] = 'Nepravilno ime strežnika';
$messages['nomessagesfound'] = 'V poštnem predalu ni sporočil.';
$messages['loggedout'] = 'Uspešno ste zaključili sejo. Nasvidenje!';
$messages['mailboxempty'] = 'Poštni predal je prazen.';
$messages['nomessages'] = 'Ni sporočil';
$messages['refreshing'] = 'Osvežujem...';
$messages['loading'] = 'Nalaganje...';
$messages['uploading'] = 'Prenos dokumenta na strežnik...';
$messages['attaching'] = 'Pripenjanje dokumenta...';
$messages['uploadingmany'] = 'Nalaganje dokumentov..';
$messages['loadingdata'] = 'Nalaganje podatkov...';
$messages['checkingmail'] = 'Preverjanje novih sporočil...';
$messages['sendingmessage'] = 'Pošiljanje sporočil...';
$messages['messagesent'] = 'Sporočilo je bilo uspešno poslano.';
$messages['savingmessage'] = 'Shranjevanje sporočila...';
$messages['messagesaved'] = 'Sporočilo je bilo shranjeno v Osnutke';
$messages['successfullysaved'] = 'Uspešno shranjeno.';
$messages['savingresponse'] = 'Shranjevanje odgovora...';
$messages['deleteresponseconfirm'] = 'Ste prepričani, da želite izbrisati ta odgovor?';
$messages['addedsuccessfully'] = 'Stik je bil uspešno dodan v imenik.';
$messages['contactexists'] = 'Stik s tem elektronskim naslovom že obstaja';
$messages['contactnameexists'] = 'Stik s tem imenom že obstaja';
$messages['blockedimages'] = 'Zaradi zaščite zasebnosti je prikaz slik v sporočilu onemogočen.';
$messages['encryptedmessage'] = 'Sporočilo je šifrirano in ne more biti prikazano.';
$messages['externalmessagedecryption'] = 'To je šifrirano sporočilo, ki ga lahko odšifrirate s pomočjo brskalnika.';
$messages['nopubkeyfor'] = 'V $email ni bilo mogoče najti javnega ključa';
$messages['nopubkeyforsender'] = 'Veljavnega javnega ključa za pošiljatelja ni bilo mogoče najti. Ali želite šifrirati sporočila samo za naslovnike?';
$messages['encryptnoattachments'] = 'Priponke, ki ste jih že naložili, ne morejo biti šifrirane. Dodajte jih znova v urejevalnik.';
$messages['searchpubkeyservers'] = 'Ali želite manjkajoče javne ključe poiskati na javno dostopnih strežnikih?';
$messages['encryptpubkeysfound'] = 'Najdeni so bili naslednji javni ključi:';
$messages['nocontactsfound'] = 'Ni stikov.';
$messages['contactnotfound'] = 'Iskanega stika ni bilo mogoče najti.';
$messages['sendingfailed'] = 'Sporočila ni bilo mogoče poslati.';
$messages['senttooquickly'] = 'Počakajte $sec sekund in nato znova poskusite s pošiljanjem sporočila.';
$messages['errorsavingsent'] = 'Pri shranjevanju poslanega sporočila je prišlo do napake.';
$messages['errorsaving'] = 'Pri shranjevanju je prišlo do napake.';
$messages['errormoving'] = 'Sporočila ni bilo mogoče premakniti.';
$messages['errorcopying'] = 'Sporočila ni bilo mogoče kopirati.';
$messages['errordeleting'] = 'Sporočila ni bilo mogoče izbrisati.';
$messages['errormarking'] = 'Sporočila ni bilo mogoče označiti.';
$messages['deletecontactconfirm']  = 'Ste prepričani, da želite izbrisati označen(e) stik(e)?';
$messages['deletegroupconfirm']  = 'Ste prepričani, da želite izbrisati izbrano skupino?';
$messages['deletemessagesconfirm'] = 'Ste prepričani, da želite izbrisati označeno(a) sporočilo(a)?';
$messages['deletefolderconfirm']  = 'Ste prepričani, da želite to mapo izbrisati?';
$messages['purgefolderconfirm']  = 'Ste prepričani, da želite izbrisati vsa sporočila v mapi?';
$messages['contactdeleting'] = 'Brisanje stika/ov...';
$messages['groupdeleting'] = 'Brisanje skupine...';
$messages['folderdeleting'] = 'Brisanje mape...';
$messages['foldermoving'] = 'Premikanje mape...';
$messages['foldersubscribing'] = 'Prijavljanje mape...';
$messages['folderunsubscribing'] = 'Odjavljanje mape...';
$messages['formincomplete'] = 'Obrazec ni v celoti izpolnjen';
$messages['noemailwarning'] = 'Vnesite veljaven elektronski naslov';
$messages['nonamewarning']  = 'Vnesite ime';
$messages['nopagesizewarning'] = 'Vnesite velikost strani';
$messages['nosenderwarning'] = 'Vnesite elektronski naslov pošiljatelja.';
$messages['recipientsadded'] = 'Naslovnik[i] uspešno dodan[i]';
$messages['norecipientwarning'] = 'Vnesite vsaj enega prejemnika sporočila';
$messages['disclosedrecipwarning'] = 'Vsi prejemniki bodo videli naslove drugih prejemnikov sporočila. Uporabite polje Skp, da zaščitite njihovo zasebnost.';
$messages['disclosedreciptitle'] = 'Preveliko število javnih naslovov prejemnikov';
$messages['nosubjectwarning']  = 'Polje "Zadeva" je prazno. Želite dodati besedilo v to polje?';
$messages['nosubjecttitle']  = 'Brez naslova';
$messages['nobodywarning'] = 'Želite poslati sporočilo brez besedila?';
$messages['notsentwarning'] = 'Sporočilo ni bilo poslano in vsebuje neshranjene spremembe. Želite spremembe zavreči?';
$messages['restoresavedcomposedata'] = 'Ali želite nadaljevati z urejanjem še neodposlanega osnutka:\n\nZadeva: $subject\nShranjeno dne: $date\n\n ';
$messages['nosearchname'] = 'Vnesite ime ali elektronski naslov stika';
$messages['notuploadedwarning'] = 'Priponke se še nalagajo na strežnik. Počakajte ali prekinite prenos.';
$messages['searchsuccessful'] = '$nr najdenih sporočil';
$messages['contactsearchsuccessful'] = '$nr najdenih stikov.';
$messages['searchnomatch'] = 'Ni zadetkov';
$messages['searching'] = 'Iskanje...';
$messages['checking'] = 'Preverjanje...';
$messages['stillsearching'] = 'Iskanje v teku...';
$messages['nospellerrors'] = 'V tekstu ni bilo nobenih pravopisnih napak';
$messages['folderdeleted'] = 'Mapa je bila uspešno izbrisana.';
$messages['foldersubscribed'] = 'Mapa je bila uspešno prijavljena.';
$messages['folderunsubscribed'] = 'Mapa je bila uspešno odjavljena.';
$messages['deletedsuccessfully'] = 'Uspešno izbrisano';
$messages['converting'] = 'Odstranjevanje nastavitev oblikovanja...';
$messages['messageopenerror'] = 'Sporočila ni bilo mogoče prenesti iz strežnika';
$messages['filelinkerror'] = 'Pripenjanje dokumenta je spodletelo.';
$messages['fileuploaderror'] = 'Prenos datoteke je spodletel';
$messages['filesizeerror'] = 'Naložena datoteka presega največjo dovoljeno velikost $size';
$messages['filecounterror'] = 'Na strežnik lahko prenesete največ $count dokumentov naenkrat.';
$messages['msgsizeerror'] = 'Datoteke ni bilo mogoče dodati. Največja dovoljena velikost sporočila ($size) je bila presežena.';
$messages['copysuccess'] = 'Uspešno ste kopirali $nr stikov.';
$messages['movesuccess'] = 'Uspešno ste premaknili $nr stikov.';
$messages['copyerror'] = 'Stikov ni bilo mogoče kopirati.';
$messages['moveerror'] = 'Stikov ni bilo mogoče premakniti.';
$messages['sourceisreadonly'] = 'Ta naslov je na voljo samo za branje';
$messages['errorsavingcontact'] = 'Stika ni bilo mogoče shraniti';
$messages['movingmessage'] = 'Premikanje sporočila...';
$messages['copyingmessage'] = 'Kopiranje sporočila...';
$messages['copyingcontact'] = 'Kopiranje stika/ov';
$messages['movingcontact'] = 'Premikanje stika(ov)...';
$messages['deletingmessage'] = 'Brisanje sporočil/a';
$messages['markingmessage'] = 'Označevanje sporočil/a';
$messages['addingmember'] = 'Dodajanje stika/ov v skupino...';
$messages['removingmember'] = 'Odstranjevanje stika/ov iz skupine..';
$messages['receiptsent'] = 'Sporočilo o branju je bilo uspešno poslano';
$messages['errorsendingreceipt'] = 'Sporočila o branju ni bilo mogoče poslati';
$messages['deleteidentityconfirm'] = 'Ste prepričani, da želite izbrisati to identiteto?';
$messages['nodeletelastidentity'] = 'Te identitete ni mogoče izbrisati, saj je edina.';
$messages['forbiddencharacter'] = 'Ime mape vsebuje nedovoljen znak';
$messages['selectimportfile'] = 'Izberite datoteko, ki jo želite prenesti';
$messages['addresswriterror'] = 'Izbran imenik ni zapisljiv';
$messages['contactaddedtogroup'] = 'Stik je bil uspešno dodan v skupino';
$messages['contactremovedfromgroup'] = 'Stik je bil uspešno izbrisan iz skupine';
$messages['nogroupassignmentschanged'] = 'Dodeljevanje skupini ni bilo spremenjeno.';
$messages['importwait'] = 'Uvažanje poteka...';
$messages['importformaterror'] = 'Uvoz ni uspel! Uvožena datoteka ni pravega formata.';
$messages['importconfirm'] = '<b>Uspešno uvoženi $inserted stiki, $skipped stikov že obstaja v imeniku</b>:<p><em>$names</em></p>';
$messages['importconfirmskipped'] = '<b>Preskočeni že obstoječi vnosi $skipped </b>';
$messages['importmessagesuccess'] = 'Upešno ste uvozili $nr sporočil.';
$messages['importmessageerror'] = 'Uvoz je spodletel. Naložena datoteka ni veljavno sporočilo ali poštna datoteka';
$messages['opnotpermitted'] = 'Operacija ni dovoljena.';
$messages['nofromaddress'] = 'V izbrani identiteti manjka elektronski naslov.';
$messages['editorwarning'] = 'Preklop med urejevalniki besedila lahko povzroči izgubo oblikovanja besedila. Želite nadaljevati?';
$messages['httpreceivedencrypterror'] = 'Prišlo je do večje napake v konfiguraciji. Obrnite se na skrbnika sistema.  <b>Sporočila ni bilo mogoče poslati.</b>';
$messages['smtpconnerror'] = 'Napaka pri pošiljanju ($code): Povezava s strežnikom je spodletela';
$messages['smtpautherror'] = 'Napaka pri pošiljanju($code): Avtentikacija je spodletela';
$messages['smtpfromerror'] = 'Napaka pri pošiljanju ($code): Neveljaven elektronski naslov pošiljatelja "$from" ($msg)';
$messages['smtptoerror'] = 'Napaka pri pošiljanju ($code): Neveljaven elektronski naslov prejemnika "$to" ($msg)';
$messages['smtprecipientserror'] = 'Napaka pri pošiljanju: Seznama prejemnikov ni bilo mogoče razčleniti';
$messages['smtperror'] = 'Napaka pri pošiljanju:$msg';
$messages['emailformaterror'] = 'Neveljaven elektronski naslov: $email';
$messages['toomanyrecipients'] = 'Navedli ste preveč prejemnikov. Zmanjšajte število prejemnikov na $max';
$messages['maxgroupmembersreached'] = 'Število članov skupine presega največje dovoljeno število $max.';
$messages['internalerror'] = 'Prišlo je do napake. Poskusite znova.';
$messages['contactdelerror'] = 'Stika/ov ni bilo mogoče izbrisati';
$messages['contactdeleted'] = 'Stik/i so bili uspešno izbrisani';
$messages['contactrestoreerror'] = 'Ni bilo mogoče obnoviti izbrisanih stikov.';
$messages['contactrestored'] = 'Stiki so bili uspešno obnovljeni.';
$messages['groupdeleted'] = 'Skupina je bila uspešno izbrisana';
$messages['grouprenamed'] = 'Skupina je bila uspešno preimenovana';
$messages['groupcreated'] = 'Skupina je bila uspešno ustvarjena';
$messages['savedsearchdeleted'] = 'Shranjeno iskanje je bilo uspešno izbrisano.';
$messages['savedsearchdeleteerror'] = 'Ni bilo mogoče izbrisati shranjenega iskanja.';
$messages['savedsearchcreated'] = 'Iskanje je bilo uspešno shranjeno.';
$messages['savedsearchcreateerror'] = 'Iskanja ni bilo mogoče shraniti.';
$messages['messagedeleted'] = 'Sporočila so bila uspešno izbrisana';
$messages['messagemoved'] = 'Sporočila so bila uspešno premaknjena';
$messages['messagemovedtotrash'] = 'Sporočilo(a) so bila uspešno premaknjena v Smeti.';
$messages['messagecopied'] = 'Sporočila so bila uspešno kopirana';
$messages['messagemarked'] = 'Sporočila so bila uspešno označena';
$messages['autocompletechars'] = 'Vnesite vsaj $min znakov za samodejno dokončanje';
$messages['autocompletemore'] = 'Z iskanjem se ujema več vnosov. Vnesite dodatne črke.';
$messages['namecannotbeempty'] = 'Imena ni mogoče izbrisati';
$messages['nametoolong'] = 'Ime je predolgo';
$messages['namedotforbidden'] = 'Ime mape se ne more začeti s piko.';
$messages['folderupdated'] = 'Mapa je bila uspešno posodobljena';
$messages['foldercreated'] = 'Mapa je bila uspešno ustvarjena';
$messages['invalidimageformat'] = 'Neveljaven format slike';
$messages['mispellingsfound'] = 'V sporočilu so bile najdene napake v črkovanju';
$messages['parentnotwritable'] = 'Podmape v tej mapi ni bilo mogoče ustvariti/premakniti. Nimate pravic.';
$messages['messagetoobig'] = 'Sporočilo je preveliko za obdelavo.';
$messages['noscriptwarning'] = 'Opozorilo: Ta spletna stran zahteva Javascript! Za uporabo ga vključite v nastavitvah vašega brskalnika.';
$messages['messageissent'] = 'Sporočilo je bilo uspešno poslano, a ni bilo shranjeno. Ga želite shraniti?';
$messages['errnotfound'] = 'Datoteke ni bilo mogoče najti';
$messages['errnotfoundexplain'] = 'Zahtevanega vira ni bilo mogoče najti!';
$messages['errfailedrequest'] = 'Zahteva je spodletela';
$messages['errauthorizationfailed'] = 'Avtorizacija je spodletela';
$messages['errunauthorizedexplain'] = 'Ni bilo mogoče preveriti, ali ste avtorizirani za uporabo te storitve!';
$messages['errrequestcheckfailed'] = 'Preverjanje zahteve je spodletelo.';
$messages['errcsrfprotectionexplain'] = "Zaradi zagotavljanja varnosti je dostop do tega vira zaščiten proti CSRF.\n Če vidite to sporočilo, se verjetno niste odjavili, preden ste zapustili spletni brskalnik.\n\nZa nadaljevanje je potrebna vaša interakcija. ";
$messages['errcontactserveradmin'] = 'Obrnite se na skrbnika strežnika.';
$messages['clicktoresumesession'] = 'Kliknite tukaj za obnovitev prejšnje seje';
$messages['errcomposesession'] = 'Napaka v seji sestavljanja sporočila';
$messages['errcomposesessionexplain'] = 'Zahtevane seje za sestavljanje sporočila ni bilo mogoče najti.';
$messages['clicktocompose'] = 'Kliknite tukaj, če želite ustvariti novo sporočilo';
$messages['listempty'] = 'Seznam je prazen.';
$messages['listusebutton'] = 'Uporabite gumb »Ustvari« za dodajanje novega zapisa.';
$messages['emptyattachment'] = 'Ta priponka je videti prazna.<br>Prosimo, posvetujte se s pošiljateljem.';
