<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/timezones/
*/

$labels['tz:utc'] = 'UTC (Pasaulinis koordinuotasis laikas)';
$labels['tz:africa'] = 'Afrika';
$labels['tz:africa:abidjan'] = 'Abidžanas';
$labels['tz:africa:accra'] = 'Akra';
$labels['tz:africa:addis_ababa'] = 'Adis Abeba';
$labels['tz:africa:algiers'] = 'Alžyras';
$labels['tz:africa:asmara'] = 'Asmara';
$labels['tz:africa:bamako'] = 'Bamakas';
$labels['tz:africa:bangui'] = 'Bangis';
$labels['tz:africa:banjul'] = 'Bandžulis';
$labels['tz:africa:bissau'] = 'Bisau';
$labels['tz:africa:blantyre'] = 'Blantairas';
$labels['tz:africa:brazzaville'] = 'Brazavilis';
$labels['tz:africa:bujumbura'] = 'Bužumbūra';
$labels['tz:africa:cairo'] = 'Kairas';
$labels['tz:africa:casablanca'] = 'Kasablanka';
$labels['tz:africa:ceuta'] = 'Seuta';
$labels['tz:africa:conakry'] = 'Konakris';
$labels['tz:africa:dakar'] = 'Dakaras';
$labels['tz:africa:dar_es_salaam'] = 'Dar es Salamas';
$labels['tz:africa:djibouti'] = 'Džibutis';
$labels['tz:africa:douala'] = 'Duala';
$labels['tz:africa:el_aaiun'] = 'Al Ajunas';
$labels['tz:africa:freetown'] = 'Fritaunas';
$labels['tz:africa:gaborone'] = 'Gaboronas';
$labels['tz:africa:harare'] = 'Hararė';
$labels['tz:africa:johannesburg'] = 'Johanesburgas';
$labels['tz:africa:juba'] = 'Džuba';
$labels['tz:africa:kampala'] = 'Kampala';
$labels['tz:africa:khartoum'] = 'Chartumas';
$labels['tz:africa:kigali'] = 'Kigalis';
$labels['tz:africa:kinshasa'] = 'Kinšasa';
$labels['tz:africa:lagos'] = 'Lagosas';
$labels['tz:africa:libreville'] = 'Librevilis';
$labels['tz:africa:lome'] = 'Lomė';
$labels['tz:africa:luanda'] = 'Luanda';
$labels['tz:africa:lubumbashi'] = 'Lubumbašis';
$labels['tz:africa:lusaka'] = 'Lusaka';
$labels['tz:africa:malabo'] = 'Malabas';
$labels['tz:africa:maputo'] = 'Maputu';
$labels['tz:africa:maseru'] = 'Maseru';
$labels['tz:africa:mbabane'] = 'Mbabanė';
$labels['tz:africa:mogadishu'] = 'Mogadišas';
$labels['tz:africa:monrovia'] = 'Monrovija';
$labels['tz:africa:nairobi'] = 'Nairobis';
$labels['tz:africa:ndjamena'] = 'Ndžamena';
$labels['tz:africa:niamey'] = 'Niamėjus';
$labels['tz:africa:nouakchott'] = 'Nuakšotas';
$labels['tz:africa:ouagadougou'] = 'Uagadugu';
$labels['tz:africa:porto-novo'] = 'Porto Novas';
$labels['tz:africa:sao_tome'] = 'San Tomė';
$labels['tz:africa:tripoli'] = 'Tripolis';
$labels['tz:africa:tunis'] = 'Tunisas';
$labels['tz:africa:windhoek'] = 'Vindhukas';
$labels['tz:america'] = 'Amerika';
$labels['tz:america:adak'] = 'Adakas';
$labels['tz:america:anchorage'] = 'Ankoridžas';
$labels['tz:america:anguilla'] = 'Angilija';
$labels['tz:america:antigua'] = 'Antigva';
$labels['tz:america:araguaina'] = 'Araguaina';
$labels['tz:america:argentina'] = 'Argentina';
$labels['tz:america:argentina:buenos_aires'] = 'Buenos Airės';
$labels['tz:america:argentina:catamarca'] = 'Katamarka';
$labels['tz:america:argentina:cordoba'] = 'Kordoba';
$labels['tz:america:argentina:jujuy'] = 'Chuchujus';
$labels['tz:america:argentina:la_rioja'] = 'La Riocha';
$labels['tz:america:argentina:mendoza'] = 'Mendosa';
$labels['tz:america:argentina:rio_gallegos'] = 'Rio Galjegosas';
$labels['tz:america:argentina:salta'] = 'Salta';
$labels['tz:america:argentina:san_juan'] = 'San Chuanas';
$labels['tz:america:argentina:san_luis'] = 'San Luisas';
$labels['tz:america:argentina:tucuman'] = 'Tukumanas';
$labels['tz:america:argentina:ushuaia'] = 'Ušuaja';
$labels['tz:america:aruba'] = 'Aruba';
$labels['tz:america:asuncion'] = 'Asunsjonas';
$labels['tz:america:atikokan'] = 'Atikokanas';
$labels['tz:america:bahia'] = 'Bahija';
$labels['tz:america:barbados'] = 'Barbadosas';
$labels['tz:america:belize'] = 'Belizas';
$labels['tz:america:boa_vista'] = 'Boa Vista';
$labels['tz:america:bogota'] = 'Bogota';
$labels['tz:america:boise'] = 'Boizis';
$labels['tz:america:cambridge_bay'] = 'Kembridž Bėjus';
$labels['tz:america:campo_grande'] = 'Kampo Grandė';
$labels['tz:america:cancun'] = 'Kankunas';
$labels['tz:america:caracas'] = 'Karakasas';
$labels['tz:america:cayenne'] = 'Kajena';
$labels['tz:america:chicago'] = 'Čikaga';
$labels['tz:america:chihuahua'] = 'Čihuahua';
$labels['tz:america:costa_rica'] = 'Kosta Rika';
$labels['tz:america:creston'] = 'Krestonas';
$labels['tz:america:cuiaba'] = 'Kujaba';
$labels['tz:america:curacao'] = 'Kiurasao';
$labels['tz:america:dawson'] = 'Dosonas';
$labels['tz:america:dawson_creek'] = 'Dosono įlanka';
$labels['tz:america:denver'] = 'Denveris';
$labels['tz:america:detroit'] = 'Detroitas';
$labels['tz:america:dominica'] = 'Dominika';
$labels['tz:america:edmonton'] = 'Edmontonas';
$labels['tz:america:eirunepe'] = 'Eirunepė';
$labels['tz:america:el_salvador'] = 'Salvadoras';
$labels['tz:america:fort_nelson'] = 'Fort Nelsonas';
$labels['tz:america:fortaleza'] = 'Fortaleza';
$labels['tz:america:godthab'] = 'Nukas';
$labels['tz:america:grand_turk'] = 'Grand Terkas';
$labels['tz:america:grenada'] = 'Grenada';
$labels['tz:america:guadeloupe'] = 'Gvadelupa';
$labels['tz:america:guatemala'] = 'Gvatemala';
$labels['tz:america:guayaquil'] = 'Gvajakilis';
$labels['tz:america:guyana'] = 'Gajana';
$labels['tz:america:halifax'] = 'Halifaksas';
$labels['tz:america:havana'] = 'Havana';
$labels['tz:america:hermosillo'] = 'Hermosiljas';
$labels['tz:america:indiana'] = 'Indiana';
$labels['tz:america:indiana:indianapolis'] = 'Indianapolis';
$labels['tz:america:indiana:marengo'] = 'Marengas';
$labels['tz:america:iqaluit'] = 'Ikaluitas';
$labels['tz:america:jamaica'] = 'Jamaika';
$labels['tz:america:juneau'] = 'Džunas';
$labels['tz:america:kentucky'] = 'Kentukis';
$labels['tz:america:kentucky:louisville'] = 'Luisvilis';
$labels['tz:america:kralendijk'] = 'Kralendeikas';
$labels['tz:america:la_paz'] = 'La Pasas';
$labels['tz:america:lima'] = 'Lima';
$labels['tz:america:los_angeles'] = 'Los Andželas';
$labels['tz:america:maceio'] = 'Masejas';
$labels['tz:america:managua'] = 'Managva';
$labels['tz:america:manaus'] = 'Manausas';
$labels['tz:america:marigot'] = 'Marigo';
$labels['tz:america:martinique'] = 'Martinika';
$labels['tz:america:matamoros'] = 'Matamorosas';
$labels['tz:america:mazatlan'] = 'Masatlanas';
$labels['tz:america:merida'] = 'Merida';
$labels['tz:america:metlakatla'] = 'Metlakatla';
$labels['tz:america:mexico_city'] = 'Meksikas';
$labels['tz:america:miquelon'] = 'Mikelonas';
$labels['tz:america:moncton'] = 'Monktonas';
$labels['tz:america:monterrey'] = 'Monterėjus';
$labels['tz:america:montevideo'] = 'Montevidėjas';
$labels['tz:america:nassau'] = 'Nasau';
$labels['tz:america:new_york'] = 'Niujorkas';
$labels['tz:america:nome'] = 'Nomas';
$labels['tz:asia'] = 'Azija';
$labels['tz:australia'] = 'Australija';
$labels['tz:europe'] = 'Europa';
$labels['tz:europe:vilnius'] = 'Vilnius';
