<?php

/**
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/roundcube/roundcube-webmail/plugin-enigma/
*/

$labels['encryption'] = 'التشفير';
$labels['enigmacerts'] = 'شهادات S / MIME';
$labels['enigmakeys'] = 'مفاتيح PGP';
$labels['keysfromto'] = 'مفاتيح $from إلى $to من $count';
$labels['keyname'] = 'الاسم';
$labels['keyid'] = 'مفتاح المعرّف';
$labels['keyuserid'] = 'معرّف المستخدم';
$labels['keytype'] = 'نوع المفتاح';
$labels['fingerprint'] = 'بصمة';
$labels['subkeys'] = 'مفاتيح فرعية';
$labels['keyprops'] = 'الخصائص الرئيسية';
$labels['basicinfo'] = 'المعلومات العامة';
$labels['userids'] = 'مستخدمون إضافيون';
$labels['typepublickey'] = 'المفتاح العام';
$labels['typekeypair'] = 'اقتران المفتاح';
$labels['keyattfound'] = 'تحتوي هذه الرسالة على مفتاح (مفاتيح) PGP مرفق.';
$labels['keyattimport'] = 'استيراد مفتاح (مفاتيح)';
$labels['typesign'] = 'علامة';
$labels['typeencrypt'] = 'تشفير';
$labels['typecert'] = 'تصديق';
$labels['typeauth'] = 'المصادقة';
$labels['subkeyid'] = 'المُعَرّف';
$labels['subkeyalgo'] = 'الخوارزمية';
$labels['subkeycreated'] = 'أُنشئ في';
$labels['subkeyexpires'] = 'تنتهي';
$labels['subkeyusage'] = 'استعمال';
$labels['expiresnever'] = 'أبداً';
$labels['unknown'] = 'مجهول';
$labels['uservalid'] = 'صالح';
$labels['userid'] = 'المُعَرّف';
$labels['valid'] = 'صالح';
$labels['supportencryption'] = 'تفعيل تشفير الرسائل والتوقيع';
$labels['supportsignatures'] = 'تفعيل التحقق من تواقيع الرسائل';
$labels['supportdecryption'] = 'تفعيل فك تشفير الرسالة';
$labels['signdefault'] = 'قم بتسجيل جميع الرسائل بشكل افتراضي';
$labels['importkeys'] = 'استيراد مفتاح (مفاتيح)';
$labels['keychpass'] = 'تغيير كلمة المرور';
$labels['newkeypass'] = 'كلمة المرور';
$labels['newkeytype'] = 'نوع المفتاح';
$labels['arialabelkeyexportoptions'] = 'خيارات تصدير المفاتيح';
$messages['decryptbadpass'] = 'فشل فك التشفير. رمز مرور خاطئ.';
$messages['signbadpass'] = 'فشل تسجيل الدخول. كلمة المرور خاطئة.';
$messages['nonameident'] = 'يجب أن يكون للهوية اسم مستخدم محدد!';
