<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Benvenuto in $product';
$labels['username'] = 'Nome Utente';
$labels['password'] = 'Password';
$labels['server'] = 'Server';
$labels['login'] = 'Accedi';
$labels['oauthlogin'] = 'Accedi con $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Esci';
$labels['mail'] = 'E-Mail';
$labels['settings'] = 'Impostazioni';
$labels['addressbook'] = 'Rubrica';
$labels['darkmode'] = 'Modalità scura';
$labels['lightmode'] = 'Modalità chiara';
$labels['inbox'] = 'Posta in arrivo';
$labels['drafts'] = 'Bozze';
$labels['sent'] = 'Inviata';
$labels['trash'] = 'Cestino';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Mostra nomi reali per le cartelle speciali';
$labels['subject'] = 'Oggetto';
$labels['from'] = 'Mittente';
$labels['sender'] = 'Mittente';
$labels['to'] = 'Destinatario';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Ccn';
$labels['replyto'] = 'Rispondi a';
$labels['followupto'] = 'Followup-To';
$labels['date'] = 'Data';
$labels['size'] = 'Dimensione';
$labels['priority'] = 'Priorità';
$labels['organization'] = 'Società';
$labels['readstatus'] = 'Visualizza lo stato';
$labels['listoptions'] = 'Elenca opzioni...';
$labels['listoptionstitle'] = 'Elenca opzioni';
$labels['mailboxlist'] = 'Cartelle';
$labels['messagesfromto'] = 'Messaggi da $from a $to di $count';
$labels['threadsfromto'] = 'Argomenti da $from a $to di $count';
$labels['messagenrof'] = 'Messaggio $nr di $count';
$labels['fromtoshort'] = '$from – $to di $count';
$labels['copy'] = 'Copia';
$labels['move'] = 'Sposta';
$labels['moveto'] = 'Sposta in...';
$labels['copyto'] = 'Copia su...';
$labels['download'] = 'Download';
$labels['open'] = 'Apri';
$labels['showattachment'] = 'Visualizza';
$labels['showanyway'] = 'Visualizza comunque';
$labels['filename'] = 'Nome file';
$labels['filesize'] = 'Dimensione file';
$labels['addtoaddressbook'] = 'Aggiungi alla rubrica';
$labels['sun'] = 'Dom';
$labels['mon'] = 'Lun';
$labels['tue'] = 'Mar';
$labels['wed'] = 'Mer';
$labels['thu'] = 'Gio';
$labels['fri'] = 'Ven';
$labels['sat'] = 'Sab';
$labels['sunday'] = 'Domenica';
$labels['monday'] = 'Lunedì';
$labels['tuesday'] = 'Martedì';
$labels['wednesday'] = 'Mercoledì';
$labels['thursday'] = 'Giovedì';
$labels['friday'] = 'Venerdì';
$labels['saturday'] = 'Sabato';
$labels['jan'] = 'Gen';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Maggio';
$labels['jun'] = 'Giu';
$labels['jul'] = 'Lug';
$labels['aug'] = 'Ago';
$labels['sep'] = 'Set';
$labels['oct'] = 'Ott';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dic';
$labels['longjan'] = 'Gennaio';
$labels['longfeb'] = 'Febbraio';
$labels['longmar'] = 'Marzo';
$labels['longapr'] = 'Aprile';
$labels['longmay'] = 'Maggio';
$labels['longjun'] = 'Giugno';
$labels['longjul'] = 'Luglio';
$labels['longaug'] = 'Agosto';
$labels['longsep'] = 'Settembre';
$labels['longoct'] = 'Ottobre';
$labels['longnov'] = 'Novembre';
$labels['longdec'] = 'Dicembre';
$labels['today'] = 'Oggi';
$labels['refresh'] = 'Aggiorna';
$labels['checkmail'] = 'Controlla nuovi messaggi';
$labels['compose'] = 'Nuovo messaggio';
$labels['writenewmessage'] = 'Scrivi un nuovo messaggio';
$labels['reply'] = 'Rispondi';
$labels['replytomessage'] = 'Rispondi al mittente';
$labels['replytoallmessage'] = 'Rispondi al mittente e ai destinatari';
$labels['replyall'] = 'Rispondi a tutti';
$labels['replylist'] = 'Rispondi alla mailing list';
$labels['forward'] = 'Inoltra';
$labels['forwardinline'] = 'Inoltra come messaggio';
$labels['forwardattachment'] = 'Inoltra come allegato';
$labels['forwardmessage'] = 'Inoltra il messaggio';
$labels['bouncemsg'] = 'Invia di nuovo (bounce)';
$labels['bounce'] = 'Reinviare';
$labels['deletemessage'] = 'Elimina il messaggio';
$labels['movemessagetotrash'] = 'Sposta il messaggio nel cestino';
$labels['printmessage'] = 'Stampa il messaggio';
$labels['previousmessage'] = 'Visualizza il messaggio precedente';
$labels['firstmessage'] = 'Visualizza il primo messaggio';
$labels['nextmessage'] = 'Visualizza il messaggio successivo';
$labels['lastmessage'] = 'Visualizza l\'ultimo messaggio';
$labels['backtolist'] = 'Torna alla lista messaggi';
$labels['viewsource'] = 'Visualizza sorgente messaggio';
$labels['mark'] = 'Contrassegna';
$labels['markmessages'] = 'Marca i messaggi';
$labels['markread'] = 'Letti';
$labels['markunread'] = 'Non letti';
$labels['markflagged'] = 'Contrassegnato';
$labels['markunflagged'] = 'Non contrassegnato';
$labels['markundeleted'] = 'Come non eliminato';
$labels['moreactions'] = 'Altre operazioni...';
$labels['markallread'] = 'Contrassegna tutti come letti';
$labels['folders-cur'] = 'Seleziona solo la cartelle';
$labels['folders-sub'] = 'Seleziona la cartelle e le sue sottocartelle';
$labels['folders-all'] = 'Tutte le cartelle';
$labels['more'] = 'Azioni';
$labels['back'] = 'Indietro';
$labels['options'] = 'Opzioni';
$labels['composeoptions'] = 'Opzioni di composizione';
$labels['optionsandattachments'] = 'Opzioni ed allegati';
$labels['actions'] = 'Azioni';
$labels['first'] = 'Primo';
$labels['last'] = 'Ultimo';
$labels['previous'] = 'Precedente';
$labels['next'] = 'Successivo';
$labels['select'] = 'Seleziona';
$labels['selection'] = 'Selezione';
$labels['all'] = 'Tutti';
$labels['none'] = 'Nessuno';
$labels['currpage'] = 'Pagina corrente';
$labels['isread'] = 'Letto';
$labels['unread'] = 'Non letto';
$labels['flagged'] = 'Contrassegnato';
$labels['unflagged'] = 'Non contrassegnato';
$labels['unanswered'] = 'Senza risposta';
$labels['withattachment'] = 'Con allegato';
$labels['deleted'] = 'Eliminato';
$labels['undeleted'] = 'Non eliminato';
$labels['replied'] = 'Risposta';
$labels['forwarded'] = 'Inoltrata';
$labels['invert'] = 'Inverti';
$labels['filter'] = 'Filtra';
$labels['list'] = 'Elenco';
$labels['threads'] = 'Argomenti';
$labels['expand-all'] = 'Espandi tutto';
$labels['expand-unread'] = 'Espandi non letti';
$labels['collapse-all'] = 'Richiudi tutti';
$labels['threaded'] = 'Per argomenti';
$labels['showunread'] = 'Mostra messaggi non letti';
$labels['autoexpand_threads'] = 'Espandi';
$labels['do_expand'] = 'tutti gli argomenti';
$labels['expand_only_unread'] = 'solo con messaggi non letti';
$labels['fromto'] = 'Mittente/Destinatario';
$labels['flag'] = 'Contrassegnato';
$labels['attachment'] = 'Allegato';
$labels['nonesort'] = 'Nessuno';
$labels['sentdate'] = 'Data d\'invio';
$labels['arrival'] = 'Data di arrivo';
$labels['asc'] = 'crescente';
$labels['desc'] = 'descrescente';
$labels['listcolumns'] = 'Elenca colonne';
$labels['listsorting'] = 'Ordina per';
$labels['listorder'] = 'Ordinamento';
$labels['listmode'] = 'Modalità di visualizzazione';
$labels['lmode'] = 'Modalità lista';
$labels['layout'] = 'Layout';
$labels['layoutwidescreen'] = 'Widescreen';
$labels['layoutdesktop'] = 'Desktop';
$labels['layoutlist'] = 'Elenco';
$labels['layoutwidescreendesc'] = 'Schermo largo (vista a 3 colonne)';
$labels['layoutdesktopdesc'] = 'Desktop (elenco ampio e anteprima del messaggio di sotto)';
$labels['layoutlistdesc'] = 'Elenco (senza anteprima del messaggio)';
$labels['folderactions'] = 'Azioni cartella...';
$labels['compact'] = 'Compatta';
$labels['empty'] = 'Svuota';
$labels['importmessages'] = 'Importa messaggi';
$labels['mailimportdesc'] = 'Puoi importare file di e-mail in formato <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> o <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Files multipli possono essere compressi in archivi zip.';
$labels['quota'] = 'Spazio utilizzato';
$labels['unknown'] = 'sconosciuto';
$labels['unlimited'] = 'illimitato';
$labels['quotatype'] = 'Tipo di quota';
$labels['quotatotal'] = 'Limite';
$labels['quotaused'] = 'Utilizzato';
$labels['quotastorage'] = 'Spazio disco';
$labels['quotamessage'] = 'Contatore messaggi';
$labels['shortheaderdate'] = 'Il $date';
$labels['shortheaderto'] = 'A $to il $date';
$labels['shortheaderfrom'] = 'Da $from il $date';
$labels['quicksearch'] = 'Ricerca veloce';
$labels['searchplaceholder'] = 'Cerca...';
$labels['resetsearch'] = 'Annulla ricerca';
$labels['searchmod'] = 'Ambito di ricerca';
$labels['msgtext'] = 'Intero messaggio';
$labels['body'] = 'Corpo';
$labels['type'] = 'Tipo';
$labels['namex'] = 'Nome';
$labels['searchscope'] = 'Contesto';
$labels['currentfolder'] = 'Cartella corrente';
$labels['subfolders'] = 'Questa e le sottocartelle';
$labels['allfolders'] = 'Tutte le cartelle';
$labels['searchinterval-1W'] = 'più vecchio di una settimana';
$labels['searchinterval-1M'] = 'più vecchio di un mese';
$labels['searchinterval-1Y'] = 'più vecchio di un anno';
$labels['searchinterval1W'] = 'più recente di una settimana';
$labels['searchinterval1M'] = 'più recente di un mese';
$labels['searchinterval1Y'] = 'più recente di un anno';
$labels['openinextwin'] = 'Apri in una nuova finestra';
$labels['emlsave'] = 'Scarica (.eml)';
$labels['changeformattext'] = 'Visualizza nel formato testo semplice';
$labels['changeformathtml'] = 'Visualizza nel formato HTML';
$labels['editasnew'] = 'Modifica come nuovo';
$labels['send'] = 'Invia';
$labels['sendmessage'] = 'Invia messaggio';
$labels['savemessage'] = 'Salva come bozza';
$labels['addattachment'] = 'Allega un file';
$labels['charset'] = 'Insieme di caratteri';
$labels['editortype'] = 'Tipo editor';
$labels['returnreceipt'] = 'Ricevuta di ritorno';
$labels['dsn'] = 'Notifica di consegna';
$labels['keepformatting'] = 'Mantieni la formattazione';
$labels['mailreplyintro'] = 'Il $date $sender ha scritto:';
$labels['originalmessage'] = 'Messaggio originale';
$labels['selectimage'] = 'Selezione immagine';
$labels['addimage'] = 'Aggiungi immagine';
$labels['selectmedia'] = 'Seleziona video';
$labels['addmedia'] = 'Aggiungi video';
$labels['encrypt'] = 'Cifra';
$labels['encryptmessage'] = 'Cifra il messaggio';
$labels['encryptmessagemailvelope'] = 'Cifra il messaggio con Mailvelope';
$labels['importpubkeys'] = 'Importa le chiavi pubbliche';
$labels['encryptedsendialog'] = 'Invia un messaggio cifrato';
$labels['encryptandsign'] = 'Cifra e firma';
$labels['keyid'] = 'ID della chiave';
$labels['keylength'] = 'Bit';
$labels['keyexpired'] = 'Scaduta';
$labels['keyrevoked'] = 'Revocata';
$labels['bccinstead'] = 'Usa ccn';
$labels['addheader'] = 'Aggiungi destinatario (intestazione)';
$labels['insert'] = 'Inserisci';
$labels['insertcontact'] = 'Aggiungi contatto(i)';
$labels['recipient'] = 'Destinatario';
$labels['recipientedit'] = 'Modifica il destinatario';
$labels['editidents'] = 'Modifica identità';
$labels['spellcheck'] = 'Controllo ortografico';
$labels['checkspelling'] = 'Controlla ortografia';
$labels['resumeediting'] = 'Torna al messaggio';
$labels['revertto'] = 'Ripristina';
$labels['restore'] = 'Ripristina';
$labels['restoremessage'] = 'Ripristinare il messaggio?';
$labels['ignore'] = 'Ignora';
$labels['responses'] = 'Risposte';
$labels['insertresponse'] = 'Inserisci una risposta';
$labels['manageresponses'] = 'Gestione risposte';
$labels['newresponse'] = 'Crea una nuova risposta';
$labels['addresponse'] = 'Aggiungi risposta';
$labels['editresponse'] = 'Modifica risposta';
$labels['editresponses'] = 'Modifica risposte';
$labels['responsename'] = 'Nome';
$labels['responsetext'] = 'Testo della risposta';
$labels['attach'] = 'Allega';
$labels['attachments'] = 'Allegati';
$labels['upload'] = 'Invia';
$labels['uploadprogress'] = '$percent ($current su $total)';
$labels['close'] = 'Chiudi';
$labels['messageoptions'] = 'Opzioni messaggi...';
$labels['togglecomposeoptions'] = 'Passa alle impostazioni di composizione';
$labels['attachmentrename'] = 'Rinomina allegato';
$labels['low'] = 'Bassa';
$labels['lowest'] = 'Molto bassa';
$labels['normal'] = 'Normale';
$labels['high'] = 'Alta';
$labels['highest'] = 'Molto alta';
$labels['nosubject'] = '(nessun oggetto)';
$labels['showimages'] = 'Visualizza immagini';
$labels['allow'] = 'Permetti';
$labels['alwaysshow'] = 'Mostra sempre immagini da $sender';
$labels['alwaysallow'] = 'Permetti sempre da $sender';
$labels['isdraft'] = 'Questa è una bozza.';
$labels['andnmore'] = 'ancora $nr...';
$labels['details'] = 'Dettagli';
$labels['summary'] = 'Riepilogo';
$labels['headers'] = 'Intestazioni';
$labels['allheaders'] = 'Tutte le intestazioni...';
$labels['togglemoreheaders'] = 'Mostra più intestazioni dei messaggi';
$labels['togglefullheaders'] = 'Visualizza/nascondi intestazioni originali';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Testo semplice';
$labels['savesentmessagein'] = 'Salva i messaggi inviati in';
$labels['dontsave'] = 'non salvare';
$labels['maxuploadsize'] = 'La dimensione massima consentita è $size';
$labels['addcc'] = 'Aggiungi Cc';
$labels['addbcc'] = 'Aggiungi Ccn';
$labels['addreplyto'] = 'Aggiungi Rispondi a';
$labels['addfollowupto'] = 'Aggiungi Followup-To';
$labels['sendreceipt'] = 'Invia conferma di lettura?';
$labels['mdnrequest'] = 'Il mittente ha richiesto di ricevere una notifica dell\'avvenuta lettura del messaggio. Intendi inviare tale notifica?';
$labels['receiptread'] = 'Ricevuta di ritorno (letto)';
$labels['yourmessage'] = 'Questa è la ricevuta di ritorno del messaggio inviato';
$labels['receiptnote'] = 'Nota: questa Ricevuta di ritorno attesta solamente che il messaggio è stato visualizzato nel computer del destinatario. Non c\'è pertanto alcuna garanzia che il destinatario abbia letto o compreso il suo contenuto.';
$labels['sendalwaysto'] = 'Invia sempre a $email';
$labels['zoomin'] = 'Ingrandisci';
$labels['zoomout'] = 'Rimpicciolisci';
$labels['rotate'] = 'Ruota';
$labels['increaseimage'] = 'Aumenta dimensione dell\'immagine';
$labels['decreaseimage'] = 'Diminuisci dimensione dell\'immagine';
$labels['rotateimage'] = 'Ruota immagine';
$labels['showtools'] = 'Mostra strumenti per l\'immagine';
$labels['hidetools'] = 'Nascondi strumenti per l\'immagine';
$labels['name'] = 'Nome visualizzato';
$labels['firstname'] = 'Nome';
$labels['surname'] = 'Cognome';
$labels['middlename'] = 'Secondo nome';
$labels['nameprefix'] = 'Prefisso';
$labels['namesuffix'] = 'Suffisso';
$labels['nickname'] = 'Soprannome';
$labels['jobtitle'] = 'Qualifica';
$labels['department'] = 'Dipartimento';
$labels['gender'] = 'Sesso';
$labels['maidenname'] = 'Cognome da nubile';
$labels['email'] = 'E-Mail';
$labels['phone'] = 'Telefono';
$labels['address'] = 'Indirizzo';
$labels['street'] = 'Via';
$labels['locality'] = 'Città';
$labels['zipcode'] = 'CAP';
$labels['region'] = 'Stato/provincia';
$labels['country'] = 'Nazione';
$labels['birthday'] = 'Compleanno';
$labels['anniversary'] = 'Anniversario';
$labels['website'] = 'Sito web';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Note';
$labels['male'] = 'maschio';
$labels['female'] = 'femmina';
$labels['manager'] = 'Dirigente';
$labels['assistant'] = 'Assistente';
$labels['spouse'] = 'Coniuge';
$labels['allfields'] = 'Tutti i campi';
$labels['search'] = 'Ricerca';
$labels['searchresult'] = 'Risultati ricerca';
$labels['advsearch'] = 'Ricerca avanzata';
$labels['advanced'] = 'Avanzata';
$labels['other'] = 'Altro';
$labels['printcontact'] = 'Stampa contatto';
$labels['qrcode'] = 'Codice QR';
$labels['typehome'] = 'Casa';
$labels['typework'] = 'Lavoro';
$labels['typeother'] = 'Altro';
$labels['typemobile'] = 'Cellulare';
$labels['typemain'] = 'Principale';
$labels['typehomefax'] = 'Fax casa';
$labels['typeworkfax'] = 'Fax lavoro';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Teledrin';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Assistente';
$labels['typehomepage'] = 'Home page';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profilo';
$labels['addfield'] = 'Aggiungi campo...';
$labels['addcontact'] = 'Aggiungi contatto';
$labels['editcontact'] = 'Modifica contatto';
$labels['contacts'] = 'Contatti';
$labels['contactproperties'] = 'Proprietà contatto';
$labels['contactnameandorg'] = 'Nome e società';
$labels['personalinfo'] = 'Informazioni personali';
$labels['personal'] = 'Personale';
$labels['contactphoto'] = 'Avatar';
$labels['edit'] = 'Modifica';
$labels['cancel'] = 'Annulla';
$labels['save'] = 'Salva';
$labels['delete'] = 'Elimina';
$labels['discard'] = 'Scarta';
$labels['continue'] = 'Continua';
$labels['ok'] = 'Ok';
$labels['rename'] = 'Rinomina';
$labels['addphoto'] = 'Aggiungi';
$labels['replacephoto'] = 'Sostituisci';
$labels['uploadphoto'] = 'Carica foto';
$labels['choosefile'] = 'Seleziona il file...';
$labels['choosefiles'] = 'Seleziona i files...';
$labels['browse'] = 'Sfoglia';
$labels['newcontact'] = 'Crea un nuovo contatto';
$labels['deletecontact'] = 'Elimina i contatti selezionati';
$labels['composeto'] = 'Invia messaggio a';
$labels['contactsfromto'] = 'Contatti da $from a $to di $count';
$labels['print'] = 'Stampa';
$labels['export'] = 'Esporta';
$labels['exportall'] = 'Esporta tutto';
$labels['exportsel'] = 'Esporta selezionati';
$labels['exportvcards'] = 'Esporta i contatti in formato vCard';
$labels['newgroup'] = 'Crea un nuovo gruppo';
$labels['addgroup'] = 'Aggiungi gruppo';
$labels['grouprename'] = 'Rinomina il gruppo';
$labels['groupdelete'] = 'Elimina il gruppo';
$labels['groupassign'] = 'Assegna a gruppo...';
$labels['groupremove'] = 'Rimuovi dal gruppo';
$labels['groupremoveselected'] = 'Rimuovi i contatti selezionati dal gruppo';
$labels['uponelevel'] = 'Sali di un livello';
$labels['previouspage'] = 'Pagina precedente';
$labels['firstpage'] = 'Prima pagina';
$labels['nextpage'] = 'Pagina successiva';
$labels['lastpage'] = 'Ultima pagina';
$labels['group'] = 'Gruppo';
$labels['groups'] = 'Gruppi';
$labels['listgroup'] = 'Elenca membri dei gruppi';
$labels['personaladrbook'] = 'Rubrica personale';
$labels['searchsave'] = 'Salva ricerca';
$labels['searchdelete'] = 'Elimina ricerca';
$labels['import'] = 'Importa';
$labels['importcontacts'] = 'Importa contatti';
$labels['importfromfile'] = 'Importa da file';
$labels['importtarget'] = 'Aggiungi contatti a';
$labels['importreplace'] = 'Sostituisci l\'intera rubrica';
$labels['importgroups'] = 'Importa le assegnazioni di gruppo';
$labels['importgroupsall'] = 'Tutti (crea i gruppi se necessario)';
$labels['importgroupsexisting'] = 'Solo per i gruppi esistenti';
$labels['importdesc'] = 'Puoi importare i contatti da una rubrica esistente.<br/>Attualmente è possibile l\'importazione di indirizzi in formato <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> o CSV.';
$labels['importmapdesc'] = 'Conferma che la mappatura dei campi di seguito sia corretta prima di procedere con l\'importazione dei dati CSV (separati da virgola).';
$labels['fieldnotmapped'] = 'Campo non mappato (non importare)';
$labels['skipheader'] = 'Non importare la prima riga (intestazioni)';
$labels['done'] = 'Fatto';
$labels['settingsfor'] = 'Impostazioni per';
$labels['about'] = 'Informazioni';
$labels['preferences'] = 'Preferenze';
$labels['userpreferences'] = 'Preferenze utente';
$labels['editpreferences'] = 'Modifica le preferenze per l\'utente';
$labels['identities'] = 'Identità';
$labels['manageidentities'] = 'Gestisci identità';
$labels['newidentity'] = 'Crea una nuova identità';
$labels['addidentity'] = 'Aggiungi identità';
$labels['editidentity'] = 'Modifica identità';
$labels['identityencryption'] = 'Cifratura';
$labels['preferhtml'] = 'Mostra HTML';
$labels['defaultcharset'] = 'Set di caratteri predefinito';
$labels['htmlmessage'] = 'Messaggio HTML';
$labels['messagepart'] = 'Parte';
$labels['digitalsig'] = 'Firma digitale';
$labels['dateformat'] = 'Formato data';
$labels['timeformat'] = 'Formato orario';
$labels['prettydate'] = 'Date più leggibili';
$labels['setdefault'] = 'Imposta predefinita';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Lingua';
$labels['timezone'] = 'Fuso orario';
$labels['pagesize'] = 'Righe per pagina';
$labels['signature'] = 'Firma';
$labels['dstactive'] = 'Gestione ora legale';
$labels['showinextwin'] = 'Apri il messaggio in una nuova finestra';
$labels['composeextwin'] = 'Componi in una nuova finestra';
$labels['htmleditor'] = 'Scrivi i messaggi in HTML';
$labels['htmlonreply'] = 'solo in risposta a messaggi HTML';
$labels['htmlonreplyandforward'] = 'su inoltro o risposta a messaggi HTML';
$labels['htmlsignature'] = 'Firma in HTML';
$labels['showemail'] = 'Visualizza indirizzi di posta con il nome visualizzato';
$labels['previewpane'] = 'Mostra l\'anteprima';
$labels['skin'] = 'Tema interfaccia';
$labels['logoutclear'] = 'Svuota il cestino all\'uscita';
$labels['logoutcompact'] = 'Compatta la Posta in arrivo all\'uscita';
$labels['uisettings'] = 'Interfaccia utente';
$labels['serversettings'] = 'Impostazioni server';
$labels['mailboxview'] = 'Impaginazione messaggi';
$labels['mdnrequests'] = 'Su richiesta per la ricevuta di ritorno';
$labels['askuser'] = 'chiedi conferma';
$labels['autosend'] = 'invia notifica';
$labels['autosendknown'] = 'invia notifica ai miei contatti, altrimenti chiedi conferma';
$labels['autosendknownignore'] = 'invia notifica ai miei contatti, altrimenti ignora';
$labels['autosendtrusted'] = 'invia ricevuta a mittenti attendibili, altrimenti chiedimelo';
$labels['autosendtrustedignore'] = 'invia la ricevuta a mittenti attendibili, altrimenti ignora';
$labels['ignorerequest'] = 'ignora la richiesta';
$labels['readwhendeleted'] = 'Marca il messaggio come letto prima di eliminarlo';
$labels['flagfordeletion'] = 'Marca il messaggio come eliminato invece di eliminarlo';
$labels['skipdeleted'] = 'Non mostrare i messaggi marcati come eliminati';
$labels['deletealways'] = 'Quando non è possibile spostare i messaggi nel Cestino, eliminali';
$labels['deletejunk'] = 'Elimina direttamente i messaggi in Spam';
$labels['showremoteimages'] = 'Mostra immagini remote contenute nel messaggio';
$labels['allowremoteresources'] = 'Permetti risorse remote (immagini, stili)';
$labels['fromknownsenders'] = 'da mittenti conosciuti';
$labels['fromtrustedsenders'] = 'da mittenti attendibili';
$labels['frommycontacts'] = 'dai miei contatti';
$labels['always'] = 'sempre';
$labels['alwaysbutplain'] = 'sempre, ad eccezione di quando si risponde in formato testo';
$labels['showinlineimages'] = 'Mostra immagini allegate sotto il messaggio';
$labels['autosavedraft'] = 'Salva le bozze automaticamente';
$labels['everynminutes'] = 'ogni $n minuto(i)';
$labels['refreshinterval'] = 'Aggiorna (controlla nuovi messaggi, ecc.)';
$labels['never'] = 'mai';
$labels['immediately'] = 'immediatamente';
$labels['messagesdisplaying'] = 'Visualizzazione messaggi';
$labels['messagescomposition'] = 'Composizione messaggi';
$labels['mimeparamfolding'] = 'Nomi allegati';
$labels['2231folding'] = 'RFC 2231 completo (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 completo (altri)';
$labels['force7bit'] = 'Usa la codifica MIME per i caratteri a 8-bit';
$labels['savelocalstorage'] = "Salva nell'archiviazione locale del browser (temporaneamente)";
$labels['advancedoptions'] = 'Opzioni avanzate';
$labels['toggleadvancedoptions'] = 'Passa alle impostazioni avanzate';
$labels['focusonnewmessage'] = 'Attiva la finestra del browser all\'arrivo di un nuovo messaggio';
$labels['checkallfolders'] = 'Controlla tutte le cartelle per la presenza di nuovi messaggi';
$labels['displaynext'] = 'Visualizza la voce successiva dell\'elenco dopo l\'eliminazione/spostamento';
$labels['defaultfont'] = 'Carattere standard per messaggi in HTML';
$labels['mainoptions'] = 'Opzioni principali';
$labels['browseroptions'] = 'Opzioni del browser';
$labels['section'] = 'Sezione';
$labels['maintenance'] = 'Manutenzione';
$labels['newmessage'] = 'Nuovo messaggio';
$labels['signatureoptions'] = 'Opzioni firma';
$labels['whenreplying'] = 'Quando rispondi';
$labels['replyempty'] = 'non citare il messaggio originale';
$labels['replytopposting'] = 'inizia il nuovo messaggio sopra quello originale';
$labels['replytoppostingnoindent'] = 'inizia il nuovo messaggio sopra quello originale (senza indentazione)';
$labels['replybottomposting'] = 'inizia il nuovo messaggio sotto quello originale';
$labels['replyremovesignature'] = 'Quando rispondi, rimuovi la firma dal messaggio originale';
$labels['autoaddsignature'] = 'Aggiungi automaticamente la firma';
$labels['newmessageonly'] = 'solo ai nuovi messaggi';
$labels['replyandforwardonly'] = 'solo alle risposte e inoltri';
$labels['insertsignature'] = 'Inserisci firma';
$labels['sigbelow'] = 'Inserire la firma sotto al testo citato';
$labels['sigseparator'] = 'Forzare il separatore standard nelle firme';
$labels['automarkread'] = 'Marca i messaggi come letti';
$labels['afternseconds'] = 'dopo $n secondi';
$labels['reqmdn'] = 'Richiedi sempre la ricevuta di ritorno';
$labels['reqdsn'] = 'Richiedi sempre la notifica di consegna';
$labels['replysamefolder'] = 'Salva risposta nella cartella del messaggio a cui si risponde';
$labels['defaultabook'] = 'Rubrica predefinita';
$labels['autocompletesingle'] = 'Non considerare gli indirizzi secondari nell\'autocompletamento';
$labels['listnamedisplay'] = 'Elenca contatti come';
$labels['contactformmode'] = 'Modalità modulo di contatto';
$labels['privatemode'] = 'Privato (Casa)';
$labels['businessmode'] = 'Business (Lavoro)';
$labels['collectedaddresses'] = 'Indirizzi collezionati';
$labels['collectedrecipients'] = 'Destinatari collezionati';
$labels['collectedrecipientsopt'] = 'Memorizza i destinatari delle email in uscita in';
$labels['collectedsendersopt'] = 'Memorizza mittenti attendibili in';
$labels['trustedsenders'] = 'Mittenti attendibili';
$labels['spellcheckbeforesend'] = 'Esegui il controllo ortografico prima di inviare un messaggio';
$labels['spellcheckoptions'] = 'Opzioni controllo ortografico';
$labels['spellcheckignoresyms'] = 'Ignora le parole contenenti simboli';
$labels['spellcheckignorenums'] = 'Ignora le parole contenenti numeri';
$labels['spellcheckignorecaps'] = 'Ignora le parole con tutte le lettere maiuscole';
$labels['addtodict'] = 'Aggiungi al dizionario';
$labels['mailtoprotohandler'] = 'Registra gestore per mailto:';
$labels['standardwindows'] = 'Gestisci i popup come finestre standard';
$labels['forwardmode'] = 'Inoltro messaggi';
$labels['inline'] = 'in linea';
$labels['asattachment'] = 'come allegato';
$labels['replyallmode'] = 'Azione predefinita del pulsante [Rispondi a tutti]';
$labels['replyalldefault'] = 'rispondi a tutti';
$labels['replyalllist'] = 'rispondi solo alla mailing list (se disponibile)';
$labels['allmessages'] = 'tutti i messaggi';
$labels['olderxdays'] = 'più vecchio di $x giorni';
$labels['folder'] = 'Cartella';
$labels['folders'] = 'Cartelle';
$labels['foldername'] = 'Nome cartella';
$labels['subscribed'] = 'Sottoscritta';
$labels['messagecount'] = 'Messaggi';
$labels['create'] = 'Crea';
$labels['createfolder'] = 'Crea nuova cartella';
$labels['managefolders'] = 'Gestione cartelle';
$labels['specialfolders'] = 'Cartelle speciali';
$labels['properties'] = 'Proprietà';
$labels['folderproperties'] = 'Proprietà cartella';
$labels['parentfolder'] = 'Cartella padre';
$labels['location'] = 'Ubicazione';
$labels['info'] = 'Informazioni';
$labels['getfoldersize'] = 'Clic per la dimensione della cartella';
$labels['changesubscription'] = 'Clic per cambiare sottoscrizione';
$labels['foldertype'] = 'Tipo di cartella';
$labels['personalfolder'] = 'Cartella privata';
$labels['otherfolder'] = 'Cartella di un altro utente';
$labels['sharedfolder'] = 'Cartella pubblica';
$labels['findfolders'] = 'Trova cartelle';
$labels['findcontacts'] = 'Trova contatti';
$labels['findmail'] = 'Trova messaggi di posta';
$labels['namespace.personal'] = 'Personale';
$labels['namespace.other'] = 'Altri utenti';
$labels['namespace.shared'] = 'Condivisa';
$labels['dualuselabel'] = 'Può contenere solo';
$labels['dualusemail'] = 'messaggi';
$labels['dualusefolder'] = 'cartella';
$labels['generate'] = 'Genera';
$labels['encryptioncreatekey'] = 'Crea una nuova coppia di chiavi';
$labels['openmailvelopesettings'] = 'Apri impostazioni di Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Ci sono $nr chiavi private corrispondenti memorizzate nel portachiavi Mailvelope:';
$labels['encryptionnoprivkeysinmailvelope'] = 'L\'indentità del server non dispone ancora di una chiave privata PGP memorizzata nell\'estensione Mailvelope. Vuoi crearne una per abilitare la cifratura dei messaggi?';
$labels['encryption'] = 'Cifratura';
$labels['mailvelopeoptions'] = 'Opzioni Mailvelope';
$labels['mailvelopemainkeyring'] = 'Usa il portachiavi principale di Mailvelope';
$labels['mailvelopenotfound'] = 'L\'estensione Mailvelope non è abilitata/installata nel tuo browser.';
$labels['sortby'] = 'Ordina per';
$labels['sortasc'] = 'Ordinamento crescente';
$labels['sortdesc'] = 'Ordinamento decrescente';
$labels['undo'] = 'Annulla';
$labels['installedplugins'] = 'Plugin installati';
$labels['plugin'] = 'Plugin';
$labels['version'] = 'Versione';
$labels['source'] = 'Sorgente';
$labels['destination'] = 'Destinazione';
$labels['license'] = 'Licenza';
$labels['support'] = 'Ottieni supporto';
$labels['savedsearches'] = 'Ricerche salvate';
$labels['dateformatY'] = 'AAAA';
$labels['dateformaty'] = 'AA';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'GG';
$labels['dateformatj'] = 'G';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Inglese';
$labels['westerneuropean'] = 'Europa occidentale';
$labels['easterneuropean'] = 'Europa orientale';
$labels['southeasterneuropean'] = 'Europa sud-orientale';
$labels['baltic'] = 'Baltiche';
$labels['cyrillic'] = 'Cirillico';
$labels['arabic'] = 'Arabo';
$labels['greek'] = 'Greco';
$labels['hebrew'] = 'Ebraico';
$labels['turkish'] = 'Turco';
$labels['nordic'] = 'Scandinavo';
$labels['thai'] = 'Tailandese';
$labels['celtic'] = 'Celtico';
$labels['vietnamese'] = 'Vietnamita';
$labels['japanese'] = 'Giapponese';
$labels['korean'] = 'Coreano';
$labels['chinese'] = 'Cinese';
$labels['arialabeltopnav'] = 'Controllo finestra';
$labels['arialabeltasknav'] = 'Attività dell\'applicazione';
$labels['arialabeltoolbar'] = 'Barra delle applicazioni';
$labels['arialabellistnav'] = 'Navigazione elenco';
$labels['arialabelactivetask'] = 'Attività attive';
$labels['arialabelmessagessearchfilter'] = 'Filtro lista delle email';
$labels['arialabelmailsearchform'] = 'Modulo ricerca messaggi di posta';
$labels['arialabelcontactsearchform'] = 'Modulo di ricerca contatti';
$labels['arialabelmailquicksearchbox'] = 'Ricerca messaggi di posta';
$labels['arialabelquicksearchbox'] = 'Immissione ricerca';
$labels['arialabelfoldersearchfilter'] = 'Filtro cartelle';
$labels['arialabelfoldersearchform'] = 'Modulo di ricerca cartelle';
$labels['arialabelfolderlist'] = 'Cartella selezione email';
$labels['arialabelmessagelist'] = 'Lista messaggi di posta';
$labels['arialabelmailpreviewframe'] = 'Anteprima messaggio';
$labels['arialabelmailboxmenu'] = 'Menu azione cartella';
$labels['arialabellistselectmenu'] = 'Menu lista selezione';
$labels['arialabelthreadselectmenu'] = 'Finestra elenco menu';
$labels['arialabelmessagelistoptions'] = 'Visualizzazione della lista dei messaggi e opzioni di ordinamento';
$labels['arialabelmailimportdialog'] = 'Dialogo importazione messaggio';
$labels['arialabelmessagenav'] = 'Navigazione messaggio';
$labels['arialabelmessagebody'] = 'Corpo messaggio';
$labels['arialabelmessageactions'] = 'Azione messaggi';
$labels['arialabelcontactquicksearch'] = 'Modulo ricerca contatti';
$labels['arialabelcontactsearchbox'] = 'Immissione ricerca contatti';
$labels['arialabelmessageheaders'] = 'Messaggio testata';
$labels['arialabelforwardingoptions'] = 'Opzioni di inoltro';
$labels['arialabelreplyalloptions'] = 'Opzione rispondi a tutti';
$labels['arialabelmoremessageactions'] = 'Altre azioni del messaggio';
$labels['arialabelmorecontactactions'] = 'Ulteriori azioni del contatto';
$labels['arialabelmarkmessagesas'] = 'Contrassegna messaggi selezionati come';
$labels['arialabelcomposeoptions'] = 'Impostazioni composizione';
$labels['arialabelresponsesmenu'] = 'Menu messaggi predefiniti';
$labels['arialabelattachmentuploadform'] = 'Allegato caricato da';
$labels['arialabelattachmentmenu'] = 'Opzioni allegato';
$labels['arialabelmailtomenu'] = 'Opzioni indirizzo di posta elettronica';
$labels['arialabelattachmentpreview'] = 'Anteprima allegato';
$labels['ariasummarycomposecontacts'] = 'Elenco dei contatti e gruppi per selezionare come destinatari';
$labels['arialabelcontactexportoptions'] = 'Impostazioni esportazione contatti';
$labels['arialabelabookgroupoptions'] = 'Impostazioni rubrica contatti/gruppi';
$labels['arialabelpreferencesform'] = 'Modulo preferenze';
$labels['arialabelidentityeditfrom'] = 'Modifica modulo identità';
$labels['arialabelresponseeditfrom'] = 'Modifica modulo ricezione';
$labels['arialabelsearchterms'] = 'Ricerca termini';
$labels['arialabeldropactionmenu'] = 'Menu azione con trascinamento';
$labels['arialabelheadersmenu'] = 'Aggiungi destinatario (intestazione) menu';
$labels['arialabelimagetools'] = 'Strumenti immagine';
$labels['helplistnavigation'] = 'Lista navigazione da tastiera';
$labels['helplistkeyboardnavigation'] = "Frecce su/giù: Sposta le righe selezionate.
Spazio: Seleziona fila mirata.
Shift + su/giù: Seleziona ulteriore fila da sotto e sopra.
Ctrl + Spazio: Aggiungi fila mirata da selezionato/rimosso a selezionato.";
$labels['helplistkeyboardnavmessages'] = "Frecce destra/sinistra: espande/comprime l'argomento del messaggio (solo in modalità argomenti).
Invio: apre il contatto selezionato.
Canc: sposta il messaggio selezionato nel cestino.";
$labels['helplistkeyboardnavcontacts'] = "Invio: Aprire il contatto selezionato";
