<roundcube:include file="includes/layout.html" />

<roundcube:if condition="env:task != 'mail'" />
	<h1 class="voice"><roundcube:label name="managesieve.filterdef" /></h1>
<roundcube:endif />

<div class="formcontent">
	<roundcube:object name="filterform" id="filter-form" class="propform" compact-form="true" />
</div>

<roundcube:if condition="env:task != 'mail'" />
<div class="formbuttons">
	<roundcube:button command="plugin.managesieve-save" class="btn btn-primary submit" label="save" />
</div>
<roundcube:endif />

<roundcube:include file="includes/footer.html" />
