<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/timezones/
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = 'Africa';
$labels['tz:africa:abidjan'] = 'Abidjan';
$labels['tz:africa:accra'] = 'Accra';
$labels['tz:africa:addis_ababa'] = 'Addis Ababa';
$labels['tz:africa:cairo'] = 'Cairo';
$labels['tz:africa:casablanca'] = 'Casablanca';
$labels['tz:africa:nairobi'] = 'Nairobi';
$labels['tz:africa:tripoli'] = 'Tripoli';
$labels['tz:africa:tunis'] = 'Tunis';
$labels['tz:america'] = 'America';
$labels['tz:america:argentina'] = 'Argentina';
$labels['tz:america:argentina:buenos_aires'] = 'Buenos Aires';
$labels['tz:america:argentina:cordoba'] = 'Cordoba';
$labels['tz:america:bogota'] = 'Bogota';
$labels['tz:america:cancun'] = 'Cancun';
$labels['tz:america:caracas'] = 'Caracas';
$labels['tz:america:cayman'] = 'Cayman';
$labels['tz:america:chicago'] = 'Chicago';
$labels['tz:america:costa_rica'] = 'Costa Rica';
$labels['tz:america:denver'] = 'Denver';
$labels['tz:america:detroit'] = 'Detroit';
$labels['tz:america:dominica'] = 'Dominica';
$labels['tz:arctic'] = 'Arctic';
$labels['tz:asia'] = 'Asia';
$labels['tz:asia:baghdad'] = 'Bagdad';
$labels['tz:asia:beirut'] = 'Beirut';
$labels['tz:asia:dubai'] = 'Dubai';
$labels['tz:asia:gaza'] = 'Gaza';
$labels['tz:asia:hong_kong'] = 'Hong Kong';
$labels['tz:asia:jerusalem'] = 'Ierusalim';
$labels['tz:asia:kuala_lumpur'] = 'Kuala Lumpur';
$labels['tz:europe:minsk'] = 'Minsk';
$labels['tz:europe:monaco'] = 'Monaco';
$labels['tz:europe:moscow'] = 'Moscova';
$labels['tz:europe:oslo'] = 'Oslo';
$labels['tz:europe:paris'] = 'Paris';
$labels['tz:europe:prague'] = 'Praga';
$labels['tz:europe:riga'] = 'Riga';
$labels['tz:europe:rome'] = 'Roma';
$labels['tz:europe:samara'] = 'Samara';
$labels['tz:europe:san_marino'] = 'San Marino';
$labels['tz:europe:sofia'] = 'Sofia';
$labels['tz:europe:vatican'] = 'Vatican';
$labels['tz:europe:vienna'] = 'Viena';
$labels['tz:europe:zagreb'] = 'Zagreb';
$labels['tz:pacific'] = 'Pacific';
$labels['tz:pacific:tahiti'] = 'Tahiti';
