<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['loginfailed']  = 'ننوتنه په بري سره ترسره نه شوه';
$messages['cookiesdisabled'] = 'ستاسو لټوني ککوړي ونه منل';
$messages['sessionerror'] = 'ستاسې ناسته ناباوري يا له مينځه تللې ده';
$messages['storageerror'] = 'له ای ميپ سرور سره پيوستون په بري سره ترسره نه شو';
$messages['nomessagesfound'] = 'ليکبکس کې هېڅ استوزي ونه مونده';
$messages['loading'] = 'د کار په حال کې';
$messages['loadingdata'] = 'اومتوک د کار په حال کې';
$messages['checkingmail'] = 'نوي استوزي ګوري';
$messages['sendingmessage'] = 'استوزه استوي.';
$messages['messagesent'] = 'استوزه په بري سره واستول شوه';
$messages['savingmessage'] = 'استوزه خوندي کوي';
$messages['messagesaved'] = 'استوزه په بارليک کې خوندي شوه';
$messages['successfullysaved'] = 'په بري‌سره خوندي شوه';
$messages['addedsuccessfully'] = 'اړيکلوری په بري سره پتې کتاب ته ور زيات شو';
$messages['blockedimages'] = 'ستاسو د پټتيآ خوندي کېدو لپاره ، له لري انځورنه په دې استوزي‌کې بند کړئ';
$messages['encryptedmessage'] = 'دا يوه پټه استوزه ده او نه څرګندېږي. بښنه غواړو';
$messages['nocontactsfound'] = 'هېڅ اړيکلوری يې ونه موند';
$messages['contactnotfound'] = 'وړاندی شوی اړيکلوری ونه مونده';
$messages['sendingfailed'] = 'استوزي استونه په بري سره پای ته ونه رسېده';
$messages['senttooquickly'] = 'مهرباني وکړئ $صبر وکړئ د دې استوزې له لېږلو مخکې';
$messages['errormoving'] = 'استوزه ونه خوځول شوه';
$messages['errordeleting'] = 'استوزه ړنګه نه شوه';
$messages['deletecontactconfirm']  = 'په رښتيا سره غواړئ چې ټاکل شوی اړيکلوری ړنګ کړئ؟';
$messages['deletemessagesconfirm'] = 'په رښتيا سره غواړئ چې ټاکل شوي استوزي‌ړنګ کړئ؟';
$messages['deletefolderconfirm']  = 'په رښتيآ سره غواړئ چې دا پوښۍ ړنګه کړئ؟';
$messages['purgefolderconfirm']  = 'په رښتيا سره غواړئ چې ددې پوښۍ ټول استوزي‌ړنګ کړئ؟';
$messages['folderdeleting'] = 'پوښۍ ړنګوي';
$messages['foldermoving'] = 'پوښۍ خوځوي';
$messages['formincomplete'] = 'دا پورمه بشپړه ډکه شوې نه ده';
$messages['noemailwarning'] = 'مهرباني وکړئ د يوه شته برېښناليک پته ورځای کړئ';
$messages['nonamewarning']  = 'مهرباني‌وکړئ يو نوم وليکئ';
$messages['nopagesizewarning'] = 'مهرباني‌وکړئ د پاڼې کچه ورکړئ';
$messages['norecipientwarning'] = 'مهرباني‌وکړئ لږ تر لږه يو ترلاسه کوونکی وليکئ';
$messages['nosubjectwarning']  = 'د مضمون ډګر تش دی يا تاسو غواړئ چې همدا اوس يو له هغو څخه وليکئ';
$messages['nobodywarning'] = 'دا استوزه پرته له متن څخه استوئ؟';
$messages['nosearchname'] = 'مهرباني وکړئ  د يو اړيکلوري‌نوم يا برېښناليک پته وليکئ';
$messages['searchsuccessful'] = 'استوزي ومونده$';
$messages['searchnomatch'] = 'د پلټلو بيا راګرځېدل هېڅ سمون ونه خوړه';
$messages['searching'] = 'پلټي';
$messages['checking'] = 'ګوري';
$messages['nospellerrors'] = 'هېڅ ليکدودي‌تيروتنه ونه مونده';
$messages['folderdeleted'] = 'پوښۍ په بشپړه توګه ړنګه شوه';
$messages['deletedsuccessfully'] = 'په بشپړه توګه ړنګ شول';
$messages['converting'] = 'له استوزي څخه بڼې ړنګېږي';
$messages['messageopenerror'] = 'له سرور څخه استوزي پرمخ نه شي تلی';
$messages['fileuploaderror'] = 'دفايل پورته کول په بري سره سرته ونه رسيده';
$messages['filesizeerror'] = 'د پورته شوي فايل کچه بايد لږترلږه له $څخه تيری ونه کړي';
$messages['sourceisreadonly'] = 'ددې پتې يوازې سرچينه لوستل کېږي';
$messages['errorsavingcontact'] = 'د پتې اړيکلوری يې خوندي‌نه شو کړای';
$messages['movingmessage'] = 'استوزه خوځوي';
$messages['receiptsent'] = 'يو لوستل شوی رسليک په بشپړه توګه واستول شو';
$messages['errorsendingreceipt'] = 'رسليک يې ونه شوای ليږلی';
$messages['nodeletelastidentity'] = 'تاسې نه شئ کولی چې دا پېژندنه ړنګه کړئ، داستاسو اخرنی پيژندنه ده';
$messages['forbiddencharacter'] = 'د پوښۍ نوم له فوربايډن تورو څخه جوړ دی';
$messages['selectimportfile'] = 'مهرباني وکړئ‌يو فايل د پورته کولو لپاره وټاکئ';
$messages['addresswriterror'] = 'ټاکل شوی پتې کتاب د بياليکلو نه دی';
$messages['importwait'] = 'نقلوي...صبر وکړئ';
$messages['importconfirm'] = '<b>په بشپړه توګه نقل شو $اړيکلوري داخل شول, $شته تيرشوي انټاير څخه تيرشول</b>:<p><em>$نومونه</em></p>';
$messages['opnotpermitted'] = 'چار اجازه نه لري';
