<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filters';
$labels['managefilters'] = 'Beheer filters voor inkomende e-mail';
$labels['filtername'] = 'Filternaam';
$labels['newfilter'] = 'Nieuw filter';
$labels['filteradd'] = 'Filter toevoegen';
$labels['filterdel'] = 'Verwijder filter';
$labels['rules'] = 'Regels';
$labels['actions'] = 'Acties';
$labels['scope'] = 'Zoekbereik';
$labels['moveup'] = 'Verplaats omhoog';
$labels['movedown'] = 'Verplaats omlaag';
$labels['filterallof'] = 'die voldoet aan alle volgende regels';
$labels['filteranyof'] = 'die voldoet aan één van de volgende regels';
$labels['filterany'] = 'alle berichten';
$labels['filtercontains'] = 'bevat';
$labels['filternotcontains'] = 'bevat niet';
$labels['filteris'] = 'is gelijk aan';
$labels['filterisnot'] = 'is niet gelijk aan';
$labels['filterexists'] = 'bestaat';
$labels['filternotexists'] = 'bestaat niet';
$labels['filtermatches'] = 'komt overeen met expressie';
$labels['filternotmatches'] = 'komt niet overeen met expressie';
$labels['filterregex'] = 'komt overeen met de reguliere expressie';
$labels['filternotregex'] = 'komt niet overeen met de reguliere expressie';
$labels['filterunder'] = 'onder';
$labels['filterover'] = 'over';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME gedeelte:';
$labels['mime-message'] = 'bericht';
$labels['mime-anychild'] = 'elke';
$labels['mime-type'] = 'type';
$labels['mime-subtype'] = 'subtype';
$labels['mime-contenttype'] = 'inhoudstype';
$labels['mime-param'] = 'parameter';
$labels['addrule'] = 'Regel toevoegen';
$labels['delrule'] = 'Regel verwijderen';
$labels['messagemoveto'] = 'Verplaats bericht naar';
$labels['messageredirect'] = 'Bericht doorsturen naar';
$labels['messagecopyto'] = 'Kopieer bericht naar';
$labels['messagesendcopy'] = 'Verstuur een kopie naar';
$labels['messagereply'] = 'Beantwoord met bericht';
$labels['messagedelete'] = 'Verwijder bericht';
$labels['messagediscard'] = 'Met bericht negeren';
$labels['messagekeep'] = 'Bewaar bericht in Postvak IN';
$labels['messagesrules'] = 'Voor binnenkomende e-mail:';
$labels['messagesactions'] = '...voer de volgende acties uit';
$labels['add'] = 'Toevoegen';
$labels['del'] = 'Verwijderen';
$labels['sender'] = 'Afzender';
$labels['recipient'] = 'Ontvanger';
$labels['vacationaddr'] = 'Mijn e-mailadressen:';
$labels['vacationdays'] = 'Hoe vaak moet een bericht verstuurd worden (in dagen):';
$labels['vacationinterval'] = 'Hoe vaak moet een bericht verstuurd worden:';
$labels['vacationreason'] = 'Bericht (vakantiereden):';
$labels['vacationfrom'] = 'Antwoord-afzender adres:';
$labels['vacationsubject'] = 'Onderwerp:';
$labels['days'] = 'dagen';
$labels['seconds'] = 'seconden';
$labels['rulestop'] = 'Stop met regels uitvoeren';
$labels['enable'] = 'In-/uitschakelen';
$labels['filterset'] = 'Filterset';
$labels['filtersets'] = 'Filtersets';
$labels['filtersetadd'] = 'Filterset toevoegen';
$labels['filtersetdel'] = 'Filterset verwijderen';
$labels['filtersetact'] = 'Huidige filterset activeren';
$labels['filtersetdeact'] = 'Huidige filterset uitschakelen';
$labels['filterseteditraw'] = 'Filterset bewerken';
$labels['filtersetswitch'] = 'Filterset in/uitschakelen';
$labels['filterdef'] = 'Filterdefinitie';
$labels['filtersetname'] = 'Filtersetnaam';
$labels['newfilterset'] = 'Nieuwe filterset';
$labels['active'] = 'actief';
$labels['none'] = 'geen';
$labels['fromset'] = 'van set';
$labels['fromfile'] = 'van bestand';
$labels['filterdisabled'] = 'Filter uitgeschakeld';
$labels['filterenabled'] = 'Filter ingeschakeld';
$labels['countisgreaterthan'] = 'aantal is groter dan';
$labels['countisgreaterthanequal'] = 'aantal is groter dan of gelijk aan';
$labels['countislessthan'] = 'aantal is kleiner dan';
$labels['countislessthanequal'] = 'aantal is kleiner dan of gelijk aan';
$labels['countequals'] = 'aantal is gelijk aan';
$labels['countnotequals'] = 'aantal is niet gelijk aan';
$labels['valueisgreaterthan'] = 'waarde is groter dan';
$labels['valueisgreaterthanequal'] = 'waarde is groter dan of gelijk aan';
$labels['valueislessthan'] = 'waarde is minder dan';
$labels['valueislessthanequal'] = 'waarde is minder dan of gelijk aan';
$labels['valueequals'] = 'waarde is gelijk aan';
$labels['valuenotequals'] = 'waarde is niet gelijk aan';
$labels['setflags'] = 'Stel markeringen in op bericht';
$labels['addflags'] = 'Voeg markeringen toe aan bericht';
$labels['removeflags'] = 'Verwijder markeringen van bericht';
$labels['flagread'] = 'Lezen';
$labels['flagdeleted'] = 'Verwijderd';
$labels['flaganswered'] = 'Beantwoord';
$labels['flagflagged'] = 'Gemarkeerd';
$labels['flagdraft'] = 'Concept';
$labels['addheader'] = 'Voeg header toe aan bericht';
$labels['deleteheader'] = 'Verwijder header van bericht';
$labels['headername'] = 'Header naam';
$labels['headervalue'] = 'Header waarde';
$labels['headerpos'] = 'Header positie';
$labels['headeratstart'] = 'in het begin';
$labels['headeratend'] = 'op het einde';
$labels['headeroccurrence'] = 'Header weergave/positie';
$labels['headerfromstart'] = 'vanaf begin';
$labels['headerfromend'] = 'vanaf einde';
$labels['headerpatterns'] = 'Header gegevenspatroon';
$labels['headermatchtype'] = 'match op type:';
$labels['setvariable'] = 'Variabele instellen';
$labels['setvarname'] = 'Naam variabele:';
$labels['setvarvalue'] = 'Waarde:';
$labels['setvarmodifiers'] = 'Waarde wijzigen:';
$labels['varlower'] = 'kleine letters';
$labels['varupper'] = 'hoofdletters';
$labels['varlowerfirst'] = 'eerste karakter als kleine letter';
$labels['varupperfirst'] = 'eerste karakter als hoofdletter';
$labels['varquotewildcard'] = 'speciale karakters quoten';
$labels['varlength'] = 'lengte';
$labels['notify'] = 'Stuur melding';
$labels['notifytarget'] = 'Meldingsdoel:';
$labels['notifymessage'] = 'Meldingsbericht (optioneel):';
$labels['notifyoptions'] = 'Meldingsopties (optioneel):';
$labels['notifyfrom'] = 'Meldingsafzender (optioneel):';
$labels['notifyimportance'] = 'Prioriteit:';
$labels['notifyimportancelow'] = 'laag';
$labels['notifyimportancenormal'] = 'normaal';
$labels['notifyimportancehigh'] = 'hoog';
$labels['notifymethodmailto'] = 'E-mail';
$labels['notifymethodtel'] = 'Telefoon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Filter aanmaken';
$labels['usedata'] = 'Gebruik de volgende gegevens in het filter:';
$labels['nextstep'] = 'Volgende stap';
$labels['...'] = '...';
$labels['string'] = 'Karakterreeks';
$labels['currdate'] = 'Huidige datum';
$labels['datetest'] = 'Datum';
$labels['dateheader'] = 'header:';
$labels['year'] = 'jaar';
$labels['month'] = 'maand';
$labels['day'] = 'dag';
$labels['date'] = 'datum (jjjj-mm-dd)';
$labels['julian'] = 'datum (juliaanse kalender)';
$labels['hour'] = 'uur';
$labels['minute'] = 'minuut';
$labels['second'] = 'seconde';
$labels['time'] = 'tijd (uu:mm:ss)';
$labels['iso8601'] = 'datum (ISO-8601)';
$labels['std11'] = 'datum (RFC 2822)';
$labels['zone'] = 'tijdzone';
$labels['weekday'] = 'weekdag (0-6)';
$labels['advancedopts'] = 'Geavanceerde opties';
$labels['body'] = 'Inhoud';
$labels['address'] = 'adres';
$labels['envelope'] = 'envelope';
$labels['modifier'] = 'toets op:';
$labels['text'] = 'tekst';
$labels['undecoded'] = 'undecoded (raw)';
$labels['contenttype'] = 'content type';
$labels['modtype'] = 'type:';
$labels['allparts'] = 'Alle';
$labels['domain'] = 'domein';
$labels['localpart'] = 'lokaal gedeelte';
$labels['user'] = 'gebruiker';
$labels['detail'] = 'detail';
$labels['comparator'] = 'vergelijkingswijze:';
$labels['default'] = 'standaard';
$labels['octet'] = 'strikt (octet)';
$labels['asciicasemap'] = 'hoofdletterongevoelig (ascii-casemap)';
$labels['asciinumeric'] = 'numeriek (ascii-numeriek)';
$labels['index'] = 'index:';
$labels['indexlast'] = 'terugwaarts';
$labels['spamtestisgreaterthan'] = 'is groter dan';
$labels['spamtestisgreaterthanequal'] = 'is groter dan of gelijk aan';
$labels['spamtestislessthan'] = 'is minder dan';
$labels['spamtestislessthanequal'] = 'is minder dan of gelijk aan';
$labels['spamtestequals'] = 'is gelijk aan';
$labels['spamtestnotequals'] = 'is niet gelijk aan';
$labels['spamtestisunknown'] = 'is onbekend';
$labels['vacation'] = 'Afwezigheidsbericht';
$labels['vacation.reply'] = 'Antwoordbericht';
$labels['vacation.advanced'] = 'Geavanceerde instellingen';
$labels['vacation.from'] = 'Antwoord-afzender adres';
$labels['vacation.subject'] = 'Onderwerp';
$labels['vacation.body'] = 'Inhoud';
$labels['vacation.start'] = 'Start tijdstip';
$labels['vacation.end'] = 'Eind tijdstip';
$labels['vacation.status'] = 'Status';
$labels['vacation.on'] = 'Aan';
$labels['vacation.off'] = 'Uit';
$labels['vacation.addresses'] = 'Mijn e-mailadressen';
$labels['vacation.interval'] = 'Antwoordinterval';
$labels['vacation.after'] = 'Plaats de afwezigheidsregel achter';
$labels['vacation.saving'] = 'Gegevens worden opgeslagen...';
$labels['vacation.action'] = 'Actie voor inkomend bericht';
$labels['vacation.keep'] = 'Bewaren';
$labels['vacation.discard'] = 'Weggooien';
$labels['vacation.redirect'] = 'Doorsturen naar';
$labels['vacation.copy'] = 'Kopie sturen naar';
$labels['forward'] = 'Doorsturen';
$labels['forward.redirect'] = 'Doorsturen naar';
$labels['forward.copy'] = 'Kopie sturen naar';
$labels['forward.on'] = 'Aan';
$labels['forward.off'] = 'Uit';
$labels['forward.status'] = 'Status:';
$labels['forward.action'] = 'Voer de volgende actie uit voor binnenkomende berichten:';
$labels['forward.saving'] = 'Gegevens worden opgeslagen...';
$labels['filladdresses'] = 'Vullen met al mijn adressen';
$labels['arialabelfiltersetactions'] = 'Filtersetacties';
$labels['arialabelfilteractions'] = 'Filteracties';
$labels['arialabelfilterform'] = 'Filtereigenschappen';
$labels['ariasummaryfilterslist'] = 'Filterlijst';
$labels['ariasummaryfiltersetslist'] = 'Lijst met filtersets';
$labels['filterstitle'] = 'Bewerk filters voor inkomende berichten';
$labels['vacationtitle'] = 'Bewerk vakantieregel';
$labels['forwardtitle'] = 'Bewerk regel voor doorsturen van mail';
$labels['message'] = 'Bericht';
$labels['duplicate'] = 'is duplicaat';
$labels['notduplicate'] = 'is geen duplicaat';
$labels['duplicate.handle'] = 'handle:';
$labels['duplicate.header'] = 'header:';
$labels['duplicate.uniqueid'] = 'identificatie:';
$labels['duplicate.seconds'] = 'timeout (seconden):';
$labels['duplicate.last'] = 'relatief aan de laatste uitvoering';
$messages['filterunknownerror'] = 'Onbekende fout';
$messages['filterconnerror'] = 'Kan geen verbinding maken met de managesieve server';
$messages['filterdeleteerror'] = 'Kan filter niet verwijderen. Er trad een serverfout op.';
$messages['filterdeleted'] = 'Filter succesvol verwijderd';
$messages['filtersaved'] = 'Filter succesvol opgeslagen';
$messages['filtersaveerror'] = 'Kan filter niet opslaan. Er trad een serverfout op.';
$messages['filterformerror'] = 'Filterformulier bevat fouten.';
$messages['filterdeleteconfirm'] = 'Weet je zeker dat je het geselecteerde filter wilt verwijderen?';
$messages['ruledeleteconfirm'] = 'Weet je zeker dat je de geselecteerde regel wilt verwijderen?';
$messages['actiondeleteconfirm'] = 'Weet je zeker dat je de geselecteerde actie wilt verwijderen?';
$messages['forbiddenchars'] = 'Verboden karakters in het veld';
$messages['cannotbeempty'] = 'Veld mag niet leeg zijn';
$messages['ruleexist'] = 'Er bestaat al een filter met deze naam.';
$messages['setactivateerror'] = 'Filterset kon niet geactiveerd worden. Er trad een serverfout op.';
$messages['setdeactivateerror'] = 'Filterset kon niet gedeactiveerd worden. Er trad een serverfout op.';
$messages['setdeleteerror'] = 'Filterset kon niet verwijderd worden. Er trad een serverfout op.';
$messages['setactivated'] = 'Filterset succesvol geactiveerd.';
$messages['setdeactivated'] = 'Filterset succesvol gedeactiveerd.';
$messages['setdeleted'] = 'Filterset succesvol verwijderd.';
$messages['setupdated'] = 'Filterset succesvol bijgewerkt.';
$messages['setdeleteconfirm'] = 'Weet u zeker dat u de geselecteerde filterset wilt verwijderen?';
$messages['setcreateerror'] = 'Filterset kon niet aangemaakt worden. Er trad een serverfout op.';
$messages['setcreated'] = 'Filterset succesvol aangemaakt.';
$messages['activateerror'] = 'Geselecteerde filter(s) konden niet ingeschakeld worden. Er trad een serverfout op.';
$messages['deactivateerror'] = 'Geselecteerde filter(s) konden niet uitgeschakeld worden. Er trad een serverfout op.';
$messages['deactivated'] = 'Filter(s) succesvol ingeschakeld.';
$messages['activated'] = 'Filter(s) succesvol uitgeschakeld.';
$messages['moved'] = 'Filter succesvol verplaatst.';
$messages['moveerror'] = 'Het geselecteerde filter kon niet verplaatst worden. Er trad een serverfout op.';
$messages['nametoolong'] = 'Naam is te lang.';
$messages['namereserved'] = 'Gereserveerde naam.';
$messages['setexist'] = 'Filterset bestaat al.';
$messages['nodata'] = 'Tenminste één positie moet geselecteerd worden!';
$messages['invaliddateformat'] = 'Ongeldige datum of datumformaat';
$messages['saveerror'] = 'Opslaan van de gegevens is mislukt. Er trad een serverfout op.';
$messages['vacationsaved'] = 'Afwezigheidsbericht correct bewaard.';
$messages['forwardsaved'] = 'Doorstuur data succesvol opgeslagen.';
$messages['emptyvacationbody'] = 'Inhoud van vakantiebericht is verplicht!';
$messages['duplicate.conflict.err'] = 'Zowel header en unieke identificatie opgeven is niet toegestaan.';
$messages['disabledaction'] = 'Actie is niet toegestaan.';
$messages['lastindexempty'] = 'Gelieve een index op te geven.';
$messages['noflagset'] = 'Er moet ten minste één optie worden geselecteerd.';
