<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Deling';
$labels['myrights'] = 'Tilgangsrettigheter';
$labels['username'] = 'Bruker:';
$labels['advanced'] = 'Avansert modus';
$labels['add'] = 'Legg til';
$labels['newuser'] = 'Legg til oppføring';
$labels['editperms'] = 'Rediger tilgangsrettigheter';
$labels['actions'] = 'Valg for tilgangsrettigheter.';
$labels['anyone'] = 'Alle brukere (alle)';
$labels['anonymous'] = 'Gjester (anonyme)';
$labels['identifier'] = 'Identifikator';
$labels['acll'] = 'Oppslag';
$labels['aclr'] = 'Les meldinger';
$labels['acls'] = 'Behold lesestatus';
$labels['aclw'] = 'Lagre flagg';
$labels['acli'] = 'Lim inn';
$labels['aclp'] = 'Post';
$labels['aclc'] = 'Opprett undermapper';
$labels['aclk'] = 'Opprett undermapper';
$labels['acld'] = 'Slett meldinger';
$labels['aclt'] = 'Slett meldinger';
$labels['acle'] = 'Slett fullstendig';
$labels['aclx'] = 'Slett mappe';
$labels['acla'] = 'Administrer';
$labels['aclfull'] = 'Full kontroll';
$labels['aclother'] = 'Annet';
$labels['aclread'] = 'Les';
$labels['aclwrite'] = 'Skriv';
$labels['acldelete'] = 'Slett';
$labels['shortacll'] = 'Oppslag';
$labels['shortaclr'] = 'Les';
$labels['shortacls'] = 'Behold';
$labels['shortaclw'] = 'Skriv';
$labels['shortacli'] = 'Sett inn';
$labels['shortaclp'] = 'Post';
$labels['shortaclc'] = 'Opprett';
$labels['shortaclk'] = 'Opprett';
$labels['shortacld'] = 'Slett';
$labels['shortaclt'] = 'Slett';
$labels['shortacle'] = 'Slett fullstendig';
$labels['shortaclx'] = 'Slett mappe';
$labels['shortacla'] = 'Administrer';
$labels['shortaclother'] = 'Annet';
$labels['shortaclread'] = 'Les';
$labels['shortaclwrite'] = 'Skriv';
$labels['shortacldelete'] = 'Slett';
$labels['longacll'] = 'Mappen er synlig og kan abonneres på';
$labels['longaclr'] = 'Mappen kan åpnes for lesing';
$labels['longacls'] = 'Meldingenes lesestatusflagg kan endres';
$labels['longaclw'] = 'Meldingsflagg og -nøkkelord kan endres, bortsett fra status for lesing og sletting';
$labels['longacli'] = 'Meldinger kan lagres eller kopieres til mappen';
$labels['longaclp'] = 'Meldinger kan postes til denne mappen';
$labels['longaclc'] = 'Mapper kan opprettes (eller navnes om) direkte under denne mappen';
$labels['longaclk'] = 'Mapper kan opprettes (eller navnes om) direkte under denne mappen';
$labels['longacld'] = 'Meldingenes flagg for sletting kan endres';
$labels['longaclt'] = 'Meldingenes flagg for sletting kan endres';
$labels['longacle'] = 'Meldingen kan slettes for godt';
$labels['longaclx'] = 'Mappen kan slettes eller gis nytt navn';
$labels['longacla'] = 'Mappens tilgangsrettigheter kan endres';
$labels['longaclfull'] = 'Full kontroll, inkludert mappeadministrasjon';
$labels['longaclread'] = 'Mappen kan åpnes for lesing';
$labels['longaclwrite'] = 'Meldinger kan merkes, lagres i eller flyttes til mappen';
$labels['longacldelete'] = 'Meldingen kan slettes';
$labels['longaclother'] = 'Andre tilgangsrettigheter';
$labels['ariasummaryacltable'] = 'List tilgangsrettigheter';
$messages['deleting'] = 'Sletter tilgangsrettigheter';
$messages['saving'] = 'Lagrer tilgangsrettigheter';
$messages['updatesuccess'] = 'Tilgangsrettigheter ble endret';
$messages['deletesuccess'] = 'Tilgangsrettigheter ble slettet';
$messages['createsuccess'] = 'Tilgangsrettigheter ble lagt til';
$messages['updateerror'] = 'Kunne ikke oppdatere tilgangsrettigheter';
$messages['deleteerror'] = 'Kunne ikke fjerne tilgangsrettigheter';
$messages['createerror'] = 'Kunne ikke legge til tilgangsrettigheter';
$messages['deleteconfirm'] = 'Er du sikker på at du vil fjerne tilgangen til  valgte brukere';
$messages['norights'] = 'Ingen rettigheter er spesifisert!';
$messages['nouser'] = 'Brukernavn er ikke spesifisert!';
